(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    167164,       2748]*)
(*NotebookOutlinePosition[    168352,       2784]*)
(*  CellTagsIndexPosition[    168308,       2780]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Butterfly Mimicry", "Title"],

Cell[TextData[
"Christian Jacob, jacob@cpsc.ucalgary.ca \[Dash] August 1997 (copyright)"], 
  "Subsubtitle"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "For the last four billion years, nature has unfolded and still does show a \
great potential of creativity in developing mechanisms to adapt organisms to \
their specific environments. ",
  StyleBox["Mimesis",
    FontSlant->"Italic"],
  ", the imitation of colour and form of other objects, provides an excellent \
example for such adaptations. Some grasshoppers, like ",
  StyleBox["Cycloptera",
    FontSlant->"Italic"],
  ", look so much alike branchlets and leaves, that they are virtually \
invisible as prey. Thus there is no need for these grasshoppers to explicitly \
hide from their enemies."
}], "Text",
  TextJustification->0.75],

Cell["\<\
However, this kind of camouflage is not due to any intelligent \
behaviour of the grasshoppers, those special structure formations and surface \
colourings are the result of evolutionary selection processes over a large \
number of generations. Those grasshoppers more unlikely to be discovered \
simply have a higher chance of survial and are thus able to pass on their \
specific genes to their descendants.\
\>", "Text"],

Cell[TextData[{
  "Camouflage is observable with many other species, especially among \
butterflies, reptiles or fish. Many examples within the context of ",
  StyleBox["industrial",
    FontSlant->"Italic"],
  " ",
  StyleBox["melanism",
    FontSlant->"Italic"],
  " have been reported among butterfly populations, one favorite example \
being the ",
  StyleBox["peppered moth",
    FontSlant->"Italic"],
  " in Great Britain during the Industrial Revolution (",
  ButtonBox["Goldberg 1989",
    ButtonData:>{":::References.nb", "Goldberg 1989"},
    ButtonStyle->"Hyperlink"],
  ", p. 149f.). Its wildform had white wings with small black specks, an \
effective camouflage in the moth\.b4s natural habitat, lichen-covered trees. \
With growing air pollution near industrial towns, however, a shift in \
population balance from the white winged form to a melanic (dark) form could \
be observed. Nowadays, with improved filter systems that tremendously reduce \
air pollution the brighter coloured moth reappears."
}], "Text"],

Cell["\<\
We will examine simplified versions of these evolutionary \
adaptation effects in the following sections.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Butterfly camouflage evolved", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell[TextData[{
  "We simulate the evolution of butterfly wing colouring by the following \
simple model. A flock of butterflies located on a tree bark is represented by \
a vector W",
  Cell[BoxData[
      \(TraditionalForm\`\( = {w\_1\)\)]],
  ", \[Ellipsis], ",
  Cell[BoxData[
      \(TraditionalForm\`w\_m\)]],
  "}, where each entry ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(w\_i\),
            "TraditionalForm"], "=", \((w\_i1\)}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w\_i2\)]],
  ") either denotes a butterfly, ",
  Cell[BoxData[
      \(TraditionalForm\`w\_i\)]],
  "=(1, ",
  StyleBox["h",
    FontSlant->"Italic"],
  "), with ",
  StyleBox["h",
    FontSlant->"Italic"],
  " \[Element] [0,1] describing the hue of its wing colour, or a \
\[RightGuillemet]bark cell\[LeftGuillemet], ",
  Cell[BoxData[
      \(TraditionalForm\`w\_i\)]],
  "=(0, ",
  StyleBox["b",
    FontSlant->"Italic"],
  "), with ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Element] \([0, 1]\)\)]],
  " being the hue of the bark."
}], "Text"],

Cell[TextData[{
  "For each butterfly with wing hue ",
  StyleBox["h",
    FontSlant->"Italic"],
  " its capability of camouflaging within its environment is considered as \
its fitness, \[Tau](",
  StyleBox["h",
    FontSlant->"Italic"],
  "), which is computed as the inverse difference to the background colour \
value:"
}], "Text"],

Cell[TextData[{
  "\[Tau](",
  StyleBox["h",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\( | h - b | \)\)]]
}], "Text",
  TextAlignment->Center],

Cell["\<\
So the better a wing colour corresponds to the background colour, \
the more unlikely this butterfly is to be discovered by a bird.\
\>", "Text"],

Cell[TextData[{
  "The butterflies\.b4 struggle for survival will be modeled by the following \
two phases of selection and birth. Each of these phases is iterated for ",
  StyleBox["Round",
    FontSlant->"Italic"],
  "[",
  Cell[BoxData[
      \(TraditionalForm\`m\/\[Rho]\)]],
  "] many times, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Element] \([0, 1]\)\)]],
  " is the ",
  StyleBox["reduction-creation portion",
    FontSlant->"Italic"],
  ", the percentage of individuals to be replaced by mutant offspring."
}], "Text"],

Cell[CellGroupData[{

Cell["Selection", "Subsubsection"],

Cell[TextData[{
  "A butterfly will be selected with a probability proportionate to its \
inverse fitness ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\[Tau]\)]],
  ". The selected individual falls prey to a bird and leaves an empty cell of \
bark."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Birth", "Subsubsection"],

Cell[TextData[{
  "One of the remaining butterflies is selected at random; from this wildtype \
a mutant is generated which is placed at one of the empty bark spots. The \
mutation is influenced by the two parameters of mutation probability, \[Mu], \
and mutation radius, \[Rho]. For a more detailed explanation of these \
parameters see the example notebooks on ",
  ButtonBox["Cumulative Selection",
    ButtonData:>{"::Cumulative Selection:Cumulative Selection.nb", 
      "mutation"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Evolution experiments \[Ellipsis]"], "Subsection"],

Cell[TextData[{
  "For some further evolution experiments on butterfly camouflage see the ",
  ButtonBox["butterflies",
    ButtonData:>{"Butterflies-2D.nb", None},
    ButtonStyle->"Hyperlink"],
  " notebook."
}], "Text"],

Cell["\<\
Figure 1 illustrates a typical evolution experiment where an \
initially darker coloured population of butterflies eventually adopts to a \
bright background.\
\>", "Text"],

Cell[GraphicsData["PICT", "\<\
a[80@`0b0SH1CP0A0_l<0?ooool0<P0004<0005>0002=P000000000N00402P12
0342=P5>00X000000000000d04<0<P4R06/00@0:04<0<P4R06/0V81B0000004o
05400000000000180000B0000000200100P000000;2A6000000002Bk0000o`00
oooooooo007oooooc<`00_oloobZZ003ooooofIV00@g8cLS=b<01GHVMRIf9P06
]BZe:[DZ00Od;_@^m2h02000oobZZ009>a<k4c/C00Yj5gXGNQL02kTJ^AZi6P0<
n1kh7_PN00d00?oloo`03UEDoocoo00?ZZSoo?ol013ooiVI<c<04OooVIT0000B
oomVI_oo01?oofIVc<`053/C>a<k4`0ENQMj5gXG01Ji6[TJ^AX05oPNn1kh7P0H
003oo?ol01To0cl3?`<06Wh7OPMn1`0K_@^m2kd;01cl3_`>o0h07EED0000000N
ZZP0000001ooo00000008?oo002IV@0Qool006IV02;oo`00<c<08ooo0000000T
?`<o0cl302En1gh7OPL09[d;_@^m2`0Wo0kl3_`>02P3l0?`0o00:D;c@_=2l`0Z
PON1mh7g02_0nl3k`?/0;000001EE00]EE@005ED02jZZ000EE@0;ool001EE00`
c<bIVOoo037<c9VIc<`0</c<VIVIV@0c0o03l0?`03A2ld;c@_<0=H7gPON1m`0f
`?_0nl3k03L00000EE@0>0OP1n07h00iA^A6i4KT03Z5ihGWQNL0>lC[a>_4j`0l
00000:ZX03eEE000ZZP0?ZZX002ZZ00ooo`00:ZX043<c3<c<c<0@Lc<<c<00012
c<`00?oo04<7h0OP1n00A4KTA^A6i015QNN5ihGW04K4jlC[a>/0A`00002ZZ018
2m0;d0_@04U:e4[DB]@0BXWHRMR9f01;b=_8flSK04`00000oo`0CEED003oo01>
ZZP00?ol04ooo000oo`0D9VIc<bIV@1AVIW<c6IV05:IVLc<<c<0D`_@2m0;d01D
B]A:e4[D05F9f8WHRMP0E/SKb=_8f`1G00000?ol05P?`0o03l00FDk4C/A>a01J
SLR=b8g805_<c<c<c<`0G000EE@0001MEEAEE00005jZZ5ED0000GoolEE@0001P
VITc<ooo066IVC<cc<`0HYVI<c>IV@1S3l0?`0o006A>a4k4C/@0IHg8SLR=b01V
c<c<c<c<06L005ED0000J1>a4k4C/@1YD[AB]5:d06ZA^96hTKP0Jm2ld;c@_01/
001EE5ED06eEE5EDEE@0KZZXEEAEE01_ooaEE5ED071VI_oo<c<0LFIVool0001b
IVK<c?oo07<C/A>a4k40M5:dD[AB]01eTKRA^96h07K@_=2ld;`0M`00EEAEE01h
5j4GXANQ07UFYEJUEZD0NYFXUJREZ01ke:cD[=B/07`005EDZZP0OEEDEEBZZ01n
ZZQEE:ZX07ooo5EDZZP0P6IVIVJIV@21IVIVIVIV089VIVIV<c<0PaNQ5j4GX@24
EZEFYEJU08FEZ9FXUJP0Q]B/e:cD[027001EE:ZX08PKTA^A6i40REZEFYEJU@2:
VIVIVIVI08_HW=RLf9`0S000EECoo02=EEAEE?ol08jZZ5EDoo`0SoolEECoo02@
<c?ooooo094c<oooc<`0TS<coonIV@2C6i4KTA^A09AJUEZEFYD0UIVIVIVIV@2F
f9cHW=RL09L005EDoo`0V1n17h4OP@2IGXENQEj509ZMRIf9WHT0Vmb<g8cLS02L
002ZZ00009eEE:ZX0000WZZXZZP0002OoobZZ0000:0c<iVI<c<0XC<cVIT0002R
<c=VI_oo0:<OPAn17h40Y5j5GXENQ@2UWHVMRIf90:KLS=b<g8`0Y`00ZZP0002X
8g8SLR=b0:URMF9eHWD0ZZ5iXGVQN@2[h7gPON1m0:`00:ZXEE@0[EEDZZQEE02^
ZZRZZ5ED0:ooo:ZXEE@0/3<c002IV@2a<c<006IV0;8c<`00<c<0/b=b8g8SLP2d
HWERMF9e0;FQNJ5iXGT0]^1mh7gPO@2g002ZZ5ED0;PWHRMR9f80^FIVIVIVIP2j
YFVUJJEY0;_TKNA]i6d0_000ZZRZZ02mEEBZZ:ZX0;jZZ:ZXZZP0_oolZZRZZ030
002IVOoo0<4009VIc<`0`P00VIVIV@339f8WHRMR0<AVIVIVIVH0aJEYYFVUJ@36
i6gTKNA]0<L00:ZXZZP0b2]B:e8[DP39JUIZEVYF0<ZYFJUIZET0bnQMj5gXG@3<
002ZZ?ol0<eEE:ZXoo`0cZZXZZSoo03?oobZZ?ol0=0003<c<c<0d@00<c<0003B
00000?oo0=<[DR]B:e80e6YFJUIZEP3EZEVYFJUI0=KXGNQMj5d0e`00ZZSoo03H
;d8_@Rm20=U^AVi6KTH0fZe:[DZ]BP3Kk4g/CNa=0=`00?ol0000gEEDoo`0003N
ZZSoo0000=ooo?ol0000h14A0000003Q003^kP000>800=gM0000hbm2;d8_@P3T
KTI^AVi60>F]BZe:[DX0i^a=k4g/C@3W003oo0000>Pc<c<c<c<0jG8fLSIb=P3Z
/CZa>[4j0>_`?_0nl3h0k000ooaEE03]EECoo5ED0>jZZ?olEE@0koolooaEE03`
000007Mg0?400000EED0lP000014A03c<c<c<c<c0?Ab=W8fLSH0mK4j/CZa>P3f
l3k`?_0n0?L00?olEE@0n3LS=b<g8`3iMRIf9WHV0?Ze:[DZ]BX0no@^m2kd;P3l
003oo:ZX0?eEE?olZZP0oZZXoobZZ03o000000000000004o0540@`0b0B80J`0T
1;0002D4/000L@B`003L1;000?l2[`04/000D@B`000j1;0006<4/000XP:_03CZ
003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?om
001Z<^X0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o
003noo`0>^X01OlT9?oo0?ko1@3oob@Too`01OmCDooo0?ko1@3ooe=Cood01On3
Pooo0?ko1@3ooh>3ood001@djP00oodT1?oo9?oooB@0oo`00?omD`Cooe?oooeC
0?om003ooH<4oon3ooomP`3oo@005acZ003om2@0oo`00?odD`3oo@00ooB30?om
00396^X00?od903oo000ooAC0?om003om8<0oo`06^X00?od903oo000ooAC0?om
003om8<0oo`0<NX00?ol90?o9?oooB@0oo`00?olD`?oDooooE<0ood00?olP`?o
PooooH<0ood003`hjP02ob@To_l30?l00?ko0BCoo002oe=Co_l30?l00?ko0E?o
o@02oh>3o_l30?l00?ko0H?oo00[jP3nood00?ol007ooo`0o_om003oo001ooom
0?koo@00oo`00Oooo@00U0B`000/1;000=a4o@00ooh00?ol003ooP00ood00?on
003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood00?m2
o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?ko
o@3no`800?on00;o003noo`0C?d01Oo3`ooo0?ko1@3ool?3ood01OlW9ooo0?ko
1@3oobLWoo`01Oo6a_oo0?ko1@3oolK6ood01OoUiOoo0?ko1@3oonGUood00<Y4
o@00oog31?oo`ooooL<0ood00?om9`CoobOooodW0?ol003ooLH4ooo6ooomaP3o
o@00oogU1?ooiOoooND0ood00>dTo@00ooC30?om003om2L0oo`00?odaP3oo@00
ooCU0?om003o9?d00?od``3oo@00oo@W0?ol003om<H0ood00?odi@3oo@00XR;m
003om<<0ood00?od9`3oo000ooC60?om003om>D0oo`0@?d00?ol``?o`ooooL<0
ood00?ol9`?o9ooooBL0oo`00?olaP?oa_oooLH0ood00?oli@?oiOoooND0ood0
0>=:o@02ol?3o_l30?l00?ko0L?oo@02obLWo_l30?l00?ko0BOoo002olK6o_l3
0?l00?ko0LKoo@02onGUo_l30?l00?ko0NGoo00ho@3nood00?ol007oood0o_om
003oo001oool0?koo@00oo`00Oooo@3nood00?ol007oood002L4/000V0B`0039
@_d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003ooP00
ood00?on003oo000ooh00?ol04;m0?ko0P00ooh00_l00?koo@3no`800?on00;o
003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo01<o@05oe=Cool0
o_l50?ooDe?oo@05oi>Cool0o_l50?ooTi?oo005o`H6ool0o_l50?oo1PKoo@05
of][ool0o_l50?ooJf_oo@000T;m003ooE<4oomCooomD`3oo@00oofC1?ooTooo
oI<0oo`00?om1PCoo`Koood60?om003ooF/4oom[ooomJ`3oo00To@00ooAC0?om
003om9<0oo`00?od1P3oo@00ooA[0?om000a9?d00?odD`3oo@00ooBC0?ol003o
m0H0ood00?odJ`3oo@00;2Cm003om5<0ood00?odT`3oo000oo@60?om003om6/0
ood00=I0o@00ooaC0omCooomD`3oo@00oobC0onCooomT`3oo000oo`60ol6ooom
1P3oo@00ooa[0om[ooomJ`3oo@00odcm00;oDe?no`<0o`00o_l1Doom00;oTi?n
o`<0o`00o_l1Tool00;o1PKno`<0o`00o_l11_om00;oJf_no`<0o`00o_l1Joom
0032=_d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om
003oo001oool00:_00:_04;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00
oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo014o@3no`800?on00;o
003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o
003nood001E:o@05obHVool0o_l50?oo9RKoo@05ofYZool0o_l50?ooJV[oo005
o`H6ool0o_l50?oo1PKoo@05oaDEool0o_l50?oo5AGoo014o@00oodV1?oo9_oo
oBH0ood00?omJPCoof[oooeZ0?ol003oo@H4ool6ooom1P3oo@00oodE1?oo5Ooo
oAD0ood002`To@00oo@V0?om003om6X0oo`00?od1P3oo@00oo@E0?om000/9?d0
0?od9P3oo@00ooAZ0?ol003om0H0ood00?od5@3oo@00g2Cm003om2H0ood00?od
JP3oo000oo@60?om003om1D0ood00?lno@00oo`V0olVooom9P3oo@00ooaZ0omZ
ooomJP3oo000oo`60ol6ooom1P3oo@00oo`E0olEooom5@3oo01<o@02obHVo_l3
0?l00?ko0BKoo@02ofYZo_l30?l00?ko0F[oo002o`H6o_l30?l00?ko0@Koo@02
oaDEo_l30?l00?ko0AGoo@00ACSm0?koo@00oo`00Oooo@3nood00?ol007ooo`0
o_om003oo001ooom0?koo@00oo`00Oooo@0070B`001j1;000:8bo@00ooh00?ol
003ooP00ood00?on003oo000ooh00?oY003ooP00oo`00?on003oo00do@3no`80
0?on00;o003nood0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo@00DSSm
00GoIFGoo`3no`D0oomUIOom00Go9BGoo`3no`D0oolU9OoY00GoYZKoo`3no`D0
oonVY_ol03Cm003ooFD4oomUooomI@3oo@00oodU1?oo9OoooBD0onT00?omYPCo
ojKooofV0?om001>7?d00?odI@3oo@00oo@U0?oY003om:H0ood000LLo@00ooAU
0?om003om2D0onT00?odYP3oo@004Q[m003om6D0ood00?od9@3oj@00ooBV0?ol
02om003oo6D3ofGoooeU0?om003oo2D3obGooodU0?oY003oo:H3ojKooofV0?ol
03[m00;oIFGno`<0o`00o_l1IOom00;o9BGno`<0o`00o_l19OoY00;oYZKno`<0
o`00o_l1Y_om000Y:Od0o_om003oo001ooom0?koo@00oo`00Oooj@3nood00?ol
007ooo`01;0002D4/000?CCZ003ooP00oo`00?on003oo000ooh00?ol003ooP00
ood00?on003oo000ooh00?om001[=>X0o_l2003ooP02o`00o_ol0?ko0P00ooh0
0_l00?koo@3no`800?on00;o003nood00?lhjP05oiFEool0o_l50?ooUIGoo005
o`H6ool0o_l50?oo1PKoo@05olK6ool0o_l50?ooa/Koo00djP00oofE1?ooUOoo
oID0oo`00?om1PCoo`Koood60?om003ooLH4ooo6ooomaP3oo@00_QcZ003om9D0
oo`00?od1P3oo@00ooC60?om000j7>X00?odU@3oo000oo@60?om003om<H0ood0
07dLjP00ooBE0?ol003om0H0ood00?odaP3oo@00XRoZ003oo9D3oiGooofE0?ol
003oo0H3o`Koood60?om003oo<H3olKooog60?ol03[Z00;oUIGno`<0o`00o_l1
UOol00;o1PKno`<0o`00o_l11_om00;oa/Kno`<0o`00o_l1a_om003G:NX0o_om
003oo001oool0?koo@00oo`00Oooo@3nood00?ol007ooo`01;0001@4/000[CCm
003ooP00oo`00?on003oj@00ooh00?ol003ooP00ood00?on003oo000ooh00?om
0039<_d0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo@3no`800?on00;o
003noo`0>?d01Oo6a_oo0?ko1@3oolK6onT01OnVY_oo0?ko1@3oojJVood01OoT
i?oo0?ko1@3oonCToo`0=?d00?omaPCoolKooog60?oY003ooJH4oonVooomYP3o
o@00oogT1?ooi?oooN@0ood003`Jo@00ooC60?oY003om:H0ood00?odi03oo00L
o@00ooC60?oY003om:H0ood00?odi03oo@00cAcm003om<H0onT00?odYP3oo@00
ooCT0?om000/<Od00?olaP?oa_oooLH0onT00?olYP?oY_oooJH0ood00?oli0?o
i?oooN@0ood00=`jo@02olK6o_l30?l00?ko0LKoj@02ojJVo_l30?l00?ko0JKo
o@02onCTo_l30?l00?ko0NCoo@00obWm0?koo@00oo`00Oooj@3nood00?ol007o
ood0o_om003oo001oool00B`000f1;0009@Do@00ooh00?ol003ooP00ol<001/D
o@3no`800?on00;o003nol<001HDo@05ob@Tool0o_l50?oo92Co`P0Bo@00oodT
1?oo9?oooB@0ol803?d00?od903o``00M0cm003om2@0ol<002`<o@00oo@T0?o3
003F4od00?ol90?o9?oooB@0ol<00?lDo@02ob@To_l30?l00?ko0BCo`P0Ao@3n
ood00?ol007ool<002d4/000X@B`003?=?d00?on003oo000ooh00?om003ooP00
oo`00?on003oj@00ooh00?ol003ooP00ood00:8bo@3no`800?on00;o003nood0
o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo00jo@05oiBDool0o_l50?oo
U9Coo@05oa@Dool0o_l50?oo51Coj@05oiJFool0o_l50?ooUYKoo@00AS;m003o
oI@4oonDooomU03oo@00oodD1?oo5?oooA@0onT00?omUPCooiKooofF0?ol01cm
003om9@0ood00?od503oj@00ooBF0?om000k7?d00?odU03oo@00oo@D0?oY003o
m9H0ood00?4Lo@00ooBD0?om003om1@0onT00?odUP3oo@004Rom003oo9@3oiCo
oofD0?om003oo1@3oaCooodD0?oY003oo9H3oiKooofF0?ol03Sm00;oU9Cno`<0
o`00o_l1U?om00;o51Cno`<0o`00o_l15?oY00;oUYKno`<0o`00o_l1U_ol02_m
0?koo@00oo`00Oooo@3nood00?ol007oonT0o_om003oo001ooom000E0Zl01;00
0=4do@00ooh00?ol003ooP00onT00?on003oo000ooh00?om003ooP00oo`00?on
003oo@00;3Cm0?ko0P00ooh00_l00?koj@3no`800?on00;o003nood0o_l2003o
oP02o`00o_om003L>_d01OnSXooo0?ko1@3ooj>SonT01OlV9_oo0?ko1@3oobHV
ood01Ooknooo0?ko1@3ooo_kood00?lbo@00oofS1?ooXooooJ<0onT00?om9PCo
obKooodV0?om003ooO/4oookooomn`3oo00Lo@00ooBS0?oY003om2H0ood00?od
n`3oo@00/Qcm003om:<0onT00?od9P3oo@00ooCk0?om00067?d00?odX`3oj@00
oo@V0?om003om?/0ood00:Pao@00oobS0onSooomX`3oj@00oo`V0olVooom9P3o
o@00oock0ookooomn`3oo@00XSSm00;oXj?no`<0o`00o_l1XooY00;o9RKno`<0
o`00o_l19_om00;ono_no`<0o`00o_l1nool02_m0?koo@00oo`00Oooj@3nood0
0?ol007oood0o_om003oo001ooom002o0Zl01;0004hdo@00ooh00?ol003ooP00
ood00?on003oo000ooh00?ol003ooP00oo`00?on003ojP00Y3Cm0?ko0P00ooh0
0_l00?koo@3no`800?on00;o003noo`0o_l2003ooP02o`00o_oZ0039>?d01On5
QOoo0?ko1@3oohF5ood01OnUYOoo0?ko1@3oojFUoo`01Oo3`ooo0?ko1@3ool?3
onT0<_d00?omQ@CoohGooof50?om003ooJD4oonUooomY@3oo000oog31?oo`ooo
oL<0onT07?d00?odQ@3oo@00ooBU0?ol003om<<0onX002TJo@00ooB50?om003o
m:D0oo`00?od``3oj@0Lo@00ooB50?om003om:D0oo`00?od``3ojP009C7m003o
o8D3ohGooof50?om003oo:D3ojGooofU0?ol003oo<<3ol?ooog30?oZ000/>_d0
0_n5QOko0`3o003no`65ood00_nUYOko0`3o003no`6Uoo`00_o3`oko0`3o003n
o`73onX00=`[o@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Ooo
jP00o`:_00B`000ZA?d00?on003oo000ooh00?om003ooP00oo`00?on003oo000
ooh00?ol003ooP00ood00?on003oo000ooh00?om001TA?d0o_l2003ooP02o`00
o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00
o_om003kC?d01OmFE_oo0?ko1@3ooeIFood01Ol41?oo0?ko1@3oo`@4oo`01Onn
__oo0?ko1@3ookjnood01On1POoo0?ko1@3ooh61ood00<=2o@00ooeF1?ooE_oo
oEH0ood00?om10Coo`Coood40?ol003ooKh4oonnooom_P3oo@00oof11?ooPOoo
oH40oo`08_d00?odEP3oo@00oo@40?ol003om;h0ood00?odP@3oo00To@00ooAF
0?om003om0@0oo`00?od_P3oo@00ooB10?om003o8_d00?odEP3oo@00oo@40?ol
003om;h0ood00?odP@3oo010o@00ooaF0omFooomEP3oo@00oo`40ol4ooom103o
o000oobn0onnooom_P3oo@00oob10on1ooomP@3oo@00C4cm00;oEUKno`<0o`00
o_l1E_om00;o10Cno`<0o`00o_l11?ol00;o_[kno`<0o`00o_l1__om00;oPH7n
o`<0o`00o_l1POom003o=_d0o_om003oo001ooom0?koo@00oo`00Oooo03nood0
0?ol007oood0o_om003oo001oool00B`000Q1;000>d4/000O2CF003ooP00oo`0
0?on003oo@00ooh00?ol003ooP00ood00:8ReP3no`800?on00;o003nood0o_l2
003ooP02o`00o_ol02SF00GoA4Coo`3no`D0oom4A?om00GoeMGoo`3no`D0oooE
eOom000j8]H00?omA0CoodCoooe40?om003ooMD4oooEooome@3oo00DeP00ooA4
0?om003om=D0ood002LDeP00ooA40?om003om=D0ood00=HReP00ooa40om4ooom
A03oo@00oocE0ooEooome@3oo@00bBKF00;oA4Cno`<0o`00o_l1A?om00;oeMGn
o`<0o`00o_l1eOol01cF0?koo@00oo`00Oooo@3nood00?ol007ooo`01;000082
[`04/000M4Cm003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003o
o000ooh00?om003ooP00oo`00?on003oo@00;4Cm0?ko0P00ooh00_l00?koo@3n
o`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00
g4cm00GoA4Coo`3no`D0oom4A?om00Go1@Goo`3no`D0ool51Ool00GoZ:Soo`3n
o`D0oonXZ?om00GoiNGoo`3no`D0oooUiOom003o@_d00?omA0CoodCoooe40?om
003oo@D4ool5ooom1@3oo000oofX1?ooZ?oooJP0ood00?omi@CoonGooogU0?ol
02Cm003om4@0ood00?od1@3oo000ooBX0?om003om>D0ood009TTo@00ooA40?om
003om0D0oo`00?odZ03oo@00ooCU0?om002a9?d00?odA03oo@00oo@50?ol003o
m:P0ood00?odi@3oo@00<T3m003oo4@3odCoooe40?om003oo0D3o`Goood50?ol
003oo:P3ojSooofX0?om003oo>D3onGooogU0?om002RB_d00_m4A?ko0`3o003n
o`54ood00_l51Oko0`3o003no`45oo`00_nXZ?ko0`3o003no`6Xood00_oUiOko
0`3o003no`7Uoo`0>?d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol
007oood0o_om003oo001ooom002c0Zl01;0003/TjP00ooh00?ol003ooP00onT0
0?on003oo000ooh00?om00219>X0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l0
0?koo@00bBKZ00GoiNGoo`3no`D0oooUiOoY00Go<c?oo`3no`D0oolc<ool02;Z
003ooND4oooUooomi@3oj@00oodc1?oo<ooooC<0oo`05>X00?odi@3oj@00oo@c
0?om000E4^X00?odi@3oj@00oo@c0?ol01CZ003om>D0onT00?od<`3oo@00;2;Z
003oo>D3onGooogU0?oY003oo3<3oc?ooodc0?om000/:>X00_oUiOko0`3o003n
o`7UonT00_lc<oko0`3o003no`4cood00=`NjP3nood00?ol007oonT0o_om003o
o001ooom003o0Zl01;0001i4o@00ooh00?ol003ooP00ood00?on003oo000ooh0
0?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood000I4o@3no`800?on
00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on
00;o003nood0015<o@05oa@Dool0o_l50?oo51Coo@05ojFUool0o_l50?ooYJGo
o005omCDool0o_l50?ooe=Coo@05ofe]ool0o_l50?ooKFgoo@00XT;m003ooA@4
oolDooom503oo@00oofU1?ooYOoooJD0oo`00?ome0CoomCooogD0?om003ooFd4
oom]ooomK@3oo00To@00oo@D0?om003om:D0oo`00?ode03oo@00ooA]0?om000[
8_d00?od503oo@00ooBU0?ol003om=@0ood00?odK@3oo00Ro@00oo@D0?om003o
m:D0oo`00?ode03oo@00ooA]0?ol03km003oo1@3oaCooodD0?om003oo:D3ojGo
oofU0?ol003oo=@3omCooogD0?om003oo6d3ofgoooe]0?ol04[m00;o51Cno`<0
o`00o_l15?om00;oYJGno`<0o`00o_l1YOol00;oe=Cno`<0o`00o_l1e?om00;o
KFgno`<0o`00o_l1KOol03Km0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om
003oo001ooom0?koo@00oo`00Oooo004/0005@B`000jA?d00?on003oo000ooh0
0?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh0
0?om001CA?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on
00;o003nood0o_l2003ooP02o`00o_om002RB_d01Ol[:ooo0?ko1@3oob/[ood0
1OmCDooo0?ko1@3ooe=Coo`01OmTI?oo0?ko1@3oofATood01OoFe_oo0?ko1@3o
omKFoo`0A?d00?om:`Coob_oood[0?om003ooE<4oomCooomD`3oo000ooeT1?oo
I?oooF@0ood00?omePCoomKooogF0?om000^8_d00?od:`3oo@00ooAC0?ol003o
m6@0ood00?odeP3oo00To@00oo@[0?om003om5<0oo`00?odI03oo@00ooCF0?om
000D9?d00?od:`3oo@00ooAC0?ol003om6@0ood00?odeP3oo@00UD3m003oo2/3
ob_oood[0?om003oo5<3oe?oooeC0?ol003oo6@3ofCoooeT0?om003oo=H3omKo
oogF0?om0039B_d00_l[:oko0`3o003no`4[ood00_mCDoko0`3o003no`5Coo`0
0_mTI?ko0`3o003no`5Tood00_oFe_ko0`3o003no`7Foo`0=_d0o_om003oo001
ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001oool00B`000l
0Zl0=>X00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003o
oP00ood00<ddjP3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00
ooh00_l00?koo@00;3[Z00Go1@Goo`3no`D0ool51Ool00Go10Coo`3no`D0ool4
1?om00GoEUKoo`3no`D0oomFE_om003F=>X00?om1@Coo`Goood50?ol003oo@@4
ool4ooom103oo@00ooeF1?ooE_oooEH0ood00?lJjP00oo@50?ol003om0@0ood0
0?odEP3oo00LjP00oo@50?ol003om0@0ood00?odEP3oo@00SAcZ003om0D0oo`0
0?od103oo@00ooAF0?om000H<NX00?ol1@?o1Oooo@D0oo`00?ol10?o1?ooo@@0
ood00?olEP?oE_oooEH0ood000DjjP02o`D5o_l30?l00?ko0@Goo002o`@4o_l3
0?l00?ko0@Coo@02oeIFo_l30?l00?ko0EKoo@00/bWZ0?koo@00oo`00Oooo03n
ood00?ol007oood0o_om003oo001oool00B`002W0Zl0A?d00?on003oo000ooh0
0?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh0
0?om000WA?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on
00;o003nood0o_l2003ooP02o`00o_om001TC?d01Ooknooo0?ko1@3ooo_kood0
1OoCdooo0?ko1@3oom?Coo`01OmUIOoo0?ko1@3oofEUood01Ooknooo0?ko1@3o
oo_kood00<U2o@00oogk1?oonooooO/0ood00?omd`Coom?ooogC0?ol003ooFD4
oomUooomI@3oo@00oogk1?oonooooO/0oo`08_d00?odn`3oo@00ooCC0?ol003o
m6D0ood00?odn`3oo00To@00ooCk0?om003om=<0oo`00?odI@3oo@00ooCk0?om
00028_d00?odn`3oo@00ooCC0?ol003om6D0ood00?odn`3oo010o@00oock0ook
ooomn`3oo@00oocC0ooCooomd`3oo000ooaU0omUooomI@3oo@00oock0ookooom
n`3oo@00M4cm00;ono_no`<0o`00o_l1noom00;odm?no`<0o`00o_l1dool00;o
IFGno`<0o`00o_l1IOom00;ono_no`<0o`00o_l1noom000/>?d0o_om003oo001
ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom003F1;00
0?l2[`0do@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`0
0?on003ojP001SCm0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2
003ooP02o`00o_oZ002Q>_d01Oo3`ooo0?ko1@3ool?3ood01Oodm?oo0?ko1@3o
ooCdoo`01On6Q_oo0?ko1@3oohJ6onX003`do@00oog31?oo`ooooL<0ood00?om
m0CoooCooogd0?ol003ooHH4oon6ooomQP3ojP00XQ[m003om<<0ood00?odm03o
o000ooB60?oY01cm003om<<0ood00?odm03oo000ooB60?oZ000O6_d00?od``3o
o@00ooCd0?ol003om8H0onT0<Od00?ol``?o`ooooL<0ood00?olm0?om?oooO@0
oo`00?olQP?oQ_oooHH0onX003/jo@02ol?3o_l30?l00?ko0L?oo@02ooCdo_l3
0?l00?ko0OCoo002ohJ6o_l30?l00?ko0HKojP00CBWm0?koo@00oo`00Oooo@3n
ood00?ol007ooo`0o_om003oo001oooY00:_00B`003o=?d00?on003oo000ooh0
0?oY003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood005Pdo@3no`800?on
00;o003nonT0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00GC[m00Go
9RKoo`3no`D0oolV9_oY00GoJV[oo`3no`D0oomZJ_om00Go9RKoo`3no`D0oolV
9_om0033<_d00?om9PCoobKooodV0?oY003ooFX4oomZooomJP3oo@00oodV1?oo
9_oooBH0oo`07?d00?od9P3oj@00ooAZ0?om003om2H0ood001HJo@00oo@V0?oY
003om6X0ood00?od9P3oo00Lo@00oo@V0?oY003om6X0ood00?od9P3oo@00CS7m
003oo2H3obKooodV0?oY003oo6X3of[oooeZ0?om003oo2H3obKooodV0?om001^
>_d00_lV9_ko0`3o003no`4VonT00_mZJ_ko0`3o003no`5Zood00_lV9_ko0`3o
003no`4Vood00<TYo@3nood00?ol007oonT0o_om003oo001ooom0?koo@00oo`0
0Oooo002[`04/000:D;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`0
0?on003oo000ooh00?om003ooP00oo`00?on003oo014o@3no`800?on00;o003n
ood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003n
ood002E<o@05odI6ool0o_l50?ooATKoo@05oeIFool0o_l50?ooEUKoo005ojFU
ool0o_l50?ooYJGoo@05oa@Dool0o_l50?oo51Coo@00;4Cm003ooDH4oom6ooom
AP3oo@00ooeF1?ooE_oooEH0oo`00?omY@CoojGooofU0?om003ooA@4oolDooom
503oo@00eRCm003om4H0ood00?odEP3oo000ooBU0?om003om1@0ood00?lRo@00
ooA60?om003om5H0oo`00?odY@3oo@00oo@D0?ol02Cm003om4H0ood00?odEP3o
o000ooBU0?om003om1@0ood00850o@00ooa60om6ooomAP3oo@00ooaF0omFooom
EP3oo000oobU0onUooomY@3oo@00oo`D0olDooom503oo@00>Tcm00;oATKno`<0
o`00o_l1A_om00;oEUKno`<0o`00o_l1E_ol00;oYJGno`<0o`00o_l1YOom00;o
51Cno`<0o`00o_l15?om0024>?d0o_om003oo001ooom0?koo@00oo`00Oooo03n
ood00?ol007oood0o_om003oo001ooom00330Zl01;0009/bo@00ooh00?ol003o
oP00ood00?on003oo000ooh00?oY003ooP00oo`00?on003oo00do@3no`800?on
00;o003nood0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo@0053[m00Go
aLGoo`3no`D0ooo5aOom00GoJ6Soo`3no`D0oomXJ?oY00Go@d?oo`3no`D0oom3
@oom001E=?d00?oma@CoolGooog50?om003ooFP4oomXooomJ03oj@00ooe31?oo
@ooooD<0ood00<TJo@00ooC50?om003om6P0onT00?od@`3oo00Jo@00ooC50?om
003om6P0onT00?od@`3oo00Lo@00ooC50?om003om6P0onT00?od@`3oo@00?2om
003oo<D3olGooog50?om003oo6P3ofSoooeX0?oY003oo4<3od?oooe30?ol03[m
00;oaLGno`<0o`00o_l1aOom00;oJ6Sno`<0o`00o_l1J?oY00;o@d?no`<0o`00
o_l1@oom003=:od0o_om003oo001ooom0?koo@00oo`00Oooj@3nood00?ol007o
ood002`4/000ePB`003o@_d00?on003oo000ooh00?om003ooP00oo`00?on003o
o000ooh00?ol003ooP00ood00?on003oo000ooh00?ol04Cm0?ko0P00ooh00_l0
0?koo@3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l0
0?koo@00nTcm00GoUYKoo`3no`D0oonFU_om00GoE5Coo`3no`D0oomDE?ol00Go
5AGoo`3no`D0oolE5Oom00Go10Coo`3no`D0ool41?om003]A?d00?omUPCooiKo
oofF0?om003ooE@4oomDooomE03oo000oodE1?oo5OoooAD0ood00?om10Coo`Co
ood40?om002G9?d00?odUP3oo@00ooAD0?ol003om1D0ood00?od103oo@00XR;m
003om9H0ood00?odE03oo000oo@E0?om003om0@0oo`09?d00?odUP3oo@00ooAD
0?ol003om1D0ood00?od103oo@004ckm003oo9H3oiKooofF0?om003oo5@3oeCo
ooeD0?ol003oo1D3oaGooodE0?om003oo0@3o`Coood40?ol04cm00;oUYKno`<0
o`00o_l1U_om00;oE5Cno`<0o`00o_l1E?ol00;o5AGno`<0o`00o_l15Oom00;o
10Cno`<0o`00o_l11?om000W>?d0o_om003oo001ooom0?koo@00oo`00Oooo03n
ood00?ol007oood0o_om003oo001ooom002g1;000<T2[`0bo@00ooh00?ol003o
oP00onT00?on003oo000ooh00?om003ooP00oo`00?on003oo00bo@3no`800?on
00;o003nonT0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo00jo@05ofIV
ool0o_l50?ooIVKoj@05odI6ool0o_l50?ooATKoo@05o`@4ool0o_l50?oo10Co
o@00ocCm003ooFH4oomVooomIP3oj@00ooe61?ooA_oooDH0ood00?om10Coo`Co
ood40?om00057?d00?odIP3oj@00ooA60?om003om0@0ood0004Lo@00ooAV0?oY
003om4H0ood00?od103oo@00@acm003om6H0onT00?odAP3oo@00oo@40?om0002
<Od00?olIP?oI_oooFH0onT00?olAP?oA_oooDH0ood00?ol10?o1?ooo@@0ood0
038ho@02ofIVo_l30?l00?ko0FKoj@02odI6o_l30?l00?ko0DKoo@02o`@4o_l3
0?l00?ko0@Coo00Yo@3nood00?ol007oonT0o_om003oo001ooom0?koo@00oo`0
0Oooo002[`02[`04/000o`:_00B`00021;0003@2[`02[`02[`04/0005@000@0:
0480<@8f0Dh0=01307d18P2f00402P1307d18P2f09R0DP000001?`1A00000000
0000B00004P0000000P00@080000002`TB`00000000T_0000?l00?ooooooo`01
ooooolc<00;oo?olZZP00ooooomVIP04=b<g8cLS00Ef9WHVMRH01[DZ]BZe:P07
m2kd;_@^00P00?olZZP02C/C>a<k4`0:NQMj5gXG00^i6[TJ^AX03?PNn1kh7P0=
003oo?ol00iEE?oloo`03jZXoocoo00@oonIVC<c017ooiVI00004_ooIVKoo`0C
oomVI/c<01@k4c/C>a<05GXGNQMj5`0F^AZi6[TJ01Oh7_PNn1h06000oocoo00I
?`<o0cl301Yn1gh7OPL06kd;_@^m2`0Lo0kl3_`>01eEE00000007ZZX0000000O
oo`00000023oo`00VIT08Ooo001VIP0Rool003<c02?oo`00000093l3?`<o0`0U
OPMn1gh702Jm2kd;_@/09o`>o0kl3P0X0o03l0?`02U2ld;c@_<0:X7gPON1m`0[
`?_0nl3k02`00000EE@0;EED001EE00^ZZP005ED02ooo000EE@0<<c<VIWoo`0a
c<bIVLc<03;<c9VIVIT0<`?`0o03l00d@_=2ld;c03F1mh7gPOL0=/3k`?_0n`0g
000005ED03P7h0OP1n00>DKTA^A6i00jQNN5ihGW03_4jlC[a>/0?000002ZZ00m
EE@00:ZX03jZZ000ZZP0?ool002ZZ010c<`c<c<c047<c3<c0000@/c<003oo`13
1n07h0OP04A6i4KTA^@0AHGWQNN5i`16a>_4jlC[04L00000ZZP0B0_@2m0;d019
B]A:e4[D04Z9f8WHRMP0BlSKb=_8f`1<00000?ol04eEE000oo`0CZZX003oo01?
oo`00?ol052IVLc<VIT0DIVIc<aVIP1BVIW<c3<c05<;d0_@2m00E4[DB]A:e01E
RMR9f8WH05K8flSKb=/0E`00003oo01H3l0?`0o005U>a4k4C/@0FXg8SLR=b01K
c<c<c<c<05`005ED0000GEEDEE@0001NZZQEE00005ooo5ED0000H9VI<c?oo`1Q
VITc<lc<06:IVC<cVIT0H`o03l0?`01TC/A>a4k406F=b8g8SLP0I/c<c<c<c01W
001EE00006PC/A>a4k40JE:dD[AB]01ZTKRA^96h06_@_=2ld;`0K000EEAEE01]
EEAEE5ED06jZZ5EDEE@0KoolEEAEE01`IVKooc<c075VI_oo0000LVIVc<coo`1c
4k4C/A>a07AB]5:dD[@0MI6hTKRA^01fd;c@_=2l07L005EDEE@0N1NQ5j4GX@1i
EZEFYEJU07ZEZ9FXUJP0NmB/e:cD[01l001EE:ZX07eEE5EDZZP0OZZXEEBZZ01o
ooaEE:ZX081VIVIVVIT0PFIVIVIVIP22IVIVIS<c08<GXANQ5j40Q5JUEZEFY@25
UJREZ9FX08KD[=B/e:`0Q`00EEBZZ0286i4KTA^A08UJUEZEFYD0RYVIVIVIV@2;
f9cHW=RL08`005EDoo`0SEEDEECoo02>ZZQEE?ol08ooo5EDoo`0T3<cooooo`2A
<c?oolc<098c<oooVIT0Ta^A6i4KT@2DFYEJUEZE09FIVIVIVIT0U]RLf9cHW02G
001EE?ol09POPAn17h40VEj5GXENQ@2JWHVMRIf909_LS=b<g8`0W000ZZP0002M
EEBZZ00009jZZ:ZX0000WoolZZP0002P<c>IVC<c0:4c<iVI0000XS<cIVKoo`2S
7h4OPAn10:ANQEj5GXD0YIf9WHVMR@2Vg8cLS=b<0:L00:ZX0000Z2=b8g8SLP2Y
HWERMF9e0:ZQNJ5iXGT0Zn1mh7gPO@2/002ZZ5ED0:eEE:ZXEE@0[ZZXZZQEE02_
oobZZ5ED0;0c<`00VIT0/C<c001VIP2b<c<003<c0;<SLR=b8g80]69eHWERM@2e
XGVQNJ5i0;KPON1mh7d0]`00ZZQEE02h9f8WHRMR0;UVIVIVIVH0^ZEYYFVUJ@2k
i6gTKNA]0;`00:ZXZZP0_EEDZZRZZ02nZZRZZ:ZX0;ooo:ZXZZP0`000VIWoo`31
002IVLc<0<8009VIVIT0`bMR9f8WHP34IVIVIVIV0<FUJJEYYFT0a^A]i6gTK@37
002ZZ:ZX0<P[DR]B:e80bFYFJUIZEP3:ZEVYFJUI0<_XGNQMj5d0c000ZZSoo03=
EEBZZ?ol0<jZZ:ZXoo`0coolZZSoo03@000c<c<c0=4003<c0000dP00003oo`3C
:e8[DR]B0=AZEVYFJUH0eJUIZEVYF@3Fj5gXGNQM0=L00:ZXoo`0f2m2;d8_@P3I
KTI^AVi60=Z]BZe:[DX0fna=k4g/C@3L003oo0000=eEE?ol0000gZZXoo`0003O
oocoo0000>0A4@000000h@00k^h0003R003Mg@000><_@Rm2;d80i6i6KTI^AP3U
[DZ]BZe:0>K/CNa=k4d0i`00oo`0003X<c<c<c<c0>Ub=W8fLSH0j[4j/CZa>P3[
l3k`?_0n0>`00?olEE@0kEEDooaEE03^ZZSoo5ED0>ooo?olEE@0l000001gM`3a
000005EE0?800000A4@0lc<c<c<c<`3dLSIb=W8f0?Fa>[4j/CX0m_0nl3k`?P3g
003oo5ED0?Pg8cLS=b<0nGHVMRIf9P3j]BZe:[DZ0?_d;_@^m2h0o000oobZZ03m
EECoo:ZX0?jZZ?olZZP0o`00000000000001?`1A04<0O@4R0;H090:_00:_00B`
003o1;000?l4/000o@B`003n1;000044/000H`B`003k0Zl0=?d00?on003oo000
ooh00?om003ooP00oo`00?on003oj@00ooh00?ol003ooP00ood00?lbo@3no`80
0?on00;o003nood0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo00jo@05
oo_kool0o_l50?oono_oo@05ob@Tool0o_l50?oo92Coj@05okBdool0o_l50?oo
];Coo@00oc;m003ooO/4oookooomn`3oo@00oodT1?oo9?oooB@0onT00?om]0Co
okCooofd0?ol01cm003om?/0ood00?od903oj@00ooBd0?om003j6_d00?odn`3o
o@00oo@T0?oY003om;@0oo`06_d00?odn`3oo@00oo@T0?oY003om;@0oo`0;od0
0?oln`?onooooO/0ood00?ol90?o9?oooB@0onT00?ol]0?o]?oooK@0oo`0>_d0
0_oknoko0`3o003no`7kood00_lT9?ko0`3o003no`4TonT00_nd]?ko0`3o003n
o`6dood00?d[o@3nood00?ol007oood0o_om003oo001oooY0?koo@00oo`00Ooo
o@00o@:_00B`003o=>X00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00
ooh00?ol003ooP00ood00?hdjP3no`800?on00;o003noo`0o_l2003ooP02o`00
o_om0?ko0P00ooh00_l00?koo@00oc[Z00Go9bOoo`3no`D0oolW9ool00Goa/Ko
o`3no`D0ooo6a_om00GoiNGoo`3no`D0oooUiOom003m=>X00?om9`CoobOooodW
0?ol003ooLH4ooo6ooomaP3oo@00oogU1?ooiOoooND0ood0008LjP00oo@W0?ol
003om<H0ood00?odi@3oo@0011cZ003om2L0oo`00?odaP3oo@00ooCU0?om003m
7>X00?od9`3oo000ooC60?om003om>D0ood00?lajP00oo`W0olWooom9`3oo000
ooc60oo6ooomaP3oo@00oocU0ooUooomi@3oo@00oS[Z00;o9bOno`<0o`00o_l1
9ool00;oa/Kno`<0o`00o_l1a_om00;oiNGno`<0o`00o_l1iOom003n:nX0o_om
003oo001oool0?koo@00oo`00Oooo@3nood00?ol007oood00?l2[`02[`0do@00
ooh00?ol003ooP00ood00?on003oo000ooh00?oY003ooP00oo`00?on003oo@00
oc;m0?ko0P00ooh00_l00?koo@3no`800?on00;o003nonT0o_l2003ooP02o`00
o_ol03[m00GoEUKoo`3no`D0oomFE_om00Go9RKoo`3no`D0oolV9_oY00GoYZKo
o`3no`D0oonVY_om003o=?d00?omEPCooeKoooeF0?om003ooBH4oolVooom9P3o
j@00oofV1?ooY_oooJH0ood00?hLo@00ooAF0?om003om2H0onT00?odYP3oo@00
^acm003om5H0ood00?od9P3oj@00ooBV0?om002k7?d00?odEP3oo@00oo@V0?oY
003om:H0ood000<ao@00ooaF0omFooomEP3oo@00oo`V0olVooom9P3oj@00oobV
0onVooomYP3oo@00oc[m00;oEUKno`<0o`00o_l1E_om00;o9RKno`<0o`00o_l1
9_oY00;oYZKno`<0o`00o_l1Y_om003o:Od0o_om003oo001ooom0?koo@00oo`0
0Oooj@3nood00?ol007ooo`00Zl00Zl0=?d00?on003oo000ooh00?om003ooP00
oo`00?on003oo000ooh00?ol003ooP00onX00?lbo@3no`800?on00;o003nood0
o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koj@0jo@05obHVool0o_l50?oo
9RKoo@05ojJVool0o_l50?ooYZKoo005o`H6ool0o_l50?oo1PKojP00oCCm003o
oBH4oolVooom9P3oo@00oofV1?ooY_oooJH0oo`00?om1PCoo`Koood60?oZ003o
7?d00?od9P3oo@00ooBV0?ol003om0H0onX00?lLo@00oo@V0?om003om:H0oo`0
0?od1P3ojP00oQ[m003om2H0ood00?odYP3oo000oo@60?oY037m003oo2H3obKo
oodV0?om003oo:H3ojKooofV0?ol003oo0H3o`Koood60?oZ002n>_d00_lV9_ko
0`3o003no`4Vood00_nVY_ko0`3o003no`6Voo`00_l61_ko0`3o003no`46onX0
0;h[o@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00OoojP00o`B`
00050Zl0A?d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol
003ooP00ood00?on003oo000ooh00?om001ZA?d0o_l2003ooP02o`00o_om0?ko
0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_om003o
C?d01OmUIOoo0?ko1@3oofEUood01OlU9Ooo0?ko1@3oobDUoo`01OoTi?oo0?ko
1@3oonCTood01OnVY_oo0?ko1@3oojJVood00?m4o@00ooeU1?ooIOoooFD0ood0
0?om9@CoobGooodU0?ol003ooN@4oooTooomi03oo@00oofV1?ooY_oooJH0ood0
0?hTo@00ooAU0?om003om2D0oo`00?odi03oo@00ooBV0?om003o9?d00?odI@3o
o@00oo@U0?ol003om>@0ood00?odYP3oo@00ob;m003om6D0ood00?od9@3oo000
ooCT0?om003om:H0oo`0?_d00?olI@?oIOoooFD0ood00?ol9@?o9OoooBD0oo`0
0?oli0?oi?oooN@0ood00?olYP?oY_oooJH0oo`0C?d00_mUIOko0`3o003no`5U
ood00_lU9Oko0`3o003no`4Uoo`00_oTi?ko0`3o003no`7Tood00_nVY_ko0`3o
003no`6Vood0004fo@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`0
0Oooo@3nood00?ol007ooo`00Zl01;000?e4o@00ooh00?ol003ooP00ood00?on
003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood00?m2
o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?ko
o@3no`800?on00;o003noo`0C?d01OlE5Ooo0?ko1@3ooaDEood01OnEUOoo0?ko
1@3ooiFEoo`01On6Q_oo0?ko1@3oohJ6ood01Oo6a_oo0?ko1@3oolK6ood00?m4
o@00oodE1?oo5OoooAD0ood00?omU@CooiGooofE0?ol003ooHH4oon6ooomQP3o
o@00oog61?ooa_oooLH0ood00?/To@00oo@E0?om003om9D0oo`00?odQP3oo@00
ooC60?om003k8_d00?od5@3oo@00ooBE0?ol003om8H0ood00?odaP3oo00To@00
oo@E0?om003om9D0oo`00?odQP3oo@00ooC60?om003n@?d00?ol5@?o5OoooAD0
ood00?olU@?oUOoooID0oo`00?olQP?oQ_oooHH0ood00?olaP?oa_oooLH0ood0
0?m<o@02oaDEo_l30?l00?ko0AGoo@02oiFEo_l30?l00?ko0IGoo002ohJ6o_l3
0?l00?ko0HKoo@02olK6o_l30?l00?ko0LKoo@00ocSm0?koo@00oo`00Oooo@3n
ood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00o0:_00B`003n
A?d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003ooP00
ood00?on003oo000ooh00?om003nA?d0o_l2003ooP02o`00o_om0?ko0P00ooh0
0_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_om003oB_d01Oo6
a_oo0?ko1@3oolK6ood01OmUIOoo0?ko1@3oofEUoo`01OnVY_oo0?ko1@3oojJV
ood01OoTi?oo0?ko1@3oonCToo`0@_d00?omaPCoolKooog60?om003ooFD4oomU
ooomI@3oo000oofV1?ooY_oooJH0ood00?omi0CoonCooogT0?ol02Cm003om<H0
ood00?odI@3oo000ooBV0?om003om>@0ood00?lRo@00ooC60?om003om6D0oo`0
0?odYP3oo@00ooCT0?ol02Cm003om<H0ood00?odI@3oo000ooBV0?om003om>@0
ood00?m0o@00ooc60oo6ooomaP3oo@00ooaU0omUooomI@3oo000oobV0onVooom
YP3oo@00oocT0ooTooomi03oo@00odcm00;oa/Kno`<0o`00o_l1a_om00;oIFGn
o`<0o`00o_l1IOol00;oYZKno`<0o`00o_l1Y_om00;oi>Cno`<0o`00o_l1i?om
003o>?d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om
003oo001ooom001;1;000?l2[`0bo@00ooh00?ol003ooP00ood00?on003oo000
ooh00?oY003ooP00oo`00?on003oo00do@3no`800?on00;o003nood0o_l2003o
oP02o`00o_oY0?ko0P00ooh00_l00?koo@000S;m0?co003no`00o?om00Gono_o
o`3no`D0oooknooY00Goi^Koo`3no`D0oooVi_ol02Sm0?;oo@00oogk1?oonooo
oO/0onT00?omiPCoonKooogV0?om003o6?d0l_om003om?/0onT00?odiP3oo@00
J1Km0?;oo@00ooCk0?oY003om>H0oo`05_d0l_om003om?/0onT00?odiP3oo00V
o@3bood00?oln`?onooooO/0onT00?oliP?oi_oooNH0ood00?hao@3ko`<0o`00
o?om00;ono_no`<0o`00o_l1nooY00;oi^Kno`<0o`00o_l1i_ol02_m0?koo@00
oo`00Oooo@3nood00?ol007oonT0o_om003oo001ooom00051;000?d4/000m4;m
003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om
003ooP00oo`00?on003oo012o@3no`800?on00;o003nood0o_l2003ooP02o`00
o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0C?d01OnDU?oo0?ko
1@3ooiBDood01Om6A_oo0?ko1@3oodI6oo`01OnFU_oo0?ko1@3ooiJFood01Ol6
1_oo0?ko1@3oo`H6ood00?m4o@00oofD1?ooU?oooI@0ood00?omAPCoodKoooe6
0?ol003ooIH4oonFooomUP3oo@00ood61?oo1_ooo@H0ood00?lTo@00ooBD0?om
003om4H0oo`00?odUP3oo@00oo@60?om003Z8_d00?odU03oo@00ooA60?ol003o
m9H0ood00?od1P3oo00To@00ooBD0?om003om4H0oo`00?odUP3oo@00oo@60?om
003o@?d00?olU0?oU?oooI@0ood00?olAP?oA_oooDH0oo`00?olUP?oU_oooIH0
ood00?ol1P?o1_ooo@H0ood006Q:o@02oiBDo_l30?l00?ko0ICoo@02odI6o_l3
0?l00?ko0DKoo002oiJFo_l30?l00?ko0IKoo@02o`H6o_l30?l00?ko0@Koo00f
o@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol
007ooo`00Zl00Zl0<_d00?on003oo000ooh00?om003ooP00oo`00?on003oj@00
ooh00?ol003ooP00oo`0<_d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?ko
j@3no`800?on00;o003noo`0>?d01OnVY_oo0?ko1@3oojJVood01Oo6a_oo0?ko
1@3oolK6onT01Ooknooo0?ko1@3ooo_koo`0<_d00?omYPCoojKooofV0?om003o
oLH4ooo6ooomaP3oj@00oogk1?oonooooO/0oo`06_d00?odYP3oo@00ooC60?oY
003om?/0oo`06_d00?odYP3oo@00ooC60?oY003om?/0oo`06_d00?odYP3oo@00
ooC60?oY003om?/0oo`0;od00?olYP?oY_oooJH0ood00?olaP?oa_oooLH0onT0
0?oln`?onooooO/0oo`0>?d00_nVY_ko0`3o003no`6Vood00_o6a_ko0`3o003n
o`76onT00_oknoko0`3o003no`7koo`0:Od0o_om003oo001ooom0?koo@00oo`0
0Oooj@3nood00?ol007ooo`00Zl00Zl08_d00?on003oo000ooh00?om003ooP00
oo`00?on003oe@0Ro@3no`800?on00;o003nood0o_l2003ooP02o`00o_oE02Km
00Goe=Coo`3no`D0oooDe?om00GoIVKoo`3no`D0oomVI_oE02;m003ooM@4oooD
ooome03oo@00ooeV1?ooI_oooFH0omD04_d00?ode03oo@00ooAV0?oE01;m003o
m=@0ood00?odIP3oe@0Bo@00ooCD0?om003om6H0omD08?d00?ole0?oe?oooM@0
ood00?olIP?oI_oooFH0omD09_d00_oDe?ko0`3o003no`7Dood00_mVI_ko0`3o
003no`5VomD07?d0o_om003oo001ooom0?koo@00oo`00Oooe@02[`02[`12o@00
ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00
ooh00?ol003ooP00oo`0@_d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?ko
o03no`800?on00;o003nood0o_l2003ooP02o`00o_ol04[m00Go9BGoo`3no`D0
oolU9Oom00Go9BGoo`3no`D0oolU9Ool00GoIFGoo`3no`D0oomUIOom00Goi>Co
o`3no`D0oooTi?ol04;m003ooBD4oolUooom9@3oo@00oodU1?oo9OoooBD0oo`0
0?omI@CoofGoooeU0?om003ooN@4oooTooomi03oo00Ro@00oo@U0?om003om2D0
oo`00?odI@3oo@00ooCT0?ol02;m003om2D0ood00?od9@3oo000ooAU0?om003o
m>@0oo`08_d00?od9@3oo@00oo@U0?ol003om6D0ood00?odi03oo00no@00oo`U
0olUooom9@3oo@00oo`U0olUooom9@3oo000ooaU0omUooomI@3oo@00oocT0ooT
ooomi03oo01:o@02obDUo_l30?l00?ko0BGoo@02obDUo_l30?l00?ko0BGoo002
ofEUo_l30?l00?ko0FGoo@02onCTo_l30?l00?ko0NCoo00fo@3nood00?ol007o
ood0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007ooo`00Zl00Zl0
0Zl0<_d00?on003oo000ooh00?oY003ooP00oo`00?on003oo@00ooh00?ol003o
oP00oo`0<_d0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo@3no`800?on
00;o003noo`0>?d01Oo6a_oo0?ko1@3oolK6onT01OlV9_oo0?ko1@3oobHVood0
1OoEeOoo0?ko1@3oomGEoo`0<_d00?omaPCoolKooog60?oY003ooBH4oolVooom
9P3oo@00oogE1?ooeOoooMD0oo`06_d00?odaP3oj@00oo@V0?om003om=D0oo`0
6_d00?odaP3oj@00oo@V0?om003om=D0oo`0;od00?olaP?oa_oooLH0onT00?ol
9P?o9_oooBH0ood00?ole@?oeOoooMD0oo`0>?d00_o6a_ko0`3o003no`76onT0
0_lV9_ko0`3o003no`4Vood00_oEeOko0`3o003no`7Eoo`0:Od0o_om003oo001
oooY0?koo@00oo`00Oooo@3nood00?ol007ooo`00Zl00Zl00Zl08_d00?on003o
o000ooh00?om003ooP00oo`00?on003oe@0Ro@3no`800?on00;o003nood0o_l2
003ooP02o`00o_oE02Km00GoIVKoo`3no`D0oomVI_om00GoUIGoo`3no`D0oonE
UOoE02;m003ooFH4oomVooomIP3oo@00oofE1?ooUOoooID0omD04_d00?odIP3o
o@00ooBE0?oE01;m003om6H0ood00?odU@3oe@0Bo@00ooAV0?om003om9D0omD0
8?d00?olIP?oI_oooFH0ood00?olU@?oUOoooID0omD09_d00_mVI_ko0`3o003n
o`5Vood00_nEUOko0`3o003no`6EomD07?d0o_om003oo001ooom0?koo@00oo`0
0Oooe@02[`02[`12o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003o
oP00oo`00?on003oo@00ooh00?ol003ooP00oo`0@_d0o_l2003ooP02o`00o_om
0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_ol
04Cm0?co003no`00o?om00Goe=Coo`3no`D0oooDe?ol00Gono_oo`3no`D0oook
noom00Go1PKoo`3no`D0ool61_ol03Km0?;oo@00oogD1?ooe?oooM@0oo`00?om
n`Cooo_ooogk0?om003oo@H4ool6ooom1P3oo00No@3bood00?ode03oo000ooCk
0?om003om0H0oo`07_d0l_om003om=@0oo`00?odn`3oo@00oo@60?ol01km0?;o
o@00ooCD0?ol003om?/0ood00?od1P3oo00co@3bood00?ole0?oe?oooM@0oo`0
0?oln`?onooooO/0ood00?ol1P?o1_ooo@H0oo`0@od0nol30?l00?coo@02omCD
o_l30?l00?ko0MCoo002oo_ko_l30?l00?ko0O_oo@02o`H6o_l30?l00?ko0@Ko
o00fo@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood0
0?ol007ooo`00Zl00Zl04]H00?on003oo000ooh00?oY01;F0?ko0P00ooh00_l0
0?koj@0DeP05okjnool0o_l50?oo_[koj@0BeP00oofn1?oo__oooKh0onT02]H0
0?od_P3oj@0:eP00ooBn0?oY00[F003om;h0onT04MH00?ol_P?o__oooKh0onT0
5=H00_nn__ko0`3o003no`6nonT03mH0o_om003oo001oooY00:_00:_03;m003o
oP00oo`00?on003oj@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol03;m
0?ko0P00ooh00_l00?koj@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol
03Sm00GoJV[oo`3no`D0oomZJ_oY00GoI6Coo`3no`D0oomTI?om00Goe]Koo`3n
o`D0oooFe_ol03;m003ooFX4oomZooomJP3oj@00ooeT1?ooI?oooF@0ood00?om
ePCoomKooogF0?ol01[m003om6X0onT00?odI03oo@00ooCF0?ol01[m003om6X0
onT00?odI03oo@00ooCF0?ol01[m003om6X0onT00?odI03oo@00ooCF0?ol02om
003oo6X3of[oooeZ0?oY003oo6@3ofCoooeT0?om003oo=H3omKooogF0?ol03Sm
00;oJV[no`<0o`00o_l1J_oY00;oI6Cno`<0o`00o_l1I?om00;oe]Kno`<0o`00
o_l1e_ol02Wm0?koo@00oo`00Oooj@3nood00?ol007oood0o_om003oo001oool
00:_00:_04;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003o
o000ooh00?om003ooP00oo`00?on003oo012o@3no`800?on00;o003nood0o_l2
003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0B_d0
1OnDU?oo0?ko1@3ooiBDood01OnVY_oo0?ko1@3oojJVoo`01OmTI?oo0?ko1@3o
ofATood01OmFE_oo0?ko1@3ooeIFoo`0@_d00?omU0CooiCooofD0?om003ooJH4
oonVooomYP3oo000ooeT1?ooI?oooF@0ood00?omEPCooeKoooeF0?ol02;m003o
m9@0ood00?odYP3oo000ooAT0?om003om5H0oo`08_d00?odU03oo@00ooBV0?ol
003om6@0ood00?odEP3oo00Ro@00ooBD0?om003om:H0oo`00?odI03oo@00ooAF
0?ol03km003oo9@3oiCooofD0?om003oo:H3ojKooofV0?ol003oo6@3ofCoooeT
0?om003oo5H3oeKoooeF0?ol04[m00;oU9Cno`<0o`00o_l1U?om00;oYZKno`<0
o`00o_l1Y_ol00;oI6Cno`<0o`00o_l1I?om00;oEUKno`<0o`00o_l1E_ol03Km
0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`0
0Oooo002[`02[`12o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003o
oP00oo`00?on003oo@00ooh00?ol003ooP00oo`0@_d0o_l2003ooP02o`00o_om
0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_ol
04[m00Gono_oo`3no`D0oooknoom00GoEUKoo`3no`D0oomFE_ol00GoIFGoo`3n
o`D0oomUIOom00Gono_oo`3no`D0oooknool04;m003ooO/4oookooomn`3oo@00
ooeF1?ooE_oooEH0oo`00?omI@CoofGoooeU0?om003ooO/4oookooomn`3oo00R
o@00ooCk0?om003om5H0oo`00?odI@3oo@00ooCk0?ol02;m003om?/0ood00?od
EP3oo000ooAU0?om003om?/0oo`08_d00?odn`3oo@00ooAF0?ol003om6D0ood0
0?odn`3oo00no@00oock0ookooomn`3oo@00ooaF0omFooomEP3oo000ooaU0omU
ooomI@3oo@00oock0ookooomn`3oo01:o@02oo_ko_l30?l00?ko0O_oo@02oeIF
o_l30?l00?ko0EKoo002ofEUo_l30?l00?ko0FGoo@02oo_ko_l30?l00?ko0O_o
o00fo@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood0
0?ol007ooo`00Zl00Zl0<_d00?on003oo000ooh00?om003ooP00oo`00?on003o
o000ooh00?ol003ooP00onT0<_d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l0
0?koo03no`800?on00;o003nonT0>?d01OlE5Ooo0?ko1@3ooaDEood01Onn__oo
0?ko1@3ookjnoo`01On6Q_oo0?ko1@3oohJ6onT0<_d00?om5@CooaGooodE0?om
003ooKh4oonnooom_P3oo000oof61?ooQ_oooHH0onT06_d00?od5@3oo@00ooBn
0?ol003om8H0onT06_d00?od5@3oo@00ooBn0?ol003om8H0onT06_d00?od5@3o
o@00ooBn0?ol003om8H0onT0;od00?ol5@?o5OoooAD0ood00?ol_P?o__oooKh0
oo`00?olQP?oQ_oooHH0onT0>?d00_lE5Oko0`3o003no`4Eood00_nn__ko0`3o
003no`6noo`00_n6Q_ko0`3o003no`66onT0:Od0o_om003oo001ooom0?koo@00
oo`00Oooo03nood00?ol007oonT00Zl00Zl0@_d00?on003oo000ooh00?om003o
oP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?ol04;m
0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2003ooP02o`00o_om
0?ko0P00ooh00_l00?koo01:o@05ofEUool0o_l50?ooIFGoo@05omGEool0o_l5
0?ooeMGoo005okjnool0o_l50?oo_[koo@05obHVool0o_l50?oo9RKoo012o@00
ooeU1?ooIOoooFD0ood00?ome@CoomGooogE0?ol003ooKh4oonnooom_P3oo@00
oodV1?oo9_oooBH0oo`08_d00?odI@3oo@00ooCE0?ol003om;h0ood00?od9P3o
o00Ro@00ooAU0?om003om=D0oo`00?od_P3oo@00oo@V0?ol02;m003om6D0ood0
0?ode@3oo000ooBn0?om003om2H0oo`0?_d00?olI@?oIOoooFD0ood00?ole@?o
eOoooMD0oo`00?ol_P?o__oooKh0ood00?ol9P?o9_oooBH0oo`0B_d00_mUIOko
0`3o003no`5Uood00_oEeOko0`3o003no`7Eoo`00_nn__ko0`3o003no`6nood0
0_lV9_ko0`3o003no`4Voo`0=_d0o_om003oo001ooom0?koo@00oo`00Oooo03n
ood00?ol007oood0o_om003oo001oool00:_00:_03;m003ooP00oo`00?on003o
o@00ooh00?ol003ooP00oo`00?on003oo000ooh00?oY03;m0?ko0P00ooh00_l0
0?koo@3no`800?on00;o003noo`0o_l2003ooP02o`00o_oY03Sm00Gono_oo`3n
o`D0oooknoom00GoEUKoo`3no`D0oomFE_ol00GoEUKoo`3no`D0oomFE_oY03;m
003ooO/4oookooomn`3oo@00ooeF1?ooE_oooEH0oo`00?omEPCooeKoooeF0?oY
01[m003om?/0ood00?odEP3oo000ooAF0?oY01[m003om?/0ood00?odEP3oo000
ooAF0?oY01[m003om?/0ood00?odEP3oo000ooAF0?oY02om003oo?/3oo_ooogk
0?om003oo5H3oeKoooeF0?ol003oo5H3oeKoooeF0?oY03Sm00;ono_no`<0o`00
o_l1noom00;oEUKno`<0o`00o_l1E_ol00;oEUKno`<0o`00o_l1E_oY02Wm0?ko
o@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001oooY00:_00:_04;m003o
oP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003o
oP00oo`00?on003oo012o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol
0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0B_d01Oo5aOoo0?ko1@3o
olG5ood01OmXJ?oo0?ko1@3oofQXoo`01Oodm?oo0?ko1@3oooCdood01OmFE_oo
0?ko1@3ooeIFoo`0@_d00?oma@CoolGooog50?om003ooFP4oomXooomJ03oo000
oogd1?oom?oooO@0ood00?omEPCooeKoooeF0?ol02;m003om<D0ood00?odJ03o
o000ooCd0?om003om5H0oo`08_d00?oda@3oo@00ooAX0?ol003om?@0ood00?od
EP3oo00Ro@00ooC50?om003om6P0oo`00?odm03oo@00ooAF0?ol03km003oo<D3
olGooog50?om003oo6P3ofSoooeX0?ol003oo?@3ooCooogd0?om003oo5H3oeKo
ooeF0?ol04[m00;oaLGno`<0o`00o_l1aOom00;oJ6Sno`<0o`00o_l1J?ol00;o
m?Cno`<0o`00o_l1m?om00;oEUKno`<0o`00o_l1E_ol03Km0?koo@00oo`00Ooo
o@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo002[`02[`12
o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on003o
o@00ooh00?ol003ooP00oo`0@_d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l0
0?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_ol04[m00GoUYKoo`3n
o`D0oonFU_om00Goi>Coo`3no`D0oooTi?ol00Go5AGoo`3no`D0oolE5Oom00Go
I6Coo`3no`D0oomTI?ol04;m003ooIH4oonFooomUP3oo@00oogT1?ooi?oooN@0
oo`00?om5@CooaGooodE0?om003ooF@4oomTooomI03oo00Ro@00ooBF0?om003o
m>@0oo`00?od5@3oo@00ooAT0?ol02;m003om9H0ood00?odi03oo000oo@E0?om
003om6@0oo`08_d00?odUP3oo@00ooCT0?ol003om1D0ood00?odI03oo00no@00
oobF0onFooomUP3oo@00oocT0ooTooomi03oo000oo`E0olEooom5@3oo@00ooaT
0omTooomI03oo01:o@02oiJFo_l30?l00?ko0IKoo@02onCTo_l30?l00?ko0NCo
o002oaDEo_l30?l00?ko0AGoo@02ofATo_l30?l00?ko0FCoo00fo@3nood00?ol
007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007ooo`00Zl0
0Zl08_d00?on003oo000ooh00?oY003ooP00oo`00?on003oj@0Ro@3no`800?on
00;o003nonT0o_l2003ooP02o`00o_oY02Km00GoIVKoo`3no`D0oomVI_oY00Go
ATKoo`3no`D0oom6A_oY02;m003ooFH4oomVooomIP3oj@00ooe61?ooA_oooDH0
onT04_d00?odIP3oj@00ooA60?oY01;m003om6H0onT00?odAP3oj@0Bo@00ooAV
0?oY003om4H0onT08?d00?olIP?oI_oooFH0onT00?olAP?oA_oooDH0onT09_d0
0_mVI_ko0`3o003no`5VonT00_m6A_ko0`3o003no`56onT07?d0o_om003oo001
oooY0?koo@00oo`00Oooj@02[`02[`02[`02[`02[`02[`02[`02[`02[`02[`00
00402P120342=P5>03@0@`3;0B810`0100X0@`3;0B810`2HP58000000Cl0D@00
0000000004P0001800000008004020000000/94H000000009;d0003o003ooooo
ool00Oooooo<c002oocoo:ZX00?oooooIVH013LS=b<g8`05MRIf9WHV00Je:[DZ
]BX01o@^m2kd;P08003oo:ZX00Tk4c/C>a<02WXGNQMj5`0;^AZi6[TJ00ch7_PN
n1h03@00oocoo00>EECoo?ol00nZZ?oloo`04?ooVITc<`0AoonIV@0001;oofIV
ool04oooIVK<c00D>a<k4c/C01Ej5gXGNQL05[TJ^AZi6P0Gn1kh7_PN01P00?ol
oo`06Cl3?`<o0`0JOPMn1gh701^m2kd;_@/07?`>o0kl3P0MEE@0000001jZZ000
00007ool0000000Pool009VI027oo`00IVH08_oo000c<`0Sool0000002@o0cl3
?`<09Gh7OPMn1`0V_@^m2kd;02Ol3_`>o0h0:0?`0o03l00Y@_=2ld;c02Z1mh7g
POL0:l3k`?_0n`0/000005ED02eEE000EE@0;ZZX001EE00_oo`005ED033<c9VI
ool0<Lc<VIW<c00bc<bIVIVI03<3l0?`0o00=4;c@_=2l`0ePON1mh7g03K0nl3k
`?/0=`00001EE00h1n07h0OP03U6i4KTA^@0>XGWQNN5i`0ka>_4jlC[03`00000
ZZP0?EED002ZZ00nZZP00:ZX03ooo000ZZP0@<c<<c<c<`11c<`c<`0004;<c000
ool0@`OP1n07h014A^A6i4KT04F5ihGWQNL0A/C[a>_4j`1700000:ZX04P;d0_@
2m00BD[DB]A:e01:RMR9f8WH04_8flSKb=/0C000003oo01=EE@00?ol04jZZ000
oo`0Cool003oo01@VIW<c9VI056IVLc<IVH0DYVIc<`c<`1C2m0;d0_@05A:e4[D
B]@0EHWHRMR9f01Fb=_8flSK05L00000oo`0F0o03l0?`01IC/A>a4k405Z=b8g8
SLP0Flc<c<c<c01L001EE00005eEE5ED0000GZZXEE@0001OooaEE000062IVC<c
ool0HIVI<c?<c01RVITc<iVI06<?`0o03l00I4k4C/A>a01USLR=b8g806K<c<c<
c<`0I`00EE@0001X4k4C/A>a06UB]5:dD[@0JY6hTKRA^01[d;c@_=2l06`005ED
EE@0KEEDEEAEE01^ZZQEE5ED06ooo5EDEE@0L6IVoolc<`1aIVKoo`00079VI/c<
ool0La>a4k4C/@1dD[AB]5:d07FA^96hTKP0M]2ld;c@_01g001EE5ED07PGXANQ
5j40NEJUEZEFY@1jUJREZ9FX07_D[=B/e:`0O000EEBZZ01mEEAEE:ZX07jZZ5ED
ZZP0OoolEEBZZ020IVIVIYVI085VIVIVIVH0PVIVIVHc<`235j4GXANQ08AFYEJU
EZD0QIFXUJREZ026e:cD[=B/08L005EDZZP0R1^A6i4KT@29FYEJUEZE08ZIVIVI
VIT0RmRLf9cHW02<001EE?ol08eEE5EDoo`0SZZXEECoo02?ooaEE?ol090c<ooo
ool0TC<cooo<c02B<c?ooiVI09<KTA^A6i40U5ZEFYEJU@2EVIVIVIVI09KHW=RL
f9`0U`00EECoo02H7h4OPAn109UNQEj5GXD0VYf9WHVMR@2Kg8cLS=b<09`00:ZX
0000WEEDZZP0002NZZRZZ00009ooo:ZX0000X3<cVITc<`2Q<c>IV@000:8c<fIV
ool0Xan17h4OP@2TGXENQEj50:FMRIf9WHT0Y]b<g8cLS02W002ZZ0000:PSLR=b
8g80ZF9eHWERM@2ZXGVQNJ5i0:_PON1mh7d0[000ZZQEE02]EEBZZ5ED0:jZZ:ZX
EE@0[oolZZQEE02`<c<009VI0;4c<`00IVH0/S<c000c<`2c8g8SLR=b0;ARMF9e
HWD0]J5iXGVQN@2fh7gPON1m0;L00:ZXEE@0^2MR9f8WHP2iIVIVIVIV0;ZUJJEY
YFT0^nA]i6gTK@2l002ZZ:ZX0;eEE:ZXZZP0_ZZXZZRZZ02ooobZZ:ZX0<0009VI
ool0`@00VIW<c032002IVIVI0<<WHRMR9f80a6IVIVIVIP35YFVUJJEY0<KTKNA]
i6d0a`00ZZRZZ038:e8[DR]B0<UZEVYFJUH0bZUIZEVYF@3;j5gXGNQM0<`00:ZX
oo`0cEEDZZSoo03>ZZRZZ?ol0<ooo:ZXoo`0d000<c<c<`3A000c<`000=800000
ool0db]B:e8[DP3DJUIZEVYF0=FYFJUIZET0e^QMj5gXG@3G002ZZ?ol0=P_@Rm2
;d80fFi6KTI^AP3J[DZ]BZe:0=_/CNa=k4d0g000oo`0003MEECoo0000=jZZ?ol
0000gooloo`0003P4A4000000>400>k^0000hP00gMd0003S;d8_@Rm20>A^AVi6
KTH0iJe:[DZ]BP3Vk4g/CNa=0>L00?ol0000j3<c<c<c<`3YLSIb=W8f0>Za>[4j
/CX0jo0nl3k`?P3/003oo5ED0>eEE?olEE@0kZZXooaEE03_oocoo5ED0?000000
MgL0l@00001EE@3b000004A40?<c<c<c<c<0m78fLSIb=P3e/CZa>[4j0?K`?_0n
l3h0m`00ooaEE03h=b<g8cLS0?Uf9WHVMRH0n[DZ]BZe:P3km2kd;_@^0?`00?ol
ZZP0oEEDoobZZ03nZZSoo:ZX0?l00000000000000Cl0D@130</18P4302@4/000
H@B`000P1;0003T4/000=`B`000P1;0003D4/000;PB`001R1;0003P4/000HCCm
003ooP00oo`00?on003oj@00ooh00?ol003ooP00ood00?on003oo000ooh00?om
001X=?d0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo@3no`800?on00;o
003nood0030jo@05oo_kool0o_l50?oono_oj@05onCTool0o_l50?ooi>Coo@05
oo_kool0o_l50?oono_oo@00;SCm003ooO/4oookooomn`3oj@00oogT1?ooi?oo
oN@0ood00?omn`Cooo_ooogk0?om000=7?d00?odn`3oj@00ooCT0?om003om?/0
ood000dLo@00ooCk0?oY003om>@0ood00?odn`3oo@00C1cm003om?/0onT00?od
i03oo@00ooCk0?om000P<Od00?oln`?onooooO/0onT00?oli0?oi?oooN@0ood0
0?oln`?onooooO/0ood007<jo@02oo_ko_l30?l00?ko0O_oj@02onCTo_l30?l0
0?ko0NCoo@02oo_ko_l30?l00?ko0O_oo@00>B_m0?koo@00oo`00Oooj@3nood0
0?ol007oood0o_om003oo001ooom001C1;000304/000LcCZ003ooP00oo`00?on
003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?om000P=>X0o_l2003o
oP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003nood003DjjP05
obLWool0o_l50?oo9bOoo005olK6ool0o_l50?ooa/Koo@05oo_kool0o_l50?oo
no_oo@00=3CZ003ooBL4oolWooom9`3oo000oog61?ooa_oooLH0ood00?omn`Co
oo_ooogk0?om000c7>X00?od9`3oo000ooC60?om003om?/0ood003TLjP00oo@W
0?ol003om<H0ood00?odn`3oo@0081cZ003om2L0oo`00?odaP3oo@00ooCk0?om
000h<NX00?ol9`?o9ooooBL0oo`00?olaP?oa_oooLH0ood00?oln`?onooooO/0
ood006HjjP02obLWo_l30?l00?ko0BOoo002olK6o_l30?l00?ko0LKoo@02oo_k
o_l30?l00?ko0O_oo@0082_Z0?koo@00oo`00Oooo03nood00?ol007oood0o_om
003oo001ooom000=1;0006P4/000<4Cm003ooP00oo`00?on003oo@00ooh00?ol
003ooP00oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo@00ITCm0?ko
0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko
0P00ooh00_l00?koo@00<Dcm00GoEUKoo`3no`D0oomFE_om00Go9RKoo`3no`D0
oolV9_ol00Gono_oo`3no`D0oooknoom00GoYZKoo`3no`D0oonVY_om001KA?d0
0?omEPCooeKoooeF0?om003ooBH4oolVooom9P3oo000oogk1?oonooooO/0ood0
0?omYPCoojKooofV0?om000=9?d00?odEP3oo@00oo@V0?ol003om?/0ood00?od
YP3oo@00=BCm003om5H0ood00?od9P3oo000ooCk0?om003om:H0ood0064To@00
ooAF0?om003om2H0oo`00?odn`3oo@00ooBV0?om001M@?d00?olEP?oE_oooEH0
ood00?ol9P?o9_oooBH0oo`00?oln`?onooooO/0ood00?olYP?oY_oooJH0ood0
00e<o@02oeIFo_l30?l00?ko0EKoo@02obHVo_l30?l00?ko0BKoo002oo_ko_l3
0?l00?ko0O_oo@02ojJVo_l30?l00?ko0JKoo@003CSm0?koo@00oo`00Oooo@3n
ood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00;PB`000P1;00
020do@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on
003ojP00C3Cm0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2003o
oP02o`00o_oZ000e>_d01OoTi?oo0?ko1@3oonCTood01OnVY_oo0?ko1@3oojJV
oo`01Ol61_oo0?ko1@3oo`H6onX003Tdo@00oogT1?ooi?oooN@0ood00?omYPCo
ojKooofV0?ol003oo@H4ool6ooom1P3ojP00M1cm003om>@0ood00?odYP3oo000
oo@60?oZ000f7?d00?odi03oo@00ooBV0?ol003om0H0onX0020Lo@00ooCT0?om
003om:H0oo`00?od1P3ojP00=C7m003oo>@3onCooogT0?om003oo:H3ojKooofV
0?ol003oo0H3o`Koood60?oZ000d>_d00_oTi?ko0`3o003no`7Tood00_nVY_ko
0`3o003no`6Voo`00_l61_ko0`3o003no`46onX000d[o@3nood00?ol007oood0
o_om003oo001oool0?koo@00oo`00OoojP00>@B`000c1;0006e4o@00ooh00?ol
003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol
003ooP00ood000e4o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko
0P00ooh00_l00?koo@3no`800?on00;o003nood0021<o@05ojJVool0o_l50?oo
YZKoo@05oo_kool0o_l50?oono_oo005onCTool0o_l50?ooi>Coo@05ojJVool0
o_l50?ooYZKoo@00<4Cm003ooJH4oonVooomYP3oo@00oogk1?oonooooO/0oo`0
0?omi0CoonCooogT0?om003ooJH4oonVooomYP3oo@00KbCm003om:H0ood00?od
n`3oo000ooCT0?om003om:H0ood0070To@00ooBV0?om003om?/0oo`00?odi03o
o@00ooBV0?om000c9?d00?odYP3oo@00ooCk0?ol003om>@0ood00?odYP3oo@00
;T3m003oo:H3ojKooofV0?om003oo?/3oo_ooogk0?ol003oo>@3onCooogT0?om
003oo:H3ojKooofV0?om000PC?d00_nVY_ko0`3o003no`6Vood00_oknoko0`3o
003no`7koo`00_oTi?ko0`3o003no`7Tood00_nVY_ko0`3o003no`6Vood003<h
o@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol
007oood00204/000L`B`001YA?d00?on003oo000ooh00?om003ooP00oo`00?on
003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?om000dA?d0o_l2003o
oP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2003o
oP02o`00o_om000aC?d01OnVY_oo0?ko1@3oojJVood01OnEUOoo0?ko1@3ooiFE
oo`01On6Q_oo0?ko1@3oohJ6ood01OlE5Ooo0?ko1@3ooaDEood006Q4o@00oofV
1?ooY_oooJH0ood00?omU@CooiGooofE0?ol003ooHH4oon6ooomQP3oo@00oodE
1?oo5OoooAD0ood004`To@00ooBV0?om003om9D0oo`00?odQP3oo@00oo@E0?om
000P9?d00?odYP3oo@00ooBE0?ol003om8H0ood00?od5@3oo@00=RCm003om:H0
ood00?odU@3oo000ooB60?om003om1D0ood003E0o@00oobV0onVooomYP3oo@00
oobE0onEooomU@3oo000oob60on6ooomQP3oo@00oo`E0olEooom5@3oo@00<dcm
00;oYZKno`<0o`00o_l1Y_om00;oUIGno`<0o`00o_l1UOol00;oQXKno`<0o`00
o_l1Q_om00;o5AGno`<0o`00o_l15Oom000P>?d0o_om003oo001ooom0?koo@00
oo`00Oooo03nood00?ol007oood0o_om003oo001ooom000_1;0003@4/000ICCm
003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?oZ
001<=?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o
003nonX003Ljo@05olK6ool0o_l50?ooa/Koo@05ofEUool0o_l50?ooIFGoo005
ojJVool0o_l50?ooYZKojP0083Cm003ooLH4ooo6ooomaP3oo@00ooeU1?ooIOoo
oFD0oo`00?omYPCoojKooofV0?oZ000f7?d00?odaP3oo@00ooAU0?ol003om:H0
onX0034Lo@00ooC60?om003om6D0oo`00?odYP3ojP00<Acm003om<H0ood00?od
I@3oo000ooBV0?oZ001W<Od00?olaP?oa_oooLH0ood00?olI@?oIOoooFD0oo`0
0?olYP?oY_oooJH0onX0078jo@02olK6o_l30?l00?ko0LKoo@02ofEUo_l30?l0
0?ko0FGoo002ojJVo_l30?l00?ko0JKojP00<b_m0?koo@00oo`00Oooo@3nood0
0?ol007ooo`0o_om003oo001oooZ001X1;000204/000=DCm003ooP00oo`00?on
003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`00?on
003oo@00<dCm0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2003o
oP02o`00o_om0?ko0P00ooh00_l00?koo@00=Dcm00Gono_oo`3no`D0oooknoom
00Gono_oo`3no`D0oooknool00Gono_oo`3no`D0oooknoom00Goa/Koo`3no`D0
ooo6a_om000dA?d00?omn`Cooo_ooogk0?om003ooO/4oookooomn`3oo000oogk
1?oonooooO/0ood00?omaPCoolKooog60?om000=9?d00?odn`3oo@00ooCk0?ol
003om?/0ood00?odaP3oo@00I2Cm003om?/0ood00?odn`3oo000ooCk0?om003o
m<H0ood0064To@00ooCk0?om003om?/0oo`00?odn`3oo@00ooC60?om001d@?d0
0?oln`?onooooO/0ood00?oln`?onooooO/0oo`00?oln`?onooooO/0ood00?ol
aP?oa_oooLH0ood000e<o@02oo_ko_l30?l00?ko0O_oo@02oo_ko_l30?l00?ko
0O_oo002oo_ko_l30?l00?ko0O_oo@02olK6o_l30?l00?ko0LKoo@00<3Sm0?ko
o@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Ooo
o@00>0B`000f1;00020do@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol
003ooP00oo`00?on003ojP00;SCm0?ko0P00ooh00_l00?koo@3no`800?on00;o
003noo`0o_l2003ooP02o`00o_oZ000c>_d01OoTi?oo0?ko1@3oonCTood01OnV
Y_oo0?ko1@3oojJVoo`01OnFU_oo0?ko1@3ooiJFonX0064do@00oogT1?ooi?oo
oN@0ood00?omYPCoojKooofV0?ol003ooIH4oonFooomUP3ojP00=Qcm003om>@0
ood00?odYP3oo000ooBF0?oZ001Y7?d00?odi03oo@00ooBV0?ol003om9H0onX0
05dLo@00ooCT0?om003om:H0oo`00?odUP3ojP003C7m003oo>@3onCooogT0?om
003oo:H3ojKooofV0?ol003oo9H3oiKooofF0?oZ000e>_d00_oTi?ko0`3o003n
o`7Tood00_nVY_ko0`3o003no`6Voo`00_nFU_ko0`3o003no`6FonX003@[o@3n
ood00?ol007oood0o_om003oo001oool0?koo@00oo`00OoojP003@B`000c1;00
02i4o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on
003oo@00ooh00?ol003ooP00ood003=4o@3no`800?on00;o003nood0o_l2003o
oP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003nood0035<o@05
oo_kool0o_l50?oono_oo@05oo_kool0o_l50?oono_oo005obDUool0o_l50?oo
9BGoo@05oo_kool0o_l50?oono_oo@00ITCm003ooO/4oookooomn`3oo@00oogk
1?oonooooO/0oo`00?om9@CoobGooodU0?om003ooO/4oookooomn`3oo@00<BCm
003om?/0ood00?odn`3oo000oo@U0?om003om?/0ood0030To@00ooCk0?om003o
m?/0oo`00?od9@3oo@00ooCk0?om000P9?d00?odn`3oo@00ooCk0?ol003om2D0
ood00?odn`3oo@00=D3m003oo?/3oo_ooogk0?om003oo?/3oo_ooogk0?ol003o
o2D3obGooodU0?om003oo?/3oo_ooogk0?om000^C?d00_oknoko0`3o003no`7k
ood00_oknoko0`3o003no`7koo`00_lU9Oko0`3o003no`4Uood00_oknoko0`3o
003no`7kood0020ho@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`0
0Oooo@3nood00?ol007oood003<4/0003@B`000g=?d00?on003oo000ooh00?om
003ooP00oo`00?on003oo000ooh00?ol003ooP00onX006Ddo@3no`800?on00;o
003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?kojP00<3[m00Goa/Ko
o`3no`D0ooo6a_om00Go9RKoo`3no`D0oolV9_ol00GoYZKoo`3no`D0oonVY_oZ
001^=?d00?omaPCoolKooog60?om003ooBH4oolVooom9P3oo000oofV1?ooY_oo
oJH0onX007@Lo@00ooC60?om003om2H0oo`00?odYP3ojP00=Acm003om<H0ood0
0?od9P3oo000ooBV0?oZ001d7?d00?odaP3oo@00oo@V0?ol003om:H0onX005/a
o@00ooc60oo6ooomaP3oo@00oo`V0olVooom9P3oo000oobV0onVooomYP3ojP00
J3[m00;oa/Kno`<0o`00o_l1a_om00;o9RKno`<0o`00o_l19_ol00;oYZKno`<0
o`00o_l1Y_oZ000i:od0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol
007oonX00204/000=`B`000^=?d00?on003oo000ooh00?om003ooP00oo`00?on
003oo000ooh00?ol003ooP00onX000ddo@3no`800?on00;o003nood0o_l2003o
oP02o`00o_ol0?ko0P00ooh00_l00?kojP00=3[m00Go9BGoo`3no`D0oolU9Oom
00Go9RKoo`3no`D0oolV9_ol00Go];Coo`3no`D0oond]?oZ001S=?d00?om9@Co
obGooodU0?om003ooBH4oolVooom9P3oo000oofd1?oo]?oooK@0onX0030Lo@00
oo@U0?om003om2H0oo`00?od]03ojP0081cm003om2D0ood00?od9P3oo000ooBd
0?oZ001/7?d00?od9@3oo@00oo@V0?ol003om;@0onX0070ao@00oo`U0olUooom
9@3oo@00oo`V0olVooom9P3oo000oobd0ondooom]03ojP00<3[m00;o9BGno`<0
o`00o_l19Oom00;o9RKno`<0o`00o_l19_ol00;o];Cno`<0o`00o_l1]?oZ001_
:od0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oonX005d4/000
H@B`000g1;0002i4o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003o
oP00oo`00?on003oo@00ooh00?ol003ooP00ood003=4o@3no`800?on00;o003n
ood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003n
ood003M<o@05o`H6ool0o_l50?oo1PKoo@05ojJVool0o_l50?ooYZKoo005obHV
ool0o_l50?oo9RKoo@05o`H6ool0o_l50?oo1PKoo@0084Cm003oo@H4ool6ooom
1P3oo@00oofV1?ooY_oooJH0oo`00?om9PCoobKooodV0?om003oo@H4ool6ooom
1P3oo@00;RCm003om0H0ood00?odYP3oo000oo@V0?om003om0H0ood006PTo@00
oo@60?om003om:H0oo`00?od9P3oo@00oo@60?om000a@?d00?ol1P?o1_ooo@H0
ood00?olYP?oY_oooJH0oo`00?ol9P?o9_oooBH0ood00?ol1P?o1_ooo@H0ood0
05]<o@02o`H6o_l30?l00?ko0@Koo@02ojJVo_l30?l00?ko0JKoo002obHVo_l3
0?l00?ko0BKoo@02o`H6o_l30?l00?ko0@Koo@00ICSm0?koo@00oo`00Oooo@3n
ood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00I@B`000^1;00
00d4/000=BCm003ooP00oo`00?on003oo@00ooh00?ol003ooP00omH003<To@3n
o`800?on00;o003nood0o_l2003ooP02o`00o_oF000i:?d01Ol61_oo0?ko1@3o
o`H6ood01OnVY_oo0?ko1@3oojJVomH007@To@00ood61?oo1_ooo@H0ood00?om
YPCoojKooofV0?oF001e5?d00?od1P3oo@00ooBV0?oF000e5?d00?od1P3oo@00
ooBV0?oF001Y5?d00?od1P3oo@00ooBV0?oF001/8_d00?ol1P?o1_ooo@H0ood0
0?olYP?oY_oooJH0omH003DXo@02o`H6o_l30?l00?ko0@Koo@02ojJVo_l30?l0
0?ko0JKoeP00;Qkm0?koo@00oo`00Oooo@3nood00?ol007oomH00204/000=`B`
000PA?d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003o
oP00ood00?on003oo000ooh00?om001`A?d0o_l2003ooP02o`00o_om0?ko0P00
ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_om001QC?d0
1OnVY_oo0?ko1@3oojJVood01OnVY_oo0?ko1@3oojJVoo`01Ooknooo0?ko1@3o
oo_kood01OlE5Ooo0?ko1@3ooaDEood003=4o@00oofV1?ooY_oooJH0ood00?om
YPCoojKooofV0?ol003ooO/4oookooomn`3oo@00oodE1?oo5OoooAD0ood006TT
o@00ooBV0?om003om:H0oo`00?odn`3oo@00oo@E0?om000^9?d00?odYP3oo@00
ooBV0?ol003om?/0ood00?od5@3oo@0082Cm003om:H0ood00?odYP3oo000ooCk
0?om003om1D0ood003=0o@00oobV0onVooomYP3oo@00oobV0onVooomYP3oo000
oock0ookooomn`3oo@00oo`E0olEooom5@3oo@00>4cm00;oYZKno`<0o`00o_l1
Y_om00;oYZKno`<0o`00o_l1Y_ol00;ono_no`<0o`00o_l1noom00;o5AGno`<0
o`00o_l15Oom000d>?d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol
007oood0o_om003oo001ooom001c1;000204/000DcCm003ooP00oo`00?on003o
o@00ooh00?ol003ooP00oo`00?on003oo000ooh00?oZ000`=?d0o_l2003ooP02
o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nonX0020jo@05o`H6
ool0o_l50?oo1PKoo@05oo_kool0o_l50?oono_oo005obHVool0o_l50?oo9RKo
jP00C3Cm003oo@H4ool6ooom1P3oo@00oogk1?oonooooO/0oo`00?om9PCoobKo
oodV0?oZ001b7?d00?od1P3oo@00ooCk0?ol003om2H0onX0078Lo@00oo@60?om
003om?/0oo`00?od9P3ojP00<acm003om0H0ood00?odn`3oo000oo@V0?oZ001X
<Od00?ol1P?o1_ooo@H0ood00?oln`?onooooO/0oo`00?ol9P?o9_oooBH0onX0
020jo@02o`H6o_l30?l00?ko0@Koo@02oo_ko_l30?l00?ko0O_oo002obHVo_l3
0?l00?ko0BKojP00=B_m0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003o
o001oooZ000c1;0003D4/000=3Cm003ooP00oo`00?on003oj@00ooh00?ol003o
oP00ood00?on003oo000ooh00?om000==?d0o_l2003ooP02o`00o_oY0?ko0P00
ooh00_l00?koo@3no`800?on00;o003nood006@jo@05ooCdool0o_l50?oom?Co
j@05onCTool0o_l50?ooi>Coo@05omKFool0o_l50?ooe]Koo@00HCCm003ooO@4
ooodooomm03oj@00oogT1?ooi?oooN@0ood00?omePCoomKooogF0?om001d7?d0
0?odm03oj@00ooCT0?om003om=H0ood000dLo@00ooCd0?oY003om>@0ood00?od
eP3oo@00<1cm003om?@0onT00?odi03oo@00ooCF0?om000h<Od00?olm0?om?oo
oO@0onT00?oli0?oi?oooN@0ood00?oleP?oe_oooMH0ood003Hjo@02ooCdo_l3
0?l00?ko0OCoj@02onCTo_l30?l00?ko0NCoo@02omKFo_l30?l00?ko0MKoo@00
82_m0?koo@00oo`00Oooj@3nood00?ol007oood0o_om003oo001ooom000^1;00
03<4/000HCCm003ooP00oo`00?on003oo@00ooh00?ol003ooP00onT00?on003o
o000ooh00?om000f=?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koj@3n
o`800?on00;o003nood006Tjo@05oiBDool0o_l50?ooU9Coo@05ojJVool0o_l5
0?ooYZKoj@05oeIFool0o_l50?ooEUKoo@00<3Cm003ooI@4oonDooomU03oo@00
oofV1?ooY_oooJH0onT00?omEPCooeKoooeF0?om001c7?d00?odU03oo@00ooBV
0?oY003om5H0ood000dLo@00ooBD0?om003om:H0onT00?odEP3oo@0081cm003o
m9@0ood00?odYP3oj@00ooAF0?om001/<Od00?olU0?oU?oooI@0ood00?olYP?o
Y_oooJH0onT00?olEP?oE_oooEH0ood006Pjo@02oiBDo_l30?l00?ko0ICoo@02
ojJVo_l30?l00?ko0JKoj@02oeIFo_l30?l00?ko0EKoo@00<2_m0?koo@00oo`0
0Oooo@3nood00?ol007oonT0o_om003oo001ooom001_1;000644/000<4Cm003o
oP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003o
oP00oo`00?on003oo@00M4Cm0?ko0P00ooh00_l00?koo@3no`800?on00;o003n
oo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00<Dcm00Go9RKoo`3n
o`D0oolV9_om00GoEUKoo`3no`D0oomFE_ol00GoEUKoo`3no`D0oomFE_om00Go
no_oo`3no`D0oooknoom001`A?d00?om9PCoobKooodV0?om003ooEH4oomFooom
EP3oo000ooeF1?ooE_oooEH0ood00?omn`Cooo_ooogk0?om000U9?d00?od9P3o
o@00ooAF0?ol003om5H0ood00?odn`3oo@00<2Cm003om2H0ood00?odEP3oo000
ooAF0?om003om?/0ood004LTo@00oo@V0?om003om5H0oo`00?odEP3oo@00ooCk
0?om000P@?d00?ol9P?o9_oooBH0ood00?olEP?oE_oooEH0oo`00?olEP?oE_oo
oEH0ood00?oln`?onooooO/0ood0031<o@02obHVo_l30?l00?ko0BKoo@02oeIF
o_l30?l00?ko0EKoo002oeIFo_l30?l00?ko0EKoo@02oo_ko_l30?l00?ko0O_o
o@00;SSm0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?ko
o@00oo`00Oooo@0080B`000e1;0003A4o@00ooh00?ol003ooP00ood00?on003o
o000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood002E4o@3n
o`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3n
o`800?on00;o003nood007A<o@05obHVool0o_l50?oo9RKoo@05okjnool0o_l5
0?oo_[koo005ohJ6ool0o_l50?ooQXKoo@05ojJVool0o_l50?ooYZKoo@00JDCm
003ooBH4oolVooom9P3oo@00oofn1?oo__oooKh0oo`00?omQPCoohKooof60?om
003ooJH4oonVooomYP3oo@00HBCm003om2H0ood00?od_P3oo000ooB60?om003o
m:H0ood000dTo@00oo@V0?om003om;h0oo`00?odQP3oo@00ooBV0?om001c9?d0
0?od9P3oo@00ooBn0?ol003om8H0ood00?odYP3oo@00M43m003oo2H3obKooodV
0?om003oo;h3okkooofn0?ol003oo8H3ohKooof60?om003oo:H3ojKooofV0?om
000`C?d00_lV9_ko0`3o003no`4Vood00_nn__ko0`3o003no`6noo`00_n6Q_ko
0`3o003no`66ood00_nVY_ko0`3o003no`6Vood006Hho@3nood00?ol007oood0
o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007oood00304/00080B`
001<=>X00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003o
oP00ood0034djP3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00
ooh00_l00?koo@003C[Z00GoeMGoo`3no`D0oooEeOol00Goi>Coo`3no`D0oooT
i?om00Go9RKoo`3no`D0oolV9_om000d=>X00?ome@CoomGooogE0?ol003ooN@4
oooTooomi03oo@00oodV1?oo9_oooBH0ood0050LjP00ooCE0?ol003om>@0ood0
0?od9P3oo@00HAcZ003om=D0oo`00?odi03oo@00oo@V0?om001d7>X00?ode@3o
o000ooCT0?om003om2H0ood000dajP00oocE0ooEooome@3oo000oocT0ooTooom
i03oo@00oo`V0olVooom9P3oo@00<3[Z00;oeMGno`<0o`00o_l1eOol00;oi>Cn
o`<0o`00o_l1i?om00;o9RKno`<0o`00o_l19_om000h:nX0o_om003oo001oool
0?koo@00oo`00Oooo@3nood00?ol007oood003H4/00080B`000^A?d00?on003o
o000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003o
o000ooh00?om000cA?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03n
o`800?on00;o003nood0o_l2003ooP02o`00o_om001QC?d01Ooknooo0?ko1@3o
oo_kood01OnVY_oo0?ko1@3oojJVoo`01OmFE_oo0?ko1@3ooeIFood01OoFe_oo
0?ko1@3oomKFood00394o@00oogk1?oonooooO/0ood00?omYPCoojKooofV0?ol
003ooEH4oomFooomEP3oo@00oogF1?ooe_oooMH0ood0020To@00ooCk0?om003o
m:H0oo`00?odEP3oo@00ooCF0?om000`9?d00?odn`3oo@00ooBV0?ol003om5H0
ood00?odeP3oo@00LbCm003om?/0ood00?odYP3oo000ooAF0?om003om=H0ood0
07E0o@00oock0ookooomn`3oo@00oobV0onVooomYP3oo000ooaF0omFooomEP3o
o@00oocF0ooFooomeP3oo@00<4cm00;ono_no`<0o`00o_l1noom00;oYZKno`<0
o`00o_l1Y_ol00;oEUKno`<0o`00o_l1E_om00;oe]Kno`<0o`00o_l1e_om001S
>?d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003o
o001ooom001d1;000204/000<cCZ003ooP00oo`00?on003oo000ooh00?ol003o
oP00ood00?on003oo000ooh00?om000P=>X0o_l2003ooP02o`00o_ol0?ko0P00
ooh00_l00?koo@3no`800?on00;o003nood0020jjP05oeIFool0o_l50?ooEUKo
o005ojJVool0o_l50?ooYZKoo@05oeIFool0o_l50?ooEUKoo@00<CCZ003ooEH4
oomFooomEP3oo000oofV1?ooY_oooJH0ood00?omEPCooeKoooeF0?om000f7>X0
0?odEP3oo000ooBV0?om003om5H0ood004`LjP00ooAF0?ol003om:H0ood00?od
EP3oo@00<1cZ003om5H0oo`00?odYP3oo@00ooAF0?om000=<NX00?olEP?oE_oo
oEH0oo`00?olYP?oY_oooJH0ood00?olEP?oE_oooEH0ood0020jjP02oeIFo_l3
0?l00?ko0EKoo002ojJVo_l30?l00?ko0JKoo@02oeIFo_l30?l00?ko0EKoo@00
M2_Z0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom000d1;00
04H4/000=2Cm003ooP00oo`00?on003oeP00ooh00?ol003ooP00ood003DTo@3n
o`800?on00;o003nomH0o_l2003ooP02o`00o_om000g:?d01OnFU_oo0?ko1@3o
oiJFomH01Ooknooo0?ko1@3ooo_kood003HTo@00oofF1?ooU_oooIH0omH00?om
n`Cooo_ooogk0?om000`5?d00?odUP3oeP00ooCk0?om001d5?d00?odUP3oeP00
ooCk0?om001K5?d00?odUP3oeP00ooCk0?om001X8_d00?olUP?oU_oooIH0omH0
0?oln`?onooooO/0ood0038Xo@02oiJFo_l30?l00?ko0IKoeP02oo_ko_l30?l0
0?ko0O_oo@0081km0?koo@00oo`00OooeP3nood00?ol007oood003L4/000;PB`
000=5=H00?on003oo000ooh00?oZ000d5=H0o_l2003ooP02o`00o_oZ001Q5]H0
1OnEUOoo0?ko1@3ooiFEonX006lDeP00oofE1?ooUOoooID0onX003<<eP00ooBE
0?oZ001d3=H00?odU@3ojP00J@cF003om9D0onX003<CeP00oobE0onEooomU@3o
jP00>1KF00;oUIGno`<0o`00o_l1UOoZ000`4MH0o_om003oo001oooZ000^1;00
03D4/000M0B`001b1;0003<4/000KPB`001_1;0003D4/000;PB`000P1;0003L0
00402P120342=P5>03@0@`4C0B81C00100X0@`4C0B81C02HP58000000Cl0D@00
0000000004P0001800000008004020000000/94/000000009;h0003o003ooooo
ool00Oooooo<c002oocoo:ZX00?oooooIVH01?oooolc<`05ooooo`0000Koolc<
ool01oooc<c<c008ooo<c9VI00Tk4c/C>a<02WXGNQMj5`0;^AZi6[TJ00ch7_PN
n1h03@00oocoo00>EECoo?ol00nZZ?oloo`04?ooVITc<`0AoonIV@0001;oofIV
ool04oooIVK<c00DoomVIYVI01GoofIVIVH05_ooIVHc<`0GoomVIP0001Sooc<c
ool06Cl3?`<o0`0JOPMn1gh701^m2kd;_@/07?`>o0kl3P0MEE@0000001jZZ000
00007ool0000000Pool009VI027oo`00IVH08_oo000c<`0Sool0000002C<c?oo
ool09Lc<ooo<c00Vc<cooiVI02O<c?ooIVH0:0?`0o03l00Y@_=2ld;c02Z1mh7g
POL0:l3k`?_0n`0/000005ED02eEE000EE@0;ZZX001EE00_oo`005ED033<c9VI
ool0<Lc<VIW<c00bc<bIVIVI03?<c9VIIVH0=<c<VITc<`0ec<bIV@0003K<c6IV
ool0=lc<IVK<c00h1n07h0OP03U6i4KTA^@0>XGWQNN5i`0ka>_4jlC[03`00000
ZZP0?EED002ZZ00nZZP00:ZX03ooo000ZZP0@<c<<c<c<`11c<`c<`0004;<c000
ool0@lc<003<c014c<`009VI04G<c000IVH0A/c<000c<`17c<`0000004P;d0_@
2m00BD[DB]A:e01:RMR9f8WH04_8flSKb=/0C000003oo01=EE@00?ol04jZZ000
oo`0Cool003oo01@VIW<c9VI056IVLc<IVH0DYVIc<`c<`1CVIW<c00005BIVIVI
ool0EIVIVIW<c01FVIVIVIVI05NIVIVIIVH0F0o03l0?`01IC/A>a4k405Z=b8g8
SLP0Flc<c<c<c01L001EE00005eEE5ED0000GZZXEE@0001OooaEE000062IVC<c
ool0HIVI<c?<c01RVITc<iVI06>IVC<cIVH0I9VI<c<c<`1UVITc<`0006JIV@00
ool0IiVI003<c01X4k4C/A>a06UB]5:dD[@0JY6hTKRA^01[d;c@_=2l06`005ED
EE@0KEEDEEAEE01^ZZQEE5ED06ooo5EDEE@0L6IVoolc<`1aIVKoo`00079VI/c<
ool0LfIVc<c<c01dIVK<c9VI07EVI/c<IVH0MVIVc<`c<`1gIVK<c00007PGXANQ
5j40NEJUEZEFY@1jUJREZ9FX07_D[=B/e:`0O000EEBZZ01mEEAEE:ZX07jZZ5ED
ZZP0OoolEEBZZ020IVIVIYVI085VIVIVIVH0PVIVIVHc<`23IVIVIP0008AVIS<c
ool0QFIV<c?<c026IVHc<iVI08MVIS<cIVH0R1^A6i4KT@29FYEJUEZE08ZIVIVI
VIT0RmRLf9cHW02<001EE?ol08eEE5EDoo`0SZZXEECoo02?ooaEE?ol090c<ooo
ool0TC<cooo<c02B<c?ooiVI09<c<oooIVH0U3<coolc<`2E<c?oo`0009Hc<lc<
ool0Uc<cc<c<c02H7h4OPAn109UNQEj5GXD0VYf9WHVMR@2Kg8cLS=b<09`00:ZX
0000WEEDZZP0002NZZRZZ00009ooo:ZX0000X3<cVITc<`2Q<c>IV@000:8c<fIV
ool0Xc<cIVK<c02T<c=VIYVI0:Dc<fIVIVH0YS<cIVHc<`2W<c=VIP000:PSLR=b
8g80ZF9eHWERM@2ZXGVQNJ5i0:_PON1mh7d0[000ZZQEE02]EEBZZ5ED0:jZZ:ZX
EE@0[oolZZQEE02`<c<009VI0;4c<`00IVH0/S<c000c<`2c<c<000000;@00?oo
ool0]@00ooo<c02f003ooiVI0;L00?ooIVH0^2MR9f8WHP2iIVIVIVIV0;ZUJJEY
YFT0^nA]i6gTK@2l002ZZ:ZX0;eEE:ZXZZP0_ZZXZZRZZ02ooobZZ:ZX0<0009VI
ool0`@00VIW<c032002IVIVI0<<009VIIVH0a000VITc<`35002IV@000<H006IV
ool0a`00IVK<c038:e8[DR]B0<UZEVYFJUH0bZUIZEVYF@3;j5gXGNQM0<`00:ZX
oo`0cEEDZZSoo03>ZZRZZ?ol0<ooo:ZXoo`0d000<c<c<`3A000c<`000=800000
ool0d`00003<c03D000009VI0=D00000IVH0eP00000c<`3Gk^h000000=P_@Rm2
;d80fFi6KTI^AP3J[DZ]BZe:0=_/CNa=k4d0g000oo`0003MEECoo0000=jZZ?ol
0000gooloo`0003P4A4000000>400>k^0000hP00gMd0003S002k^`000>@00:ZZ
0000i@00R8P0003V001gM`000>L005EE0000j3<c<c<c<`3YLSIb=W8f0>Za>[4j
/CX0jo0nl3k`?P3/003oo5ED0>eEE?olEE@0kZZXooaEE03_oocoo5ED0?000000
MgL0l@00001EE@3b000004A40?<000008R80m000000A4@3ek^k^k^k^0?KMgMgM
gMd0mk^k^k^k^`3h=b<g8cLS0?Uf9WHVMRH0n[DZ]BZe:P3km2kd;_@^0?`00?ol
ZZP0oEEDoobZZ03nZZSoo:ZX0?l00000000000000Cl0D@130A<18P5<02@4/000
;0B`003L1;000?l2[`04/0007PB`003]1;0004T4/000XP:_00B`000:@_d00?on
003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on
003oo000ooh00?ol04Cm0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0
o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@0054cm00Gono_oo`3no`D0
oooknoom00Gono_oo`3no`D0oooknool00Go2P[oo`3no`D0ool:2_om00Go^k_o
o`3no`D0oonk^oom003XA?d00?omn`Cooo_ooogk0?om003ooO/4oookooomn`3o
o000ood:1?oo2_ooo@X0ood00?om^`Cook_ooofk0?om00398_d00?odn`3oo@00
ooCk0?ol003om0X0ood00?od^`3oo00Ro@00ooCk0?om003om?/0oo`00?od2P3o
o@00ooBk0?ol02Cm003om?/0ood00?odn`3oo000oo@:0?om003om;/0ood003`n
o@00oock0ookooomn`3oo@00oock0ookooomn`3oo000oo`:0ol:ooom2P3oo@00
oobk0onkooom^`3oo01<o@02oo_ko_l30?l00?ko0O_oo@02oo_ko_l30?l00?ko
0O_oo002o`X:o_l30?l00?ko0@[oo@02ok^ko_l30?l00?ko0K_oo@00cCSm0?ko
o@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Ooo
o@00;0B`003L1;000?m2o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol
003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`0A?d0o_l2003ooP02o`00
o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00
o_om001YC?d01Om9BOoo0?ko1@3oodU9ood01OlL7?oo0?ko1@3ooa`Loo`01Oo;
booo0?ko1@3ool_;ood01Ooknooo0?ko1@3ooo_kood00>e4o@00ooe91?ooBOoo
oDT0ood00?om70CooacooodL0?ol003ooL/4ooo;ooomb`3oo@00oogk1?oonooo
oO/0ood00=/To@00ooA90?om003om1`0oo`00?odb`3oo@00ooCk0?om002R8_d0
0?odB@3oo@00oo@L0?ol003om</0ood00?odn`3oo00To@00ooA90?om003om1`0
oo`00?odb`3oo@00ooCk0?om0022?_d00?olB@?oBOoooDT0ood00?ol70?o7?oo
oA`0oo`00?olb`?obooooL/0ood00?oln`?onooooO/0oo`0C?d00_m9BOko0`3o
003no`59ood00_lL7?ko0`3o003no`4Loo`00_o;boko0`3o003no`7;ood00_ok
noko0`3o003no`7kood002Lho@3nood00?ol007oood0o_om003oo001oool0?ko
o@00oo`00Oooo@3nood00?ol007oood003D4/000G@:_03;m003ooP00oo`00?on
003oj@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol03Cm0?ko0P00ooh0
0_l00?koj@3no`800?on00;o003nood0o_l2003ooP02o`00o_om0002>?d01Oo;
booo0?ko1@3ool_;onT01Oohn?oo0?ko1@3oooShood01Ooknooo0?ko1@3ooo_k
oo`0=?d00?omb`Cool_ooog;0?oY003ooOP4ooohooomn03oo@00oogk1?oonooo
oO/0ood007@Lo@00ooC;0?oY003om?P0ood00?odn`3oo@00;1cm003om</0onT0
0?odn03oo@00ooCk0?om003L7?d00?odb`3oj@00ooCh0?om003om?/0ood00?l_
o@00ooc;0oo;ooomb`3oj@00ooch0oohooomn03oo@00oock0ookooomn`3oo00j
o@02ol_;o_l30?l00?ko0L_oj@02ooSho_l30?l00?ko0OSoo@02oo_ko_l30?l0
0?ko0O_oo@00hR_m0?koo@00oo`00Oooj@3nood00?ol007oood0o_om003oo001
ooom002Q1;0007h4/000XS;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00
onT00?on003oo000ooh00?ol03Cm0?ko0P00ooh00_l00?koo@3no`800?on00;o
003nonT0o_l2003ooP02o`00o_om003k>?d01Ooknooo0?ko1@3ooo_kood01OnK
Vooo0?ko1@3ooi^KonT01Ooknooo0?ko1@3ooo_koo`0=?d00?omn`Cooo_ooogk
0?om003ooI/4oonKooomV`3oj@00oogk1?oonooooO/0ood003/Lo@00ooCk0?om
003om9/0onT00?odn`3oo@00[acm003om?/0ood00?odV`3oj@00ooCk0?om0039
6_d00?odn`3oo@00ooBK0?oY003om?/0oo`0;od00?oln`?onooooO/0ood00?ol
V`?oVooooI/0onT00?oln`?onooooO/0oo`0>_d00_oknoko0`3o003no`7kood0
0_nKVoko0`3o003no`6KonT00_oknoko0`3o003no`7kood001DYo@3nood00?ol
007oood0o_om003oo001oooY0?koo@00oo`00Oooo004/000<@B`000/=>X00?on
003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood00=`d
jP3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?ko
o@00ocSZ00Gono_oo`3no`D0oooknool00GomoOoo`3no`D0ooogmoom00GoRh_o
o`3no`D0oon;Rool03CZ003ooO/4oookooomn`3oo000oogg1?oomooooOL0ood0
0?omR`Cooh_ooof;0?om000]7>X00?odn`3oo000ooCg0?om003om8/0ood00:4L
jP00ooCk0?ol003om?L0ood00?odR`3oo@00cacZ003om?/0oo`00?odm`3oo@00
ooB;0?om002R;nX00?oln`?onooooO/0oo`00?olm`?omooooOL0ood00?olR`?o
RooooH/0oo`0>^X00_oknoko0`3o003no`7koo`00_ogmoko0`3o003no`7good0
0_n;Roko0`3o003no`6;ood004HYjP3nood00?ol007ooo`0o_om003oo001ooom
0?koo@00oo`00Oooo004/000>`B`003aA?d00?on003oo000ooh00?om003ooP00
oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?om0039@_d0
o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0
o_l2003ooP02o`00o_ol04[m00GoVi_oo`3no`D0oonKVoom00GonOWoo`3no`D0
oooinOol00Gono_oo`3no`D0oooknoom00Gono_oo`3no`D0oooknool04Cm003o
oI/4oonKooomV`3oo@00oogi1?oonOoooOT0oo`00?omn`Cooo_ooogk0?om003o
oO/4oookooomn`3oo@005B;m003om9/0ood00?odn@3oo000ooCk0?om003om?/0
oo`09?d00?odV`3oo@00ooCi0?ol003om?/0ood00?odn`3oo@00;2Cm003om9/0
ood00?odn@3oo000ooCk0?om003om?/0ood002a0o@00oobK0onKooomV`3oo@00
ooci0ooiooomn@3oo000oock0ookooomn`3oo@00oock0ookooomn`3oo@00g4cm
00;oVi_no`<0o`00o_l1Voom00;onOWno`<0o`00o_l1nOol00;ono_no`<0o`00
o_l1noom00;ono_no`<0o`00o_l1noom003o=_d0o_om003oo001ooom0?koo@00
oo`00Oooo03nood00?ol007oood0o_om003oo001oool00B`002b1;0000Hdo@00
ooh00?ol003ooP00ood00?on003oo000ooh00?oY003ooP00oo`00?on003oo@00
Z3Cm0?ko0P00ooh00_l00?koo@3no`800?on00;o003nonT0o_l2003ooP02o`00
o_om002R>?d01Ooknooo0?ko1@3ooo_kood01Ooknooo0?ko1@3ooo_konT01Onk
^ooo0?ko1@3ook^koo`0=?d00?omn`Cooo_ooogk0?om003ooO/4oookooomn`3o
j@00oofk1?oo^ooooK/0ood00;lJo@00ooCk0?om003om?/0onT00?od^`3oo00L
o@00ooCk0?om003om?/0onT00?od^`3oo@00CQcm003om?/0ood00?odn`3oj@00
ooBk0?om0029<Od00?oln`?onooooO/0ood00?oln`?onooooO/0onT00?ol^`?o
^ooooK/0ood00<Tho@02oo_ko_l30?l00?ko0O_oo@02oo_ko_l30?l00?ko0O_o
j@02ok^ko_l30?l00?ko0K_oo00Yo@3nood00?ol007oood0o_om003oo001oooY
0?koo@00oo`00Oooo004/000:@:_02CZ003ooP00oo`00?on003oj@00ooh00?ol
003ooP00ood002DTjP3no`800?on00;o003nonT0o_l2003ooP02o`00o_om000/
:>X01Ooknooo0?ko1@3ooo_konT01Ooknooo0?ko1@3ooo_kood00=`TjP00oogk
1?oonooooO/0onT00?omn`Cooo_ooogk0?om003o4^X00?odn`3oj@00ooCk0?ol
01CZ003om?/0onT00?odn`3oo@00:QCZ003om?/0onT00?odn`3oo@00>R;Z003o
o?/3oo_ooogk0?oY003oo?/3oo_ooogk0?om003k:>X00_oknoko0`3o003no`7k
onT00_oknoko0`3o003no`7kood00:8LjP3nood00?ol007oonT0o_om003oo001
oool00B`000:0Zl0=?d00?on003oo000ooh00?om003ooP00oo`00?on003oo000
ooh00?ol003ooP00onX004hdo@3no`800?on00;o003nood0o_l2003ooP02o`00
o_ol0?ko0P00ooh00_l00?kojP00<C[m00Go^k_oo`3no`D0oonk^oom00GoVi_o
o`3no`D0oonKVool00Gono_oo`3no`D0oooknooZ0039<_d00?om^`Cook_ooofk
0?om003ooI/4oonKooomV`3oo000oogk1?oonooooO/0onT06_d00?od^`3oo@00
ooBK0?ol003om?/0onT07?d00?od^`3oo@00ooBK0?ol003om?/0onX002TJo@00
ooBk0?om003om9/0oo`00?odn`3oj@0ao@00oobk0onkooom^`3oo@00oobK0onK
ooomV`3oo000oock0ookooomn`3ojP00;S[m00;o^k_no`<0o`00o_l1^oom00;o
Vi_no`<0o`00o_l1Vool00;ono_no`<0o`00o_l1nooZ000/:od0o_om003oo001
ooom0?koo@00oo`00Oooo03nood00?ol007oonX00=`4/000o`:_04Cm003ooP00
oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00
oo`00?on003oo@00MDCm0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0
o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00>Tcm00Go^k_oo`3no`D0
oonk^oom00Go^k_oo`3no`D0oonk^ool00Gono_oo`3no`D0oooknoom00Gono_o
o`3no`D0oooknoom002`A?d00?om^`Cook_ooofk0?om003ooK/4oonkooom^`3o
o000oogk1?oonooooO/0ood00?omn`Cooo_ooogk0?om002R8_d00?od^`3oo@00
ooBk0?ol003om?/0ood00?odn`3oo00To@00ooBk0?om003om;/0oo`00?odn`3o
o@00ooCk0?om002>8_d00?od^`3oo@00ooBk0?ol003om?/0ood00?odn`3oo010
o@00oobk0onkooom^`3oo@00oobk0onkooom^`3oo000oock0ookooomn`3oo@00
oock0ookooomn`3oo@0054cm00;o^k_no`<0o`00o_l1^oom00;o^k_no`<0o`00
o_l1^ool00;ono_no`<0o`00o_l1noom00;ono_no`<0o`00o_l1noom001J>?d0
o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001
ooom00390Zl00Zl0=>X00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00
ooh00?ol003ooP00ood003`bjP3no`800?on00;o003noo`0o_l2003ooP02o`00
o_om0?ko0P00ooh00_l00?koo00jjP05og]kool0o_l50?ooNg_oo005oo_kool0
o_l50?oono_oo@05oi^Kool0o_l50?ooVi_oo@00cCCZ003ooG/4oomkooomN`3o
o000oogk1?oonooooO/0ood00?omV`Cooi_ooofK0?om000/7>X00?odN`3oo000
ooCk0?om003om9/0ood00=`LjP00ooAk0?ol003om?/0ood00?odV`3oo@00oa[Z
003om7/0oo`00?odn`3oo@00ooBK0?ol037Z003oo7/3og_oooek0?ol003oo?/3
oo_ooogk0?om003oo9/3oi_ooofK0?om003^>^X00_mkNoko0`3o003no`5koo`0
0_oknoko0`3o003no`7kood00_nKVoko0`3o003no`6Kood00>d[jP3nood00?ol
007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00J0B`002R0Zl0=>X00?on
003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood000Lb
jP3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?ko
o00jjP05oi^Kool0o_l50?ooVi_oo005oa`Lool0o_l50?oo71coo@05oo_kool0
o_l50?oono_oo@009cCZ003ooI/4oonKooomV`3oo000oodL1?oo7?oooA`0ood0
0?omn`Cooo_ooogk0?om002_7>X00?odV`3oo000oo@L0?om003om?/0ood00<TJ
jP00ooBK0?ol003om1`0ood00?odn`3oo00JjP00ooBK0?ol003om1`0ood00?od
n`3oo00_jP00oobK0onKooomV`3oo000oo`L0olLooom703oo@00oock0ookooom
n`3oo00hjP02oi^Ko_l30?l00?ko0I_oo002oa`Lo_l30?l00?ko0Acoo@02oo_k
o_l30?l00?ko0O_oo00[jP3nood00?ol007ooo`0o_om003oo001ooom0?koo@00
oo`00Oooo@00c@B`000/1;000=`4/000od;m003ooP00oo`00?on003oo@00ooh0
0?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo014o@3n
o`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3n
o`800?on00;o003nood003U<o@05oo_kool0o_l50?oono_oo@05oi^Kool0o_l5
0?ooVi_oo005o`T9ool0o_l50?oo2@Woo@05oo_kool0o_l50?oono_oo@00kDCm
003ooO/4oookooomn`3oo@00oofK1?ooVooooI/0oo`00?om2@Coo`Woood90?om
003ooO/4oookooomn`3oo@004BCm003om?/0ood00?odV`3oo000oo@90?om003o
m?/0ood00:8Ro@00ooCk0?om003om9/0oo`00?od2@3oo@00ooCk0?ol043m003o
o?/3oo_ooogk0?om003oo9/3oi_ooofK0?ol003oo0T3o`Woood90?om003oo?/3
oo_ooogk0?om001BB_d00_oknoko0`3o003no`7kood00_nKVoko0`3o003no`6K
oo`00_l92Oko0`3o003no`49ood00_oknoko0`3o003no`7koo`0>?d0o_om003o
o001ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom000W
1;000?44/000b@:_04;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`0
0?on003oo000ooh00?om003ooP00oo`00?on003oo014o@3no`800?on00;o003n
ood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003n
ood0009:o@05oi^Kool0o_l50?ooVi_oo@05oi^Kool0o_l50?ooVi_oo005oi^K
ool0o_l50?ooVi_oo@05og]kool0o_l50?ooNg_oo014o@00oofK1?ooVooooI/0
ood00?omV`Cooi_ooofK0?ol003ooI/4oonKooomV`3oo@00ooek1?ooNooooG/0
ood007@To@00ooBK0?om003om9/0oo`00?odV`3oo@00ooAk0?om000/9?d00?od
V`3oo@00ooBK0?ol003om9/0ood00?odN`3oo@00FBCm003om9/0ood00?odV`3o
o000ooBK0?om003om7/0ood00?lno@00oobK0onKooomV`3oo@00oobK0onKooom
V`3oo000oobK0onKooomV`3oo@00ooak0omkooomN`3oo01<o@02oi^Ko_l30?l0
0?ko0I_oo@02oi^Ko_l30?l00?ko0I_oo002oi^Ko_l30?l00?ko0I_oo@02og]k
o_l30?l00?ko0G_oo@00/SSm0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om
003oo001ooom0?koo@00oo`00Oooo@00X@B`002X1;000:8bo@00ooh00?ol003o
oP00onT00?on003oo000ooh00?om003ooP00oo`00?on003oo00do@3no`800?on
00;o003nonT0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00bcSm00Go
jNWoo`3no`D0oooYjOoY00Gono_oo`3no`D0oooknoom00Go71coo`3no`D0oolL
7?ol03Cm003ooNT4oooYooomj@3oj@00oogk1?oonooooO/0ood00?om70Cooaco
oodL0?om000k7?d00?odj@3oj@00ooCk0?om003om1`0ood0090Lo@00ooCY0?oY
003om?/0ood00?od703oo@00bA[m003om>T0onT00?odn`3oo@00oo@L0?ol02om
003oo>T3onWooogY0?oY003oo?/3oo_ooogk0?om003oo1`3oacooodL0?ol03[m
00;ojNWno`<0o`00o_l1jOoY00;ono_no`<0o`00o_l1noom00;o71cno`<0o`00
o_l17?om000E:Od0o_om003oo001oooY0?koo@00oo`00Oooo@3nood00?ol007o
oo`01;0002`4/000;2CZ003ooP00oo`00?on003oo000ooh00?ol003ooP00onX0
0=`TjP3no`800?on00;o003noo`0o_l2003ooP02o`00o_oZ003o9^X01Ooknooo
0?ko1@3ooo_koo`01Om9BOoo0?ko1@3oodU9onT09>X00?omn`Cooo_ooogk0?ol
003ooDT4oom9ooomB@3ojP00=QCZ003om?/0oo`00?odB@3ojP001QCZ003om?/0
oo`00?odB@3ojP00XACZ003om?/0oo`00?odB@3ojP00XR3Z003oo?/3oo_ooogk
0?ol003oo4T3odWoooe90?oY02SZ00;ono_no`<0o`00o_l1nool00;oBDWno`<0
o`00o_l1BOoZ000F7>X0o_om003oo001oool0?koo@00oo`00Oooj@04/000>`B`
001^A?d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003o
oP00ood00?on003oo000ooh00?om0039@_d0o_l2003ooP02o`00o_om0?ko0P00
ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_ol04[m00Go
Ng_oo`3no`D0oomkNoom00Gono_oo`3no`D0oooknool00Go^k_oo`3no`D0oonk
^oom00Gobl_oo`3no`D0ooo;bool04Cm003ooG/4oomkooomN`3oo@00oogk1?oo
nooooO/0oo`00?om^`Cook_ooofk0?om003ooL/4ooo;ooomb`3oo@005B;m003o
m7/0ood00?odn`3oo000ooBk0?om003om</0oo`09?d00?odN`3oo@00ooCk0?ol
003om;/0ood00?odb`3oo@00;2Cm003om7/0ood00?odn`3oo000ooBk0?om003o
m</0ood002a0o@00ooak0omkooomN`3oo@00oock0ookooomn`3oo000oobk0onk
ooom^`3oo@00ooc;0oo;ooomb`3oo@00g4cm00;oNg_no`<0o`00o_l1Noom00;o
no_no`<0o`00o_l1nool00;o^k_no`<0o`00o_l1^oom00;obl_no`<0o`00o_l1
boom003o=_d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0
o_om003oo001oool00B`00211;0000I4o@00ooh00?ol003ooP00ood00?on003o
o000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood003U4o@3n
o`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3n
o`800?on00;o003nood00:9:o@05oi^Kool0o_l50?ooVi_oo@05oo_kool0o_l5
0?oono_oo005og]kool0o_l50?ooNg_oo@05of][ool0o_l50?ooJf_oo014o@00
oofK1?ooVooooI/0ood00?omn`Cooo_ooogk0?ol003ooG/4oomkooomN`3oo@00
ooe[1?ooJooooF/0ood008hRo@00ooBK0?om003om?/0oo`00?odN`3oo@00ooA[
0?ol02Cm003om9/0ood00?odn`3oo000ooAk0?om003om6/0ood004hTo@00ooBK
0?om003om?/0oo`00?odN`3oo@00ooA[0?om001E@?d00?olV`?oVooooI/0ood0
0?oln`?onooooO/0oo`00?olN`?oNooooG/0ood00?olJ`?oJooooF/0ood00<U:
o@02oi^Ko_l30?l00?ko0I_oo@02oo_ko_l30?l00?ko0O_oo002og]ko_l30?l0
0?ko0G_oo@02of][o_l30?l00?ko0F_oo00fo@3nood00?ol007oood0o_om003o
o001oool0?koo@00oo`00Oooo@3nood00?ol007ooo`01;0002T2[`0To@00ooh0
0?ol003ooP00onT00?on003oo000ooh00?oZ000U9?d0o_l2003ooP02o`00o_oY
0?ko0P00ooh00_l00?kojP00;2Sm00Go2@Woo`3no`D0ool92OoY00Go2@Woo`3n
o`D0ool92OoZ003L9?d00?om2@Coo`Woood90?oY003oo@T4ool9ooom2@3ojP00
oa;m003om0T0onT00?od2@3oj@0Do@00oo@90?oY003om0T0onX00?XDo@00oo@9
0?oY003om0T0onX003XRo@00oo`90ol9ooom2@3oj@00oo`90ol9ooom2@3ojP00
DRSm00;o2@Wno`<0o`00o_l12OoY00;o2@Wno`<0o`00o_l12OoZ002R7?d0o_om
003oo001oooY0?koo@00oo`00Oooj@04/0004`:_03Cm003ooP00oo`00?on003o
o@00ooh00?ol003ooP00onT00?on003oo000ooh00?om000D=?d0o_l2003ooP02
o`00o_om0?ko0P00ooh00_l00?koj@3no`800?on00;o003nood00;Ljo@05oa/K
ool0o_l50?oo6a_oo@05o`T9ool0o_l50?oo2@Woj@05og]kool0o_l50?ooNg_o
o@00bC;m003ooA/4oolKooom6`3oo@00ood91?oo2Oooo@T0onT00?omN`Coog_o
ooek0?ol01[m003om1/0ood00?od2@3oj@00ooAk0?ol01cm003om1/0ood00?od
2@3oj@00ooAk0?om000Y6_d00?od6`3oo@00oo@90?oY003om7/0oo`0<Od00?ol
6`?o6ooooA/0ood00?ol2@?o2Oooo@T0onT00?olN`?oNooooG/0ood002Djo@02
oa/Ko_l30?l00?ko0A_oo@02o`T9o_l30?l00?ko0@Woj@02og]ko_l30?l00?ko
0G_oo@00;2_m0?koo@00oo`00Oooo@3nood00?ol007oonT0o_om003oo001ooom
003L1;000?l2[`14o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003o
oP00oo`00?on003oo@00ooh00?ol003ooP00ood004E4o@3no`800?on00;o003n
ood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003n
ood003Y<o@05oo_kool0o_l50?oono_oo@05og]kool0o_l50?ooNg_oo005o`T9
ool0o_l50?oo2@Woo@05oo_kool0o_l50?oono_oo@00^TCm003ooO/4oookooom
n`3oo@00ooek1?ooNooooG/0oo`00?om2@Coo`Woood90?om003ooO/4oookooom
n`3oo@00XR;m003om?/0ood00?odN`3oo000oo@90?om003om?/0oo`09?d00?od
n`3oo@00ooAk0?ol003om0T0ood00?odn`3oo@00GR;m003om?/0ood00?odN`3o
o000oo@90?om003om?/0oo`0@?d00?oln`?onooooO/0ood00?olN`?oNooooG/0
oo`00?ol2@?o2Oooo@T0ood00?oln`?onooooO/0ood001A<o@02oo_ko_l30?l0
0?ko0O_oo@02og]ko_l30?l00?ko0G_oo002o`T9o_l30?l00?ko0@Woo@02oo_k
o_l30?l00?ko0O_oo@001cSm0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om
003oo001ooom0?koo@00oo`00Oooo@00b@:_00:_01C3003ooP00oo`00?on003o
o@00?1;30?ko0P00ooh00_l00?koo00F``05ol_;ool0o_l50?oobl_oo@00cAC3
003ooL/4ooo;ooomb`3oo@00?@c3003om</0ood005T<``00ooC;0?om003o2/<0
0?odb`3oo00C``00ooc;0oo;ooomb`3oo@00_QK300;obl_no`<0o`00o_l1boom
000H4L<0o_om003oo001ooom001m1;000:82[`14o@00ooh00?ol003ooP00ood0
0?on003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood0
0=M2o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l0
0?koo@3no`800?on00;o003noo`0C?d01OmkNooo0?ko1@3oog]kood01Ooknooo
0?ko1@3ooo_koo`01Ooknooo0?ko1@3ooo_kood01Ooknooo0?ko1@3ooo_kood0
02M4o@00ooek1?ooNooooG/0ood00?omn`Cooo_ooogk0?ol003ooO/4oookooom
n`3oo@00oogk1?oonooooO/0ood0090To@00ooAk0?om003om?/0oo`00?odn`3o
o@00ooCk0?om00398_d00?odN`3oo@00ooCk0?ol003om?/0ood00?odn`3oo00R
o@00ooAk0?om003om?/0oo`00?odn`3oo@00ooCk0?ol043m003oo7/3og_oooek
0?om003oo?/3oo_ooogk0?ol003oo?/3oo_ooogk0?om003oo?/3oo_ooogk0?om
0002B_d00_mkNoko0`3o003no`5kood00_oknoko0`3o003no`7koo`00_oknoko
0`3o003no`7kood00_oknoko0`3o003no`7koo`0>?d0o_om003oo001ooom0?ko
o@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom001d1;000744/000
g4Cm003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh0
0?om003ooP00oo`00?on003oo@00od;m0?ko0P00ooh00_l00?koo@3no`800?on
00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo01<o@05oh^;
ool0o_l50?ooRh_oo@05oi^Kool0o_l50?ooVi_oo005oi^Kool0o_l50?ooVi_o
o@05oo_kool0o_l50?oono_oo@00=TCm003ooH/4oon;ooomR`3oo@00oofK1?oo
VooooI/0oo`00?omV`Cooi_ooofK0?om003ooO/4oookooomn`3oo@00kBCm003o
m8/0ood00?odV`3oo000ooBK0?om003om?/0ood005dTo@00ooB;0?om003om9/0
oo`00?odV`3oo@00ooCk0?om002R8_d00?odR`3oo@00ooBK0?ol003om9/0ood0
0?odn`3oo010o@00oob;0on;ooomR`3oo@00oobK0onKooomV`3oo000oobK0onK
ooomV`3oo@00oock0ookooomn`3oo@008T[m00;oRh_no`<0o`00o_l1Room00;o
Vi_no`<0o`00o_l1Vool00;oVi_no`<0o`00o_l1Voom00;ono_no`<0o`00o_l1
nool03Sm0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?ko
o@00oo`00Oooo@009`B`001^1;000<Tbo@00ooh00?ol003ooP00onT00?on003o
o000ooh00?om003ooP00oo`00?on003oo00bo@3no`800?on00;o003nonT0o_l2
003ooP02o`00o_om0?ko0P00ooh00_l00?koo00jo@05oiZJool0o_l50?ooVY[o
j@05ol_;ool0o_l50?oobl_oo@05oo[jool0o_l50?oon_[oo@000S;m003ooIX4
oonJooomVP3oj@00oog;1?oobooooL/0ood00?omnPCooo[ooogj0?ol01cm003o
m9X0onT00?odb`3oo@00ooCj0?om000a7?d00?odVP3oj@00ooC;0?om003om?X0
ood002`Lo@00ooBJ0?oY003om</0ood00?odnP3oo@00g37m003oo9X3oi[ooofJ
0?oY003oo</3ol_ooog;0?om003oo?X3oo[ooogj0?om003o>?d00_nJV_ko0`3o
003no`6JonT00_o;boko0`3o003no`7;ood00_ojn_ko0`3o003no`7joo`0:od0
o_om003oo001oooY0?koo@00oo`00Oooo@3nood00?ol007oood00844/000X@B`
00241;000:82[`04/000V`:_00B`000k1;0006@4/000b@:_00000@0:0480<@8f
0Dh0=05803829`1[00402P5803829`1[09R0DP000001?`1A000000000000B000
04P0000000P00@080000002`TAP00000000T_`000?l00?ooooooo`01ooooolc<
00;oo?olZZP00ooooomVIP04=b<g8cLS00Ef9WHVMRH01[DZ]BZe:P07m2kd;_@^
00P00?olZZP02C/C>a<k4`0:NQMj5gXG00^i6[TJ^AX03?PNn1kh7P0=003oo?ol
00iEE?oloo`03jZXoocoo00@oonIVC<c017ooiVI00004_ooIVKoo`0CoomVI/c<
01@k4c/C>a<05GXGNQMj5`0F^AZi6[TJ01Oh7_PNn1h06000oocoo00I?`<o0cl3
01Yn1gh7OPL06kd;_@^m2`0Lo0kl3_`>01eEE00000007ZZX0000000Ooo`00000
023oo`00VIT08Ooo001VIP0Rool003<c02?oo`00000093l3?`<o0`0UOPMn1gh7
02Jm2kd;_@/09o`>o0kl3P0X0o03l0?`02U2ld;c@_<0:X7gPON1m`0[`?_0nl3k
02`00000EE@0;EED001EE00^ZZP005ED02ooo000EE@0<<c<VIWoo`0ac<bIVLc<
03;<c9VIVIT0<`?`0o03l00d@_=2ld;c03F1mh7gPOL0=/3k`?_0n`0g000005ED
03P7h0OP1n00>DKTA^A6i00jQNN5ihGW03_4jlC[a>/0?000002ZZ00mEE@00:ZX
03jZZ000ZZP0?ool002ZZ010c<`c<c<c047<c3<c0000@/c<003oo`131n07h0OP
04A6i4KTA^@0AHGWQNN5i`16a>_4jlC[04L00000ZZP0B0_@2m0;d019B]A:e4[D
04Z9f8WHRMP0BlSKb=_8f`1<00000?ol04eEE000oo`0CZZX003oo01?oo`00?ol
052IVLc<VIT0DIVIc<aVIP1BVIW<c3<c05<;d0_@2m00E4[DB]A:e01ERMR9f8WH
05K8flSKb=/0E`00003oo01H3l0?`0o005U>a4k4C/@0FXg8SLR=b01Kc<c<c<c<
05`005ED0000GEEDEE@0001NZZQEE00005ooo5ED0000H9VI<c?oo`1QVITc<lc<
06:IVC<cVIT0H`o03l0?`01TC/A>a4k406F=b8g8SLP0I/c<c<c<c01W001EE000
06PC/A>a4k40JE:dD[AB]01ZTKRA^96h06_@_=2ld;`0K000EEAEE01]EEAEE5ED
06jZZ5EDEE@0KoolEEAEE01`IVKooc<c075VI_oo0000LVIVc<coo`1c4k4C/A>a
07AB]5:dD[@0MI6hTKRA^01fd;c@_=2l07L005EDEE@0N1NQ5j4GX@1iEZEFYEJU
07ZEZ9FXUJP0NmB/e:cD[01l001EE:ZX07eEE5EDZZP0OZZXEEBZZ01oooaEE:ZX
081VIVIVVIT0PFIVIVIVIP22IVIVIS<c08<GXANQ5j40Q5JUEZEFY@25UJREZ9FX
08KD[=B/e:`0Q`00EEBZZ0286i4KTA^A08UJUEZEFYD0RYVIVIVIV@2;f9cHW=RL
08`005EDoo`0SEEDEECoo02>ZZQEE?ol08ooo5EDoo`0T3<cooooo`2A<c?oolc<
098c<oooVIT0Ta^A6i4KT@2DFYEJUEZE09FIVIVIVIT0U]RLf9cHW02G001EE?ol
09POPAn17h40VEj5GXENQ@2JWHVMRIf909_LS=b<g8`0W000ZZP0002MEEBZZ000
09jZZ:ZX0000WoolZZP0002P<c>IVC<c0:4c<iVI0000XS<cIVKoo`2S7h4OPAn1
0:ANQEj5GXD0YIf9WHVMR@2Vg8cLS=b<0:L00:ZX0000Z2=b8g8SLP2YHWERMF9e
0:ZQNJ5iXGT0Zn1mh7gPO@2/002ZZ5ED0:eEE:ZXEE@0[ZZXZZQEE02_oobZZ5ED
0;0c<`00VIT0/C<c001VIP2b<c<003<c0;<SLR=b8g80]69eHWERM@2eXGVQNJ5i
0;KPON1mh7d0]`00ZZQEE02h9f8WHRMR0;UVIVIVIVH0^ZEYYFVUJ@2ki6gTKNA]
0;`00:ZXZZP0_EEDZZRZZ02nZZRZZ:ZX0;ooo:ZXZZP0`000VIWoo`31002IVLc<
0<8009VIVIT0`bMR9f8WHP34IVIVIVIV0<FUJJEYYFT0a^A]i6gTK@37002ZZ:ZX
0<P[DR]B:e80bFYFJUIZEP3:ZEVYFJUI0<_XGNQMj5d0c000ZZSoo03=EEBZZ?ol
0<jZZ:ZXoo`0coolZZSoo03@000c<c<c0=4003<c0000dP00003oo`3C:e8[DR]B
0=AZEVYFJUH0eJUIZEVYF@3Fj5gXGNQM0=L00:ZXoo`0f2m2;d8_@P3IKTI^AVi6
0=Z]BZe:[DX0fna=k4g/C@3L003oo0000=eEE?ol0000gZZXoo`0003Ooocoo000
0>0A4@000000h@00k^h0003R003Mg@000><_@Rm2;d80i6i6KTI^AP3U[DZ]BZe:
0>K/CNa=k4d0i`00oo`0003X<c<c<c<c0>Ub=W8fLSH0j[4j/CZa>P3[l3k`?_0n
0>`00?olEE@0kEEDooaEE03^ZZSoo5ED0>ooo?olEE@0l000001gM`3a000005EE
0?800000A4@0lc<c<c<c<`3dLSIb=W8f0?Fa>[4j/CX0m_0nl3k`?P3g003oo5ED
0?Pg8cLS=b<0nGHVMRIf9P3j]BZe:[DZ0?_d;_@^m2h0o000oobZZ03mEECoo:ZX
0?jZZ?olZZP0o`00000000000001?`1A0DP0<P8W06/090B`000c1;0002h4/000
<`B`000`1;0006H4/000<@B`001K1;0000d4/000<@B`001/=?d00?on003oo000
ooh00?om003ooP00oo`00?on003oj@00ooh00?ol003ooP00ood0020do@3no`80
0?on00;o003nood0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo@00HC[m
00Gono_oo`3no`D0oooknoom00Gono_oo`3no`D0oooknooY00Go@d?oo`3no`D0
oom3@oom001T=?d00?omn`Cooo_ooogk0?om003ooO/4oookooomn`3oj@00ooe3
1?oo@ooooD<0ood002hLo@00ooCk0?om003om?/0onT00?od@`3oo@0081cm003o
m?/0ood00?odn`3oj@00ooA30?om001Q7?d00?odn`3oo@00ooCk0?oY003om4<0
ood0030ao@00oock0ookooomn`3oo@00oock0ookooomn`3oj@00ooa30om3ooom
@`3oo@00<c[m00;ono_no`<0o`00o_l1noom00;ono_no`<0o`00o_l1nooY00;o
@d?no`<0o`00o_l1@oom000e:od0o_om003oo001ooom0?koo@00oo`00Oooj@3n
ood00?ol007oood00304/000<`B`000fA?d00?on003oo000ooh00?om003ooP00
oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?om000PA?d0
o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0
o_l2003ooP02o`00o_om000PC?d01Om6A_oo0?ko1@3oodI6ood01Ooknooo0?ko
1@3ooo_koo`01OoFe_oo0?ko1@3oomKFood01Ooknooo0?ko1@3ooo_kood007A4
o@00ooe61?ooA_oooDH0ood00?omn`Cooo_ooogk0?ol003ooMH4oooFooomeP3o
o@00oogk1?oonooooO/0ood003<To@00ooA60?om003om?/0oo`00?odeP3oo@00
ooCk0?om001U9?d00?odAP3oo@00ooCk0?ol003om=H0ood00?odn`3oo@00=2Cm
003om4H0ood00?odn`3oo000ooCF0?om003om?/0ood000e0o@00ooa60om6ooom
AP3oo@00oock0ookooomn`3oo000oocF0ooFooomeP3oo@00oock0ookooomn`3o
o@00;Tcm00;oATKno`<0o`00o_l1A_om00;ono_no`<0o`00o_l1nool00;oe]Kn
o`<0o`00o_l1e_om00;ono_no`<0o`00o_l1noom000^>?d0o_om003oo001ooom
0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom000e1;0003H4
/000<4Cm003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000
ooh00?om003ooP00oo`00?on003oo@00KdCm0?ko0P00ooh00_l00?koo@3no`80
0?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00GDcm
00Go10Coo`3no`D0ool41?om00Go9bOoo`3no`D0oolW9ool00Gono_oo`3no`D0
oooknoom00Gono_oo`3no`D0oooknoom001QA?d00?om10Coo`Coood40?om003o
oBL4oolWooom9`3oo000oogk1?oonooooO/0ood00?omn`Cooo_ooogk0?om000g
9?d00?od103oo@00oo@W0?ol003om?/0ood00?odn`3oo@00=BCm003om0@0ood0
0?od9`3oo000ooCk0?om003om?/0ood003TTo@00oo@40?om003om2L0oo`00?od
n`3oo@00ooCk0?om000P@?d00?ol10?o1?ooo@@0ood00?ol9`?o9ooooBL0oo`0
0?oln`?onooooO/0ood00?oln`?onooooO/0ood004a<o@02o`@4o_l30?l00?ko
0@Coo@02obLWo_l30?l00?ko0BOoo002oo_ko_l30?l00?ko0O_oo@02oo_ko_l3
0?l00?ko0O_oo@00=3Sm0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003o
o001ooom0?koo@00oo`00Oooo@00J@B`000`1;00020djP00ooh00?ol003ooP00
oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo@00JSCZ0?ko0P00ooh0
0_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_om001g>^X01OnV
Y_oo0?ko1@3oojJVoo`01Ol41?oo0?ko1@3oo`@4ood01Ooknooo0?ko1@3ooo_k
ood002hdjP00oofV1?ooY_oooJH0oo`00?om10Coo`Coood40?om003ooO/4oook
ooomn`3oo@003AcZ003om:H0oo`00?od103oo@00ooCk0?om000e7>X00?odYP3o
o000oo@40?om003om?/0ood003<LjP00ooBV0?ol003om0@0ood00?odn`3oo@00
>C7Z003oo:H3ojKooofV0?ol003oo0@3o`Coood40?om003oo?/3oo_ooogk0?om
001d>^X00_nVY_ko0`3o003no`6Voo`00_l41?ko0`3o003no`44ood00_oknoko
0`3o003no`7kood0078[jP3nood00?ol007ooo`0o_om003oo001ooom0?koo@00
oo`00Oooo@00<`B`001^1;0006ldjP00ooh00?ol003ooP00oo`00?on003oo000
ooh00?om003ooP00oo`00?on003oo@00=CCZ0?ko0P00ooh00_l00?koo03no`80
0?on00;o003nood0o_l2003ooP02o`00o_om000^>^X01Ooknooo0?ko1@3ooo_k
oo`01Ooknooo0?ko1@3ooo_kood01OnFU_oo0?ko1@3ooiJFood0020djP00oogk
1?oonooooO/0oo`00?omn`Cooo_ooogk0?om003ooIH4oonFooomUP3oo@00=acZ
003om?/0oo`00?odn`3oo@00ooBF0?om000P7>X00?odn`3oo000ooCk0?om003o
m9H0ood0070LjP00ooCk0?ol003om?/0ood00?odUP3oo@00L37Z003oo?/3oo_o
oogk0?ol003oo?/3oo_ooogk0?om003oo9H3oiKooofF0?om000c>^X00_oknoko
0`3o003no`7koo`00_oknoko0`3o003no`7kood00_nFU_ko0`3o003no`6Food0
06<[jP3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00=PB`
001<1;00020To@00ooh00?ol003ooP00ood00?on003oo000ooh00?oF000c9?d0
o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koeP00<BSm00Go@d?oo`3no`D0
oom3@oom00Goa/Koo`3no`D0ooo6a_oF000=9?d00?om@`Cood?oooe30?om003o
oLH4ooo6ooomaP3oeP00KaCm003om4<0ood00?odaP3oeP00HACm003om4<0ood0
0?odaP3oeP00=ACm003om4<0ood00?odaP3oeP0082;m003oo4<3od?oooe30?om
003oo<H3olKooog60?oF000a:?d00_m3@oko0`3o003no`53ood00_o6a_ko0`3o
003no`76omH003HNo@3nood00?ol007oood0o_om003oo001oooF000h1;0003@4
/0003DCm003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000
ooh00?om003ooP00oo`00?on003oo@00;TCm0?ko0P00ooh00_l00?koo@3no`80
0?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00I4cm
00Gono_oo`3no`D0oooknoom00Gono_oo`3no`D0oooknool00Gono_oo`3no`D0
oooknoom00Gono_oo`3no`D0oooknoom001=A?d00?omn`Cooo_ooogk0?om003o
oO/4oookooomn`3oo000oogk1?oonooooO/0ood00?omn`Cooo_ooogk0?om001Q
9?d00?odn`3oo@00ooCk0?ol003om?/0ood00?odn`3oo@00DbCm003om?/0ood0
0?odn`3oo000ooCk0?om003om?/0ood0020To@00ooCk0?om003om?/0oo`00?od
n`3oo@00ooCk0?om001V@?d00?oln`?onooooO/0ood00?oln`?onooooO/0oo`0
0?oln`?onooooO/0ood00?oln`?onooooO/0ood005=<o@02oo_ko_l30?l00?ko
0O_oo@02oo_ko_l30?l00?ko0O_oo002oo_ko_l30?l00?ko0O_oo@02oo_ko_l3
0?l00?ko0O_oo@00KSSm0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003o
o001ooom0?koo@00oo`00Oooo@00D`B`000=1;0000ddo@00ooh00?ol003ooP00
ood00?on003oo000ooh00?oY003ooP00oo`00?on003oo@00;SCm0?ko0P00ooh0
0_l00?koo@3no`800?on00;o003nonT0o_l2003ooP02o`00o_om000^>_d01Ook
nooo0?ko1@3ooo_kood01Ooknooo0?ko1@3ooo_konT01Ooknooo0?ko1@3ooo_k
ood0034do@00oogk1?oonooooO/0ood00?omn`Cooo_ooogk0?oY003ooO/4oook
ooomn`3oo@00C1cm003om?/0ood00?odn`3oj@00ooCk0?om001C7?d00?odn`3o
o@00ooCk0?oY003om?/0ood002hLo@00ooCk0?om003om?/0onT00?odn`3oo@00
837m003oo?/3oo_ooogk0?om003oo?/3oo_ooogk0?oY003oo?/3oo_ooogk0?om
001Q>_d00_oknoko0`3o003no`7kood00_oknoko0`3o003no`7konT00_oknoko
0`3o003no`7kood0030[o@3nood00?ol007oood0o_om003oo001oooY0?koo@00
oo`00Oooo@00<`B`000e1;00030do@00ooh00?ol003ooP00onT00?on003oo000
ooh00?om003ooP00oo`00?on003oo@00<cCm0?ko0P00ooh00_l00?koj@3no`80
0?on00;o003nood0o_l2003ooP02o`00o_om000f>_d01Oo6a_oo0?ko1@3oolK6
onT01Ooknooo0?ko1@3ooo_kood01Oofm_oo0?ko1@3oooKfood0020do@00oog6
1?ooa_oooLH0onT00?omn`Cooo_ooogk0?om003ooOH4ooofooommP3oo@0081cm
003om<H0onT00?odn`3oo@00ooCf0?om001d7?d00?odaP3oj@00ooCk0?om003o
m?H0ood003<Lo@00ooC60?oY003om?/0ood00?odmP3oo@00IC7m003oo<H3olKo
oog60?oY003oo?/3oo_ooogk0?om003oo?H3ooKooogf0?om000d>_d00_o6a_ko
0`3o003no`76onT00_oknoko0`3o003no`7kood00_ofm_ko0`3o003no`7food0
00d[o@3nood00?ol007oonT0o_om003oo001ooom0?koo@00oo`00Oooo@00;PB`
000^1;0003E4o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00
oo`00?on003oo@00ooh00?ol003ooP00ood003I4o@3no`800?on00;o003nood0
o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003nood0
03M<o@05olK6ool0o_l50?ooa/Koo@05oo_kool0o_l50?oono_oo005oo_kool0
o_l50?oono_oo@05oo_kool0o_l50?oono_oo@00KTCm003ooLH4ooo6ooomaP3o
o@00oogk1?oonooooO/0oo`00?omn`Cooo_ooogk0?om003ooO/4oookooomn`3o
o@0082Cm003om<H0ood00?odn`3oo000ooCk0?om003om?/0ood006DTo@00ooC6
0?om003om?/0oo`00?odn`3oo@00ooCk0?om000a9?d00?odaP3oo@00ooCk0?ol
003om?/0ood00?odn`3oo@00;T3m003oo<H3olKooog60?om003oo?/3oo_ooogk
0?ol003oo?/3oo_ooogk0?om003oo?/3oo_ooogk0?om001cC?d00_o6a_ko0`3o
003no`76ood00_oknoko0`3o003no`7koo`00_oknoko0`3o003no`7kood00_ok
noko0`3o003no`7kood0020ho@3nood00?ol007oood0o_om003oo001oool0?ko
o@00oo`00Oooo@3nood00?ol007oood00204/0003@B`000d9=H00?on003oo000
ooh00?om003ooP00oo`00?on003oo@0082CF0?ko0P00ooh00_l00?koo@3no`80
0?on00;o003nood003<XeP05oo_kool0o_l50?oono_oo@05ojJVool0o_l50?oo
YZKoo@00>2CF003ooO/4oookooomn`3oo@00oofV1?ooY_oooJH0ood003DDeP00
ooCk0?om003om:H0ood000dDeP00ooCk0?om003om:H0ood007<DeP00ooCk0?om
003om:H0ood0030ReP00oock0ookooomn`3oo@00oobV0onVooomYP3oo@00KRSF
00;ono_no`<0o`00o_l1noom00;oYZKno`<0o`00o_l1Y_om001d7]H0o_om003o
o001ooom0?koo@00oo`00Oooo@00=`B`000a1;0000e4o@00ooh00?ol003ooP00
ood00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00
ood002i4o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh0
0_l00?koo@3no`800?on00;o003nood000e<o@05ojJVool0o_l50?ooYZKoo@05
ojJVool0o_l50?ooYZKoo005obLWool0o_l50?oo9bOoo@05oo_kool0o_l50?oo
no_oo@00HTCm003ooJH4oonVooomYP3oo@00oofV1?ooY_oooJH0oo`00?om9`Co
obOooodW0?om003ooO/4oookooomn`3oo@00KRCm003om:H0ood00?odYP3oo000
oo@W0?om003om?/0ood0034To@00ooBV0?om003om:H0oo`00?od9`3oo@00ooCk
0?om000P9?d00?odYP3oo@00ooBV0?ol003om2L0ood00?odn`3oo@003D3m003o
o:H3ojKooofV0?om003oo:H3ojKooofV0?ol003oo2L3obOooodW0?om003oo?/3
oo_ooogk0?om000=C?d00_nVY_ko0`3o003no`6Vood00_nVY_ko0`3o003no`6V
oo`00_lW9oko0`3o003no`4Wood00_oknoko0`3o003no`7kood002hho@3nood0
0?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007oood0
03H4/000>0B`000c1;0005<do@00ooh00?ol003ooP00onT00?on003oo000ooh0
0?om003ooP00oo`00?on003oo@00@cCm0?ko0P00ooh00_l00?koj@3no`800?on
00;o003nood0o_l2003ooP02o`00o_om000a>_d01Ooknooo0?ko1@3ooo_konT0
1OoEeOoo0?ko1@3oomGEood01Ooknooo0?ko1@3ooo_kood007@do@00oogk1?oo
nooooO/0onT00?ome@CoomGooogE0?om003ooO/4oookooomn`3oo@003Acm003o
m?/0onT00?ode@3oo@00ooCk0?om000P7?d00?odn`3oj@00ooCE0?om003om?/0
ood004`ao@00oock0ookooomn`3oj@00oocE0ooEooome@3oo@00oock0ookooom
n`3oo@00=C[m00;ono_no`<0o`00o_l1nooY00;oeMGno`<0o`00o_l1eOom00;o
no_no`<0o`00o_l1noom000f:od0o_om003oo001oooY0?koo@00oo`00Oooo@3n
ood00?ol007oood003@4/000LPB`001d1;00030djP00ooh00?ol003ooP00oo`0
0?on003oo000ooh00?om003ooP00oo`00?on003oo@00ISCZ0?ko0P00ooh00_l0
0?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_om000`>^X01Ooknooo
0?ko1@3ooo_koo`01OnVY_oo0?ko1@3oojJVood01Ooknooo0?ko1@3ooo_kood0
020djP00oogk1?oonooooO/0oo`00?omYPCoojKooofV0?om003ooO/4oookooom
n`3oo@00C1cZ003om?/0oo`00?odYP3oo@00ooCk0?om000a7>X00?odn`3oo000
ooBV0?om003om?/0ood000dLjP00ooCk0?ol003om:H0ood00?odn`3oo@00=37Z
003oo?/3oo_ooogk0?ol003oo:H3ojKooofV0?om003oo?/3oo_ooogk0?om001@
>^X00_oknoko0`3o003no`7koo`00_nVY_ko0`3o003no`6Vood00_oknoko0`3o
003no`7kood004d[jP3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`0
0Oooo@00H@B`001U1;00020djP00ooh00?ol003ooP00oo`00?on003oo000ooh0
0?om003ooP00oo`00?on003oo@00=CCZ0?ko0P00ooh00_l00?koo03no`800?on
00;o003nood0o_l2003ooP02o`00o_om000f>^X01On6Q_oo0?ko1@3oohJ6oo`0
1Ooknooo0?ko1@3ooo_kood01OlW9ooo0?ko1@3oobLWood003@djP00oof61?oo
Q_oooHH0oo`00?omn`Cooo_ooogk0?om003ooBL4oolWooom9`3oo@0081cZ003o
m8H0oo`00?odn`3oo@00oo@W0?om000g7>X00?odQP3oo000ooCk0?om003om2L0
ood004dLjP00ooB60?ol003om?/0ood00?od9`3oo@00=C7Z003oo8H3ohKooof6
0?ol003oo?/3oo_ooogk0?om003oo2L3obOooodW0?om001/>^X00_n6Q_ko0`3o
003no`66oo`00_oknoko0`3o003no`7kood00_lW9oko0`3o003no`4Wood000d[
jP3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00L0B`000^
1;00030To@00ooh00?ol003ooP00ood00?on003oo000ooh00?oF001<9?d0o_l2
003ooP02o`00o_om0?ko0P00ooh00_l00?koeP00;RSm00Gono_oo`3no`D0oook
noom00Goe=Coo`3no`D0oooDe?oF000=9?d00?omn`Cooo_ooogk0?om003ooM@4
oooDooome03oeP00=aCm003om?/0ood00?ode03oeP00<1Cm003om?/0ood00?od
e03oeP00IQCm003om?/0ood00?ode03oeP00<B;m003oo?/3oo_ooogk0?om003o
o=@3omCooogD0?oF001K:?d00_oknoko0`3o003no`7kood00_oDe?ko0`3o003n
o`7DomH000dNo@3nood00?ol007oood0o_om003oo001oooF000`1;0000d4/000
83Cm003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh0
0?oZ001d=?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on
00;o003nonX003@jo@05oc<cool0o_l50?oo<c?oo@05ooKfool0o_l50?oom_Ko
o005oo_kool0o_l50?oono_ojP00ASCm003ooC<4oolcooom<`3oo@00oogf1?oo
m_oooOH0oo`00?omn`Cooo_ooogk0?oZ000d7?d00?od<`3oo@00ooCf0?ol003o
m?/0onX003DLo@00oo@c0?om003om?H0oo`00?odn`3ojP00=acm003om3<0ood0
0?odmP3oo000ooCk0?oZ000f<Od00?ol<`?o<ooooC<0ood00?olmP?om_oooOH0
oo`00?oln`?onooooO/0onX003@jo@02oc<co_l30?l00?ko0C?oo@02ooKfo_l3
0?l00?ko0OKoo002oo_ko_l30?l00?ko0O_ojP00KR_m0?koo@00oo`00Oooo@3n
ood00?ol007ooo`0o_om003oo001oooZ000=1;0007@4/000=DCm003ooP00oo`0
0?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`0
0?on003oo@00=DCm0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2
003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00>Dcm00GoQXKoo`3no`D0oon6
Q_om00Gono_oo`3no`D0oooknool00GoIFGoo`3no`D0oomUIOom00Go1PKoo`3n
o`D0ool61_om000PA?d00?omQPCoohKooof60?om003ooO/4oookooomn`3oo000
ooeU1?ooIOoooFD0ood00?om1PCoo`Koood60?om001<9?d00?odQP3oo@00ooCk
0?ol003om6D0ood00?od1P3oo@00=2Cm003om8H0ood00?odn`3oo000ooAU0?om
003om0H0ood006TTo@00ooB60?om003om?/0oo`00?odI@3oo@00oo@60?om000a
@?d00?olQP?oQ_oooHH0ood00?oln`?onooooO/0oo`00?olI@?oIOoooFD0ood0
0?ol1P?o1_ooo@H0ood005]<o@02ohJ6o_l30?l00?ko0HKoo@02oo_ko_l30?l0
0?ko0O_oo002ofEUo_l30?l00?ko0FGoo@02o`H6o_l30?l00?ko0@Koo@00ICSm
0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`0
0Oooo@00I@B`000P1;0004`djP00ooh00?ol003ooP00oo`00?on003oo000ooh0
0?om003ooP00oo`00?on003oo@00<CCZ0?ko0P00ooh00_l00?koo03no`800?on
00;o003nood0o_l2003ooP02o`00o_om000c>^X01Ooknooo0?ko1@3ooo_koo`0
1On6Q_oo0?ko1@3oohJ6ood01On6Q_oo0?ko1@3oohJ6ood003PdjP00oogk1?oo
nooooO/0oo`00?omQPCoohKooof60?om003ooHH4oon6ooomQP3oo@00IQcZ003o
m?/0oo`00?odQP3oo@00ooB60?om000P7>X00?odn`3oo000ooB60?om003om8H0
ood0030LjP00ooCk0?ol003om8H0ood00?odQP3oo@00L37Z003oo?/3oo_ooogk
0?ol003oo8H3ohKooof60?om003oo8H3ohKooof60?om001Q>^X00_oknoko0`3o
003no`7koo`00_n6Q_ko0`3o003no`66ood00_n6Q_ko0`3o003no`66ood003T[
jP3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00<`B`000i
1;0003M4o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`0
0?on003oo@00ooh00?ol003ooP00ood003=4o@3no`800?on00;o003nood0o_l2
003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003nood000e<
o@05olK6ool0o_l50?ooa/Koo@05oo_kool0o_l50?oono_oo005olK6ool0o_l5
0?ooa/Koo@05ohJ6ool0o_l50?ooQXKoo@00LTCm003ooLH4ooo6ooomaP3oo@00
oogk1?oonooooO/0oo`00?omaPCoolKooog60?om003ooHH4oon6ooomQP3oo@00
<bCm003om<H0ood00?odn`3oo000ooC60?om003om8H0ood006PTo@00ooC60?om
003om?/0oo`00?odaP3oo@00ooB60?om000P9?d00?odaP3oo@00ooCk0?ol003o
m<H0ood00?odQP3oo@00=D3m003oo<H3olKooog60?om003oo?/3oo_ooogk0?ol
003oo<H3olKooog60?om003oo8H3ohKooof60?om000cC?d00_o6a_ko0`3o003n
o`76ood00_oknoko0`3o003no`7koo`00_o6a_ko0`3o003no`76ood00_n6Q_ko
0`3o003no`66ood003Dho@3nood00?ol007oood0o_om003oo001oool0?koo@00
oo`00Oooo@3nood00?ol007oood003@4/0003@B`001TA?d00?on003oo000ooh0
0?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh0
0?om001RA?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on
00;o003nood0o_l2003ooP02o`00o_om000=C?d01Ooknooo0?ko1@3ooo_kood0
1Om6A_oo0?ko1@3oodI6oo`01OlD5?oo0?ko1@3ooa@Dood01Ooknooo0?ko1@3o
oo_kood00654o@00oogk1?oonooooO/0ood00?omAPCoodKoooe60?ol003ooA@4
oolDooom503oo@00oogk1?oonooooO/0ood0020To@00ooCk0?om003om4H0oo`0
0?od503oo@00ooCk0?om000i9?d00?odn`3oo@00ooA60?ol003om1@0ood00?od
n`3oo@00=bCm003om?/0ood00?odAP3oo000oo@D0?om003om?/0ood00210o@00
oock0ookooomn`3oo@00ooa60om6ooomAP3oo000oo`D0olDooom503oo@00oock
0ookooomn`3oo@00=Dcm00;ono_no`<0o`00o_l1noom00;oATKno`<0o`00o_l1
A_ol00;o51Cno`<0o`00o_l15?om00;ono_no`<0o`00o_l1noom000^>?d0o_om
003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom
001R1;0003@4/000HCCm003ooP00oo`00?on003oo@00ooh00?ol003ooP00onT0
0?on003oo000ooh00?om001X=?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l0
0?koj@3no`800?on00;o003nood0030jo@05oo_kool0o_l50?oono_oo@05oo_k
ool0o_l50?oono_oj@05oo_kool0o_l50?oono_oo@0083Cm003ooO/4oookooom
n`3oo@00oogk1?oonooooO/0onT00?omn`Cooo_ooogk0?om001]7?d00?odn`3o
o@00ooCk0?oY003om?/0ood006LLo@00ooCk0?om003om?/0onT00?odn`3oo@00
81cm003om?/0ood00?odn`3oj@00ooCk0?om000g<Od00?oln`?onooooO/0ood0
0?oln`?onooooO/0onT00?oln`?onooooO/0ood000djo@02oo_ko_l30?l00?ko
0O_oo@02oo_ko_l30?l00?ko0O_oj@02oo_ko_l30?l00?ko0O_oo@00;R_m0?ko
o@00oo`00Oooo@3nood00?ol007oonT0o_om003oo001ooom000P1;000304/000
LcCZ003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh0
0?om001e=>X0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on
00;o003nood003TjjP05oo_kool0o_l50?oono_oo005obLWool0o_l50?oo9bOo
o@05oo_kool0o_l50?oono_oo@00K3CZ003ooO/4oookooomn`3oo000oodW1?oo
9ooooBL0ood00?omn`Cooo_ooogk0?om000=7>X00?odn`3oo000oo@W0?om003o
m?/0ood0070LjP00ooCk0?ol003om2L0ood00?odn`3oo@00;QcZ003om?/0oo`0
0?od9`3oo@00ooCk0?om000`<NX00?oln`?onooooO/0oo`00?ol9`?o9ooooBL0
ood00?oln`?onooooO/0ood004`jjP02oo_ko_l30?l00?ko0O_oo002obLWo_l3
0?l00?ko0BOoo@02oo_ko_l30?l00?ko0O_oo@00;R_Z0?koo@00oo`00Oooo03n
ood00?ol007oood0o_om003oo001ooom000=1;0003L4/000=CCm003ooP00oo`0
0?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?oZ001d=?d0o_l2
003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nonX003Hj
o@05oo_kool0o_l50?oono_oo@05oo_kool0o_l50?oono_oo005ojJVool0o_l5
0?ooYZKojP0083Cm003ooO/4oookooomn`3oo@00oogk1?oonooooO/0oo`00?om
YPCoojKooofV0?oZ000e7?d00?odn`3oo@00ooCk0?ol003om:H0onX003@Lo@00
ooCk0?om003om?/0oo`00?odYP3ojP003Acm003om?/0ood00?odn`3oo000ooBV
0?oZ000i<Od00?oln`?onooooO/0ood00?oln`?onooooO/0oo`00?olYP?oY_oo
oJH0onX003<jo@02oo_ko_l30?l00?ko0O_oo@02oo_ko_l30?l00?ko0O_oo002
ojJVo_l30?l00?ko0JKojP00KB_m0?koo@00oo`00Oooo@3nood00?ol007ooo`0
o_om003oo001oooZ000^1;000644/000<4Cm003ooP00oo`00?on003oo@00ooh0
0?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo@00KTCm
0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2003ooP02o`00o_om
0?ko0P00ooh00_l00?koo@003Dcm00Gono_oo`3no`D0oooknoom00Gono_oo`3n
o`D0oooknool00Gono_oo`3no`D0oooknoom00Gono_oo`3no`D0oooknoom000a
A?d00?omn`Cooo_ooogk0?om003ooO/4oookooomn`3oo000oogk1?oonooooO/0
ood00?omn`Cooo_ooogk0?om000f9?d00?odn`3oo@00ooCk0?ol003om?/0ood0
0?odn`3oo@00>BCm003om?/0ood00?odn`3oo000ooCk0?om003om?/0ood003@T
o@00ooCk0?om003om?/0oo`00?odn`3oo@00ooCk0?om000=@?d00?oln`?onooo
oO/0ood00?oln`?onooooO/0oo`00?oln`?onooooO/0ood00?oln`?onooooO/0
ood006M<o@02oo_ko_l30?l00?ko0O_oo@02oo_ko_l30?l00?ko0O_oo002oo_k
o_l30?l00?ko0O_oo@02oo_ko_l30?l00?ko0O_oo@00KcSm0?koo@00oo`00Ooo
o@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00<`B`001d
1;0006T4/000>0B`000c1;0002h4/0003@B`000^1;000204/000L`B`000`0001
00X0@P0a0SH1CP0d0DP0O@8W0;H00@0:0DP0O@8W0;H0V81B0000004o05400000
000000180000B0000000200100P000000;2A;000000002C00000o`00oooooooo
007oooooc<`00_oloobZZ003ooooofIV00@g8cLS=b<01GHVMRIf9P06]BZe:[DZ
00Od;_@^m2h02000oobZZ009>a<k4c/C00Yj5gXGNQL02kTJ^AZi6P0<n1kh7_PN
00d00?oloo`03UEDoocoo00?ZZSoo?ol013ooiVI<c<04OooVIT0000BoomVI_oo
01?oofIVc<`053/C>a<k4`0ENQMj5gXG01Ji6[TJ^AX05oPNn1kh7P0H003oo?ol
01To0cl3?`<06Wh7OPMn1`0K_@^m2kd;01cl3_`>o0h07EED0000000NZZP00000
01ooo00000008?oo002IV@0Qool006IV02;oo`00<c<08ooo0000000T?`<o0cl3
02En1gh7OPL09[d;_@^m2`0Wo0kl3_`>02P3l0?`0o00:D;c@_=2l`0ZPON1mh7g
02_0nl3k`?/0;000001EE00]EE@005ED02jZZ000EE@0;ool001EE00`c<bIVOoo
037<c9VIc<`0</c<VIVIV@0c0o03l0?`03A2ld;c@_<0=H7gPON1m`0f`?_0nl3k
03L00000EE@0>0OP1n07h00iA^A6i4KT03Z5ihGWQNL0>lC[a>_4j`0l00000:ZX
03eEE000ZZP0?ZZX002ZZ00ooo`00:ZX043<c3<c<c<0@Lc<<c<00012c<`00?oo
04<7h0OP1n00A4KTA^A6i015QNN5ihGW04K4jlC[a>/0A`00002ZZ0182m0;d0_@
04U:e4[DB]@0BXWHRMR9f01;b=_8flSK04`00000oo`0CEED003oo01>ZZP00?ol
04ooo000oo`0D9VIc<bIV@1AVIW<c6IV05:IVLc<<c<0D`_@2m0;d01DB]A:e4[D
05F9f8WHRMP0E/SKb=_8f`1G00000?ol05P?`0o03l00FDk4C/A>a01JSLR=b8g8
05_<c<c<c<`0G000EE@0001MEEAEE00005jZZ5ED0000GoolEE@0001PVITc<ooo
066IVC<cc<`0HYVI<c>IV@1S3l0?`0o006A>a4k4C/@0IHg8SLR=b01Vc<c<c<c<
06L005ED0000J1>a4k4C/@1YD[AB]5:d06ZA^96hTKP0Jm2ld;c@_01/001EE5ED
06eEE5EDEE@0KZZXEEAEE01_ooaEE5ED071VI_oo<c<0LFIVool0001bIVK<c?oo
07<C/A>a4k40M5:dD[AB]01eTKRA^96h07K@_=2ld;`0M`00EEAEE01h5j4GXANQ
07UFYEJUEZD0NYFXUJREZ01ke:cD[=B/07`005EDZZP0OEEDEEBZZ01nZZQEE:ZX
07ooo5EDZZP0P6IVIVJIV@21IVIVIVIV089VIVIV<c<0PaNQ5j4GX@24EZEFYEJU
08FEZ9FXUJP0Q]B/e:cD[027001EE:ZX08PKTA^A6i40REZEFYEJU@2:VIVIVIVI
08_HW=RLf9`0S000EECoo02=EEAEE?ol08jZZ5EDoo`0SoolEECoo02@<c?ooooo
094c<oooc<`0TS<coonIV@2C6i4KTA^A09AJUEZEFYD0UIVIVIVIV@2Ff9cHW=RL
09L005EDoo`0V1n17h4OP@2IGXENQEj509ZMRIf9WHT0Vmb<g8cLS02L002ZZ000
09eEE:ZX0000WZZXZZP0002OoobZZ0000:0c<iVI<c<0XC<cVIT0002R<c=VI_oo
0:<OPAn17h40Y5j5GXENQ@2UWHVMRIf90:KLS=b<g8`0Y`00ZZP0002X8g8SLR=b
0:URMF9eHWD0ZZ5iXGVQN@2[h7gPON1m0:`00:ZXEE@0[EEDZZQEE02^ZZRZZ5ED
0:ooo:ZXEE@0/3<c002IV@2a<c<006IV0;8c<`00<c<0/b=b8g8SLP2dHWERMF9e
0;FQNJ5iXGT0]^1mh7gPO@2g002ZZ5ED0;PWHRMR9f80^FIVIVIVIP2jYFVUJJEY
0;_TKNA]i6d0_000ZZRZZ02mEEBZZ:ZX0;jZZ:ZXZZP0_oolZZRZZ030002IVOoo
0<4009VIc<`0`P00VIVIV@339f8WHRMR0<AVIVIVIVH0aJEYYFVUJ@36i6gTKNA]
0<L00:ZXZZP0b2]B:e8[DP39JUIZEVYF0<ZYFJUIZET0bnQMj5gXG@3<002ZZ?ol
0<eEE:ZXoo`0cZZXZZSoo03?oobZZ?ol0=0003<c<c<0d@00<c<0003B00000?oo
0=<[DR]B:e80e6YFJUIZEP3EZEVYFJUI0=KXGNQMj5d0e`00ZZSoo03H;d8_@Rm2
0=U^AVi6KTH0fZe:[DZ]BP3Kk4g/CNa=0=`00?ol0000gEEDoo`0003NZZSoo000
0=ooo?ol0000h14A0000003Q003^kP000>800=gM0000hbm2;d8_@P3TKTI^AVi6
0>F]BZe:[DX0i^a=k4g/C@3W003oo0000>Pc<c<c<c<0jG8fLSIb=P3Z/CZa>[4j
0>_`?_0nl3h0k000ooaEE03]EECoo5ED0>jZZ?olEE@0koolooaEE03`000007Mg
0?400000EED0lP000014A03c<c<c<c<c0?Ab=W8fLSH0mK4j/CZa>P3fl3k`?_0n
0?L00?olEE@0n3LS=b<g8`3iMRIf9WHV0?Ze:[DZ]BX0no@^m2kd;P3l003oo:ZX
0?eEE?olZZP0oZZXoobZZ03o000000000000004o0541B01m0RL0]P0T1;0000d4
/000>0B`000^1;000304/000<`B`000P1;0003D4/00080B`001e1;0007<To@00
ooh00?ol003ooP00ood00?on003oo000ooh00?oF001d9?d0o_l2003ooP02o`00
o_om0?ko0P00ooh00_l00?koeP00<BSm00GoUYKoo`3no`D0oonFU_om00Gono_o
o`3no`D0oooknooF000^9?d00?omUPCooiKooofF0?om003ooO/4oookooomn`3o
eP00<ACm003om9H0ood00?odn`3oeP00=ACm003om9H0ood00?odn`3oeP00=1Cm
003om9H0ood00?odn`3oeP003B;m003oo9H3oiKooofF0?om003oo?/3oo_ooogk
0?oF001e:?d00_nFU_ko0`3o003no`6Food00_oknoko0`3o003no`7komH003HN
o@3nood00?ol007oood0o_om003oo001oooF001S1;0005d4/0003CCm003ooP00
oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?oZ000P=?d0
o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nonX0
06Pjo@05oo_kool0o_l50?oono_oo@05obLWool0o_l50?oo9bOoo005oo_kool0
o_l50?oono_ojP00KcCm003ooO/4oookooomn`3oo@00oodW1?oo9ooooBL0oo`0
0?omn`Cooo_ooogk0?oZ000P7?d00?odn`3oo@00oo@W0?ol003om?/0onX004`L
o@00ooCk0?om003om2L0oo`00?odn`3ojP00C1cm003om?/0ood00?od9`3oo000
ooCk0?oZ000P<Od00?oln`?onooooO/0ood00?ol9`?o9ooooBL0oo`00?oln`?o
nooooO/0onX000djo@02oo_ko_l30?l00?ko0O_oo@02obLWo_l30?l00?ko0BOo
o002oo_ko_l30?l00?ko0O_ojP00=2_m0?koo@00oo`00Oooo@3nood00?ol007o
oo`0o_om003oo001oooZ000P1;0006P4/000;TCm003ooP00oo`00?on003oo@00
ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo@00
84Cm0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2003ooP02o`00
o_om0?ko0P00ooh00_l00?koo@00HDcm00Gono_oo`3no`D0oooknoom00Gono_o
o`3no`D0oooknool00Go9bOoo`3no`D0oolW9oom00Go9bOoo`3no`D0oolW9oom
000`A?d00?omn`Cooo_ooogk0?om003ooO/4oookooomn`3oo000oodW1?oo9ooo
oBL0ood00?om9`CoobOooodW0?om000c9?d00?odn`3oo@00ooCk0?ol003om2L0
ood00?od9`3oo@0082Cm003om?/0ood00?odn`3oo000oo@W0?om003om2L0ood0
020To@00ooCk0?om003om?/0oo`00?od9`3oo@00oo@W0?om000a@?d00?oln`?o
nooooO/0ood00?oln`?onooooO/0oo`00?ol9`?o9ooooBL0ood00?ol9`?o9ooo
oBL0ood003I<o@02oo_ko_l30?l00?ko0O_oo@02oo_ko_l30?l00?ko0O_oo002
obLWo_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOoo@00C3Sm0?koo@00oo`0
0Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00=@B`
001d1;0003I4o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00
oo`00?on003oo@00ooh00?ol003ooP00ood00214o@3no`800?on00;o003nood0
o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003nood0
03E<o@05obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOoo005oo_kool0
o_l50?oono_oo@05obLWool0o_l50?oo9bOoo@00=4Cm003ooBL4oolWooom9`3o
o@00oodW1?oo9ooooBL0oo`00?omn`Cooo_ooogk0?om003ooBL4oolWooom9`3o
o@003BCm003om2L0ood00?od9`3oo000ooCk0?om003om2L0ood003TTo@00oo@W
0?om003om2L0oo`00?odn`3oo@00oo@W0?om000c9?d00?od9`3oo@00oo@W0?ol
003om?/0ood00?od9`3oo@00KD3m003oo2L3obOooodW0?om003oo2L3obOooodW
0?ol003oo?/3oo_ooogk0?om003oo2L3obOooodW0?om000^C?d00_lW9oko0`3o
003no`4Wood00_lW9oko0`3o003no`4Woo`00_oknoko0`3o003no`7kood00_lW
9oko0`3o003no`4Wood0064ho@3nood00?ol007oood0o_om003oo001oool0?ko
o@00oo`00Oooo@3nood00?ol007oood00304/000KPB`000==?d00?on003oo000
ooh00?oY003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood0034do@3no`80
0?on00;o003nonT0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00=S[m
00Gono_oo`3no`D0oooknooY00Gono_oo`3no`D0oooknoom00Gono_oo`3no`D0
oooknoom000i=?d00?omn`Cooo_ooogk0?oY003ooO/4oookooomn`3oo@00oogk
1?oonooooO/0ood003@Lo@00ooCk0?oY003om?/0ood00?odn`3oo@003Acm003o
m?/0onT00?odn`3oo@00ooCk0?om001W7?d00?odn`3oj@00ooCk0?om003om?/0
ood006Hao@00oock0ookooomn`3oj@00oock0ookooomn`3oo@00oock0ookooom
n`3oo@00=C[m00;ono_no`<0o`00o_l1nooY00;ono_no`<0o`00o_l1noom00;o
no_no`<0o`00o_l1noom000=:od0o_om003oo001oooY0?koo@00oo`00Oooo@3n
ood00?ol007oood007@4/0003@B`001S=?d00?on003oo000ooh00?om003ooP00
oo`00?on003oo000ooh00?ol003ooP00onX0020do@3no`800?on00;o003nood0
o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?kojP003C[m00Gono_oo`3no`D0
oooknoom00Go9bOoo`3no`D0oolW9ool00Gono_oo`3no`D0oooknooZ001X=?d0
0?omn`Cooo_ooogk0?om003ooBL4oolWooom9`3oo000oogk1?oonooooO/0onX0
03<Lo@00ooCk0?om003om2L0oo`00?odn`3ojP00=Qcm003om?/0ood00?od9`3o
o000ooCk0?oZ000^7?d00?odn`3oo@00oo@W0?ol003om?/0onX0030ao@00oock
0ookooomn`3oo@00oo`W0olWooom9`3oo000oock0ookooomn`3ojP00Lc[m00;o
no_no`<0o`00o_l1noom00;o9bOno`<0o`00o_l19ool00;ono_no`<0o`00o_l1
nooZ000P:od0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oonX0
0784/000;PB`001Q5<<00?on003oo000ooh00?om001`5<<0o_l2003ooP02o`00
o_om000h5/<01OlW9ooo0?ko1@3oobLWood003<D``00oodW1?oo9ooooBL0ood0
02h<``00oo@W0?om000a3<<00?od9`3oo@00;Pc3003om2L0ood006<C``00oo`W
0olWooom9`3oo@00JAK300;o9bOno`<0o`00o_l19oom000`4L<0o_om003oo001
ooom000=1;0003P4/000;TCm003ooP00oo`00?on003oo@00ooh00?ol003ooP00
oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo@00<4Cm0?ko0P00ooh0
0_l00?koo@3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh0
0_l00?koo@00<dcm00Golo?oo`3no`D0ooocloom00Go9bOoo`3no`D0oolW9ool
00Gono_oo`3no`D0oooknoom00Gono_oo`3no`D0oooknoom000PA?d00?oml`Co
oo?ooogc0?om003ooBL4oolWooom9`3oo000oogk1?oonooooO/0ood00?omn`Co
oo_ooogk0?om000e9?d00?odl`3oo@00oo@W0?ol003om?/0ood00?odn`3oo@00
82Cm003om?<0ood00?od9`3oo000ooCk0?om003om?/0ood0078To@00ooCc0?om
003om2L0oo`00?odn`3oo@00ooCk0?om000P@?d00?oll`?olooooO<0ood00?ol
9`?o9ooooBL0oo`00?oln`?onooooO/0ood00?oln`?onooooO/0ood006m<o@02
oo?co_l30?l00?ko0O?oo@02obLWo_l30?l00?ko0BOoo002oo_ko_l30?l00?ko
0O_oo@02oo_ko_l30?l00?ko0O_oo@00>3Sm0?koo@00oo`00Oooo@3nood00?ol
007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo@00=`B`000P1;0003A4o@00
ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00
ooh00?ol003ooP00ood007=4o@3no`800?on00;o003nood0o_l2003ooP02o`00
o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003nood003A<o@05ooGeool0
o_l50?oomOGoo@05obLWool0o_l50?oo9bOoo005oo_kool0o_l50?oono_oo@05
obLWool0o_l50?oo9bOoo@003DCm003ooOD4oooeooomm@3oo@00oodW1?oo9ooo
oBL0oo`00?omn`Cooo_ooogk0?om003ooBL4oolWooom9`3oo@00CBCm003om?D0
ood00?od9`3oo000ooCk0?om003om2L0ood0064To@00ooCe0?om003om2L0oo`0
0?odn`3oo@00oo@W0?om001U9?d00?odm@3oo@00oo@W0?ol003om?/0ood00?od
9`3oo@00843m003oo?D3ooGoooge0?om003oo2L3obOooodW0?ol003oo?/3oo_o
oogk0?om003oo2L3obOooodW0?om000eC?d00_oemOko0`3o003no`7eood00_lW
9oko0`3o003no`4Woo`00_oknoko0`3o003no`7kood00_lW9oko0`3o003no`4W
ood003Hho@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3n
ood00?ol007oood003@4/00080B`000gA?d00?on003oo000ooh00?om003ooP00
oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?om001=A?d0
o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0
o_l2003ooP02o`00o_om000^C?d01OlW9ooo0?ko1@3oobLWood01OlW9ooo0?ko
1@3oobLWoo`01OlW9ooo0?ko1@3oobLWood01Ooknooo0?ko1@3ooo_kood002E4
o@00oodW1?oo9ooooBL0ood00?om9`CoobOooodW0?ol003ooBL4oolWooom9`3o
o@00oogk1?oonooooO/0ood0030To@00oo@W0?om003om2L0oo`00?od9`3oo@00
ooCk0?om001T9?d00?od9`3oo@00oo@W0?ol003om2L0ood00?odn`3oo@00=BCm
003om2L0ood00?od9`3oo000oo@W0?om003om?/0ood002i0o@00oo`W0olWooom
9`3oo@00oo`W0olWooom9`3oo000oo`W0olWooom9`3oo@00oock0ookooomn`3o
o@00<Dcm00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19ool00;o9bOn
o`<0o`00o_l19oom00;ono_no`<0o`00o_l1noom000c>?d0o_om003oo001ooom
0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom000h1;0003L4
/00083Cm003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000
ooh00?oZ000P=?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`80
0?on00;o003nonX0020jo@05oj>Sool0o_l50?ooXj?oo@05oo_kool0o_l50?oo
no_oo005oiJFool0o_l50?ooUYKojP003CCm003ooJ<4oonSooomX`3oo@00oogk
1?oonooooO/0oo`00?omUPCooiKooofF0?oZ000P7?d00?odX`3oo@00ooCk0?ol
003om9H0onX002hLo@00ooBS0?om003om?/0oo`00?odUP3ojP00<acm003om:<0
ood00?odn`3oo000ooBF0?oZ000e<Od00?olX`?oXooooJ<0ood00?oln`?onooo
oO/0oo`00?olUP?oU_oooIH0onX002hjo@02oj>So_l30?l00?ko0J?oo@02oo_k
o_l30?l00?ko0O_oo002oiJFo_l30?l00?ko0IKojP00<B_m0?koo@00oo`00Ooo
o@3nood00?ol007ooo`0o_om003oo001oooZ000=1;000204/000FcCm003ooP00
oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?oZ001Y=?d0
o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nonX0
00djo@05obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOoo005obLWool0
o_l50?oo9bOojP00<3Cm003ooBL4oolWooom9`3oo@00oodW1?oo9ooooBL0oo`0
0?om9`CoobOooodW0?oZ001d7?d00?od9`3oo@00oo@W0?ol003om2L0onX0030L
o@00oo@W0?om003om2L0oo`00?od9`3ojP00Macm003om2L0ood00?od9`3oo000
oo@W0?oZ000P<Od00?ol9`?o9ooooBL0ood00?ol9`?o9ooooBL0oo`00?ol9`?o
9ooooBL0onX0034jo@02obLWo_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOo
o002obLWo_l30?l00?ko0BOojP00IB_m0?koo@00oo`00Oooo@3nood00?ol007o
oo`0o_om003oo001oooZ001K1;0006P4/00080B`000h=?d00?on003oo000ooh0
0?om003ooP00oo`00?on003oj@00ooh00?ol003ooP00ood005<do@3no`800?on
00;o003nood0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo@00<3[m00Go
9bOoo`3no`D0oolW9oom00Gono_oo`3no`D0oooknooY00Go9bOoo`3no`D0oolW
9oom001c=?d00?om9`CoobOooodW0?om003ooO/4oookooomn`3oj@00oodW1?oo
9ooooBL0ood0020Lo@00oo@W0?om003om?/0onT00?od9`3oo@00=Acm003om2L0
ood00?odn`3oj@00oo@W0?om000d<Od00?ol9`?o9ooooBL0ood00?oln`?onooo
oO/0onT00?ol9`?o9ooooBL0ood003<jo@02obLWo_l30?l00?ko0BOoo@02oo_k
o_l30?l00?ko0O_oj@02obLWo_l30?l00?ko0BOoo@00>B_m0?koo@00oo`00Ooo
o@3nood00?ol007oonT0o_om003oo001ooom000P1;0003<4/00080B`000a=?d0
0?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003ooP00onX0
05/do@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l0
0?kojP00Ic[m00Go9bOoo`3no`D0oolW9oom00Gono_oo`3no`D0oooknool00Go
no_oo`3no`D0oooknooZ000d=?d00?om9`CoobOooodW0?om003ooO/4oookooom
n`3oo000oogk1?oonooooO/0onX0034Lo@00oo@W0?om003om?/0oo`00?odn`3o
jP00=acm003om2L0ood00?odn`3oo000ooCk0?oZ000`7?d00?od9`3oo@00ooCk
0?ol003om?/0onX003@ao@00oo`W0olWooom9`3oo@00oock0ookooomn`3oo000
oock0ookooomn`3ojP00L3[m00;o9bOno`<0o`00o_l19oom00;ono_no`<0o`00
o_l1nool00;ono_no`<0o`00o_l1nooZ001c:od0o_om003oo001ooom0?koo@00
oo`00Oooo03nood00?ol007oonX00304/000KPB`001d=?d00?on003oo000ooh0
0?om003ooP00oo`00?on003oo000ooh00?ol003ooP00onX003Ldo@3no`800?on
00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?kojP00<C[m00Go
no_oo`3no`D0oooknoom00Gono_oo`3no`D0oooknool00Go9bOoo`3no`D0oolW
9ooZ000==?d00?omn`Cooo_ooogk0?om003ooO/4oookooomn`3oo000oodW1?oo
9ooooBL0onX002hLo@00ooCk0?om003om?/0oo`00?od9`3ojP003Acm003om?/0
ood00?odn`3oo000oo@W0?oZ001V7?d00?odn`3oo@00ooCk0?ol003om2L0onX0
078ao@00oock0ookooomn`3oo@00oock0ookooomn`3oo000oo`W0olWooom9`3o
jP00<C[m00;ono_no`<0o`00o_l1noom00;ono_no`<0o`00o_l1nool00;o9bOn
o`<0o`00o_l19ooZ001Y:od0o_om003oo001ooom0?koo@00oo`00Oooo03nood0
0?ol007oonX006`4/000L0B`000PA?d00?on003oo000ooh00?om003ooP00oo`0
0?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?om000=A?d0o_l2
003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2
003ooP02o`00o_om001^C?d01Ooknooo0?ko1@3ooo_kood01OlW9ooo0?ko1@3o
obLWoo`01Ooknooo0?ko1@3ooo_kood01Ooknooo0?ko1@3ooo_kood006i4o@00
oogk1?oonooooO/0ood00?om9`CoobOooodW0?ol003ooO/4oookooomn`3oo@00
oogk1?oonooooO/0ood003<To@00ooCk0?om003om2L0oo`00?odn`3oo@00ooCk
0?om000P9?d00?odn`3oo@00oo@W0?ol003om?/0ood00?odn`3oo@00=2Cm003o
m?/0ood00?od9`3oo000ooCk0?om003om?/0ood003Q0o@00oock0ookooomn`3o
o@00oo`W0olWooom9`3oo000oock0ookooomn`3oo@00oock0ookooomn`3oo@00
<dcm00;ono_no`<0o`00o_l1noom00;o9bOno`<0o`00o_l19ool00;ono_no`<0
o`00o_l1noom00;ono_no`<0o`00o_l1noom001_>?d0o_om003oo001ooom0?ko
o@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom001b1;0002h4/000
HBCm003ooP00oo`00?on003oeP00ooh00?ol003ooP00ood0070To@3no`800?on
00;o003nomH0o_l2003ooP02o`00o_om000i:?d01OlW9ooo0?ko1@3oobLWomH0
1Ooknooo0?ko1@3ooo_kood003<To@00oodW1?oo9ooooBL0omH00?omn`Cooo_o
oogk0?om000i5?d00?od9`3oeP00ooCk0?om000g5?d00?od9`3oeP00ooCk0?om
000c5?d00?od9`3oeP00ooCk0?om000=8_d00?ol9`?o9ooooBL0omH00?oln`?o
nooooO/0ood000dXo@02obLWo_l30?l00?ko0BOoeP02oo_ko_l30?l00?ko0O_o
o@00=1km0?koo@00oo`00OooeP3nood00?ol007oood007<4/00080B`000fA?d0
0?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood0
0?on003oo000ooh00?om000aA?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l0
0?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_om000aC?d01OlW9ooo
0?ko1@3oobLWood01Ooknooo0?ko1@3ooo_koo`01OlW9ooo0?ko1@3oobLWood0
1OnVY_oo0?ko1@3oojJVood002i4o@00oodW1?oo9ooooBL0ood00?omn`Cooo_o
oogk0?ol003ooBL4oolWooom9`3oo@00oofV1?ooY_oooJH0ood003@To@00oo@W
0?om003om?/0oo`00?od9`3oo@00ooBV0?om001R9?d00?od9`3oo@00ooCk0?ol
003om2L0ood00?odYP3oo@00M2Cm003om2L0ood00?odn`3oo000oo@W0?om003o
m:H0ood002i0o@00oo`W0olWooom9`3oo@00oock0ookooomn`3oo000oo`W0olW
ooom9`3oo@00oobV0onVooomYP3oo@00M4cm00;o9bOno`<0o`00o_l19oom00;o
no_no`<0o`00o_l1nool00;o9bOno`<0o`00o_l19oom00;oYZKno`<0o`00o_l1
Y_om000f>?d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0
o_om003oo001ooom000f1;0003D4/000<2CZ003ooP00oo`00?on003oj@00ooh0
0?ol003ooP00ood004`TjP3no`800?on00;o003nonT0o_l2003ooP02o`00o_om
000P:>X01OlW9ooo0?ko1@3oobLWonT01OlW9ooo0?ko1@3oobLWood006hTjP00
oodW1?oo9ooooBL0onT00?om9`CoobOooodW0?om000b5>X00?od9`3oj@00oo@W
0?om001S5>X00?od9`3oj@00oo@W0?om001S5>X00?od9`3oj@00oo@W0?om001]
8^X00?ol9`?o9ooooBL0onT00?ol9`?o9ooooBL0ood0034XjP02obLWo_l30?l0
0?ko0BOoj@02obLWo_l30?l00?ko0BOoo@00;QkZ0?koo@00oo`00Oooj@3nood0
0?ol007oood002h4/0003@B`000^A?d00?on003oo000ooh00?om003ooP00oo`0
0?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh00?om000=A?d0o_l2
003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2
003ooP02o`00o_om000cC?d01Ooknooo0?ko1@3ooo_kood01Ooknooo0?ko1@3o
oo_koo`01OlW9ooo0?ko1@3oobLWood01OnVY_oo0?ko1@3oojJVood005=4o@00
oogk1?oonooooO/0ood00?omn`Cooo_ooogk0?ol003ooBL4oolWooom9`3oo@00
oofV1?ooY_oooJH0ood0030To@00ooCk0?om003om?/0oo`00?od9`3oo@00ooBV
0?om001c9?d00?odn`3oo@00ooCk0?ol003om2L0ood00?odYP3oo@0082Cm003o
m?/0ood00?odn`3oo000oo@W0?om003om:H0ood003E0o@00oock0ookooomn`3o
o@00oock0ookooomn`3oo000oo`W0olWooom9`3oo@00oobV0onVooomYP3oo@00
=4cm00;ono_no`<0o`00o_l1noom00;ono_no`<0o`00o_l1nool00;o9bOno`<0
o`00o_l19oom00;oYZKno`<0o`00o_l1Y_om000c>?d0o_om003oo001ooom0?ko
o@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom000i1;000204/000
<cCm003ooP00oo`00?on003oj@00ooh00?ol003ooP00ood00?on003oo000ooh0
0?om001c=?d0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l00?koo@3no`800?on
00;o003nood0020jo@05obLWool0o_l50?oo9bOoj@05obLWool0o_l50?oo9bOo
o@05obLWool0o_l50?oo9bOoo@0083Cm003ooBL4oolWooom9`3oj@00oodW1?oo
9ooooBL0ood00?om9`CoobOooodW0?om000=7?d00?od9`3oj@00oo@W0?om003o
m2L0ood003@Lo@00oo@W0?oY003om2L0ood00?od9`3oo@0081cm003om2L0onT0
0?od9`3oo@00oo@W0?om000c<Od00?ol9`?o9ooooBL0onT00?ol9`?o9ooooBL0
ood00?ol9`?o9ooooBL0ood003Pjo@02obLWo_l30?l00?ko0BOoj@02obLWo_l3
0?l00?ko0BOoo@02obLWo_l30?l00?ko0BOoo@00=B_m0?koo@00oo`00Oooj@3n
ood00?ol007oood0o_om003oo001ooom001Y1;000204/0003DCm003ooP00oo`0
0?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`0
0?on003oo@00KTCm0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2
003ooP02o`00o_om0?ko0P00ooh00_l00?koo@00KTcm00Gono_oo`3no`D0oook
noom00Go9bOoo`3no`D0oolW9ool00GoYZKoo`3no`D0oonVY_om00GoQXKoo`3n
o`D0oon6Q_om000cA?d00?omn`Cooo_ooogk0?om003ooBL4oolWooom9`3oo000
oofV1?ooY_oooJH0ood00?omQPCoohKooof60?om000P9?d00?odn`3oo@00oo@W
0?ol003om:H0ood00?odQP3oo@00=2Cm003om?/0ood00?od9`3oo000ooBV0?om
003om8H0ood003PTo@00ooCk0?om003om2L0oo`00?odYP3oo@00ooB60?om000c
@?d00?oln`?onooooO/0ood00?ol9`?o9ooooBL0oo`00?olYP?oY_oooJH0ood0
0?olQP?oQ_oooHH0ood006m<o@02oo_ko_l30?l00?ko0O_oo@02obLWo_l30?l0
0?ko0BOoo002ojJVo_l30?l00?ko0JKoo@02ohJ6o_l30?l00?ko0HKoo@00ICSm
0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`0
0Oooo@00<0B`001S1;0006E4o@00ooh00?ol003ooP00ood00?on003oo000ooh0
0?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood003=4o@3no`800?on
00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on
00;o003nood003Q<o@05obLWool0o_l50?oo9bOoo@05oiJFool0o_l50?ooUYKo
o005oo_kool0o_l50?oono_oo@05oo_kool0o_l50?oono_oo@003DCm003ooBL4
oolWooom9`3oo@00oofF1?ooU_oooIH0oo`00?omn`Cooo_ooogk0?om003ooO/4
oookooomn`3oo@00;RCm003om2L0ood00?odUP3oo000ooCk0?om003om?/0ood0
00dTo@00oo@W0?om003om9H0oo`00?odn`3oo@00ooCk0?om001Y9?d00?od9`3o
o@00ooBF0?ol003om?/0ood00?odn`3oo@00J43m003oo2L3obOooodW0?om003o
o9H3oiKooofF0?ol003oo?/3oo_ooogk0?om003oo?/3oo_ooogk0?om000PC?d0
0_lW9oko0`3o003no`4Wood00_nFU_ko0`3o003no`6Foo`00_oknoko0`3o003n
o`7kood00_oknoko0`3o003no`7kood007<ho@3nood00?ol007oood0o_om003o
o001oool0?koo@00oo`00Oooo@3nood00?ol007oood00344/0003@B`000^=?d0
0?on003oo000ooh00?om003ooP00oo`00?on003oj@00ooh00?ol003ooP00ood0
03<do@3no`800?on00;o003nood0o_l2003ooP02o`00o_oY0?ko0P00ooh00_l0
0?koo@00=C[m00Go9bOoo`3no`D0oolW9oom00Gono_oo`3no`D0oooknooY00Go
no_oo`3no`D0oooknoom000^=?d00?om9`CoobOooodW0?om003ooO/4oookooom
n`3oj@00oogk1?oonooooO/0ood006HLo@00oo@W0?om003om?/0onT00?odn`3o
o@00LQcm003om2L0ood00?odn`3oj@00ooCk0?om000P7?d00?od9`3oo@00ooCk
0?oY003om?/0ood006lao@00oo`W0olWooom9`3oo@00oock0ookooomn`3oj@00
oock0ookooomn`3oo@00>3[m00;o9bOno`<0o`00o_l19oom00;ono_no`<0o`00
o_l1nooY00;ono_no`<0o`00o_l1noom000g:od0o_om003oo001ooom0?koo@00
oo`00Oooj@3nood00?ol007oood00204/000=0B`001cA?d00?on003oo000ooh0
0?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh0
0?om000dA?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on
00;o003nood0o_l2003ooP02o`00o_om000=C?d01Ooknooo0?ko1@3ooo_kood0
1OnSXooo0?ko1@3ooj>Soo`01Ooknooo0?ko1@3ooo_kood01OlW9ooo0?ko1@3o
obLWood003Q4o@00oogk1?oonooooO/0ood00?omX`Cooj?ooofS0?ol003ooO/4
oookooomn`3oo@00oodW1?oo9ooooBL0ood0064To@00ooCk0?om003om:<0oo`0
0?odn`3oo@00oo@W0?om001X9?d00?odn`3oo@00ooBS0?ol003om?/0ood00?od
9`3oo@00<2Cm003om?/0ood00?odX`3oo000ooCk0?om003om2L0ood00210o@00
oock0ookooomn`3oo@00oobS0onSooomX`3oo000oock0ookooomn`3oo@00oo`W
0olWooom9`3oo@00KDcm00;ono_no`<0o`00o_l1noom00;oXj?no`<0o`00o_l1
Xool00;ono_no`<0o`00o_l1noom00;o9bOno`<0o`00o_l19oom001W>?d0o_om
003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001ooom
000P1;0003L4/0003@B`000^1;000204/00080B`001Q1;0003D4/000;PB`000a
1;0003<000402P120342=P5>03@1B03;0RL10`0100X1B03;0RL10`2HP5800000
0Cl0D@000000000004P0001800000008004020000000/94H000000009<40003o
003oooooool00Oooooo<c002oocoo:ZX00?oooooIVH013LS=b<g8`05MRIf9WHV
00Je:[DZ]BX01o@^m2kd;P08003oo:ZX00Tk4c/C>a<02WXGNQMj5`0;^AZi6[TJ
00ch7_PNn1h03@00oocoo00>EECoo?ol00nZZ?oloo`04?ooVITc<`0AoonIV@00
01;oofIVool04oooIVK<c00D>a<k4c/C01Ej5gXGNQL05[TJ^AZi6P0Gn1kh7_PN
01P00?oloo`06Cl3?`<o0`0JOPMn1gh701^m2kd;_@/07?`>o0kl3P0MEE@00000
01jZZ00000007ool0000000Pool009VI027oo`00IVH08_oo000c<`0Sool00000
02@o0cl3?`<09Gh7OPMn1`0V_@^m2kd;02Ol3_`>o0h0:0?`0o03l00Y@_=2ld;c
02Z1mh7gPOL0:l3k`?_0n`0/000005ED02eEE000EE@0;ZZX001EE00_oo`005ED
033<c9VIool0<Lc<VIW<c00bc<bIVIVI03<3l0?`0o00=4;c@_=2l`0ePON1mh7g
03K0nl3k`?/0=`00001EE00h1n07h0OP03U6i4KTA^@0>XGWQNN5i`0ka>_4jlC[
03`00000ZZP0?EED002ZZ00nZZP00:ZX03ooo000ZZP0@<c<<c<c<`11c<`c<`00
04;<c000ool0@`OP1n07h014A^A6i4KT04F5ihGWQNL0A/C[a>_4j`1700000:ZX
04P;d0_@2m00BD[DB]A:e01:RMR9f8WH04_8flSKb=/0C000003oo01=EE@00?ol
04jZZ000oo`0Cool003oo01@VIW<c9VI056IVLc<IVH0DYVIc<`c<`1C2m0;d0_@
05A:e4[DB]@0EHWHRMR9f01Fb=_8flSK05L00000oo`0F0o03l0?`01IC/A>a4k4
05Z=b8g8SLP0Flc<c<c<c01L001EE00005eEE5ED0000GZZXEE@0001OooaEE000
062IVC<cool0HIVI<c?<c01RVITc<iVI06<?`0o03l00I4k4C/A>a01USLR=b8g8
06K<c<c<c<`0I`00EE@0001X4k4C/A>a06UB]5:dD[@0JY6hTKRA^01[d;c@_=2l
06`005EDEE@0KEEDEEAEE01^ZZQEE5ED06ooo5EDEE@0L6IVoolc<`1aIVKoo`00
079VI/c<ool0La>a4k4C/@1dD[AB]5:d07FA^96hTKP0M]2ld;c@_01g001EE5ED
07PGXANQ5j40NEJUEZEFY@1jUJREZ9FX07_D[=B/e:`0O000EEBZZ01mEEAEE:ZX
07jZZ5EDZZP0OoolEEBZZ020IVIVIYVI085VIVIVIVH0PVIVIVHc<`235j4GXANQ
08AFYEJUEZD0QIFXUJREZ026e:cD[=B/08L005EDZZP0R1^A6i4KT@29FYEJUEZE
08ZIVIVIVIT0RmRLf9cHW02<001EE?ol08eEE5EDoo`0SZZXEECoo02?ooaEE?ol
090c<oooool0TC<cooo<c02B<c?ooiVI09<KTA^A6i40U5ZEFYEJU@2EVIVIVIVI
09KHW=RLf9`0U`00EECoo02H7h4OPAn109UNQEj5GXD0VYf9WHVMR@2Kg8cLS=b<
09`00:ZX0000WEEDZZP0002NZZRZZ00009ooo:ZX0000X3<cVITc<`2Q<c>IV@00
0:8c<fIVool0Xan17h4OP@2TGXENQEj50:FMRIf9WHT0Y]b<g8cLS02W002ZZ000
0:PSLR=b8g80ZF9eHWERM@2ZXGVQNJ5i0:_PON1mh7d0[000ZZQEE02]EEBZZ5ED
0:jZZ:ZXEE@0[oolZZQEE02`<c<009VI0;4c<`00IVH0/S<c000c<`2c8g8SLR=b
0;ARMF9eHWD0]J5iXGVQN@2fh7gPON1m0;L00:ZXEE@0^2MR9f8WHP2iIVIVIVIV
0;ZUJJEYYFT0^nA]i6gTK@2l002ZZ:ZX0;eEE:ZXZZP0_ZZXZZRZZ02ooobZZ:ZX
0<0009VIool0`@00VIW<c032002IVIVI0<<WHRMR9f80a6IVIVIVIP35YFVUJJEY
0<KTKNA]i6d0a`00ZZRZZ038:e8[DR]B0<UZEVYFJUH0bZUIZEVYF@3;j5gXGNQM
0<`00:ZXoo`0cEEDZZSoo03>ZZRZZ?ol0<ooo:ZXoo`0d000<c<c<`3A000c<`00
0=800000ool0db]B:e8[DP3DJUIZEVYF0=FYFJUIZET0e^QMj5gXG@3G002ZZ?ol
0=P_@Rm2;d80fFi6KTI^AP3J[DZ]BZe:0=_/CNa=k4d0g000oo`0003MEECoo000
0=jZZ?ol0000gooloo`0003P4A4000000>400>k^0000hP00gMd0003S;d8_@Rm2
0>A^AVi6KTH0iJe:[DZ]BP3Vk4g/CNa=0>L00?ol0000j3<c<c<c<`3YLSIb=W8f
0>Za>[4j/CX0jo0nl3k`?P3/003oo5ED0>eEE?olEE@0kZZXooaEE03_oocoo5ED
0?000000MgL0l@00001EE@3b000004A40?<c<c<c<c<0m78fLSIb=P3e/CZa>[4j
0?K`?_0nl3h0m`00ooaEE03h=b<g8cLS0?Uf9WHVMRH0n[DZ]BZe:P3km2kd;_@^
0?`00?olZZP0oEEDoobZZ03nZZSoo:ZX0?l00000000000000Cl0D@580</29`43
02@4/000o`:_00B`003o0Zl00Zl01;000=X4/00070:_00:_00B`003o=>X00?on
003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003ooP00ood00?lb
jP3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?ko
o00jjP05obLWool0o_l50?oo9bOoo005oiJFool0o_l50?ooUYKoo@05obLWool0
o_l50?oo9bOoo@00oCCZ003ooBL4oolWooom9`3oo000oofF1?ooU_oooIH0ood0
0?om9`CoobOooodW0?om00017>X00?od9`3oo000ooBF0?om003om2L0ood00?hL
jP00oo@W0?ol003om9H0ood00?od9`3oo@00oA[Z003om2L0oo`00?odUP3oo@00
oo@W0?ol037Z003oo2L3obOooodW0?ol003oo9H3oiKooofF0?om003oo2L3obOo
oodW0?om003o>>X00_lW9oko0`3o003no`4Woo`00_nFU_ko0`3o003no`6Food0
0_lW9oko0`3o003no`4Woo`0:NX0o_om003oo001oool0?koo@00oo`00Oooo@3n
ood00?ol007ooo`01;000?l4/000mCCZ003ooP00oo`00?on003oo000ooh00?ol
003ooP00ood00?on003oo000ooh00?om003n<^X0o_l2003ooP02o`00o_ol0?ko
0P00ooh00_l00?koo@3no`800?on00;o003noo`0>^X01OlW9ooo0?ko1@3oobLW
oo`01OlW9ooo0?ko1@3oobLWood01OlW9ooo0?ko1@3oobLWood00?ldjP00oodW
1?oo9ooooBL0oo`00?om9`CoobOooodW0?om003ooBL4oolWooom9`3oo@00oacZ
003om2L0oo`00?od9`3oo@00oo@W0?om000L6^X00?od9`3oo000oo@W0?om003o
m2L0oo`07>X00?od9`3oo000oo@W0?om003om2L0ood00?4ajP00oo`W0olWooom
9`3oo000oo`W0olWooom9`3oo@00oo`W0olWooom9`3oo@00oS[Z00;o9bOno`<0
o`00o_l19ool00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19oom003m
:nX0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007oood00?`4/000
70B`003mA?d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol
003ooP00ood00?on003oo000ooh00?om003mA?d0o_l2003ooP02o`00o_om0?ko
0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_om000L
B_d01OlW9ooo0?ko1@3oobLWood01OlZ:_oo0?ko1@3oobXZoo`01OmEEOoo0?ko
1@3ooeEEood01OlW9ooo0?ko1@3oobLWoo`0A?d00?om9`CoobOooodW0?om003o
oBX4oolZooom:P3oo000ooeE1?ooEOoooED0ood00?om9`CoobOooodW0?om003o
8_d00?od9`3oo@00oo@Z0?ol003om5D0ood00?od9`3oo00Ro@00oo@W0?om003o
m2X0oo`00?odE@3oo@00oo@W0?ol02Cm003om2L0ood00?od:P3oo000ooAE0?om
003om2L0ood00?m0o@00oo`W0olWooom9`3oo@00oo`Z0olZooom:P3oo000ooaE
0omEooomE@3oo@00oo`W0olWooom9`3oo@001Dcm00;o9bOno`<0o`00o_l19oom
00;o:R[no`<0o`00o_l1:_ol00;oEEGno`<0o`00o_l1EOom00;o9bOno`<0o`00
o_l19oom000L=_d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007o
ood0o_om003oo001oool00B`001E0Zl0<^X00?on003oo000ooh00?ol003ooP00
oo`00?on003oo@00ooh00?ol003ooP00oo`0=>X0o_l2003ooP02o`00o_ol0?ko
0P00ooh00_l00?koo@3no`800?on00;o003nood00?ljjP05obLWool0o_l50?oo
9bOoo005obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOoo@00oc;Z003o
oBL4oolWooom9`3oo000oodW1?oo9ooooBL0ood00?om9`CoobOooodW0?ol01cZ
003om2L0oo`00?od9`3oo@00oo@W0?om003o7>X00?od9`3oo000oo@W0?om003o
m2L0ood00:/JjP00oo@W0?ol003om2L0ood00?od9`3oo00ajP00oo`W0olWooom
9`3oo000oo`W0olWooom9`3oo@00oo`W0olWooom9`3oo@001C[Z00;o9bOno`<0
o`00o_l19ool00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19oom003o
:nX0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007oood00?@2[`04
/000oTCm003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000
ooh00?om003ooP00oo`00?on003oo@00d4;m0?ko0P00ooh00_l00?koo@3no`80
0?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo01<o@05
obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOoo005obLWool0o_l50?oo
9bOoo@05obLWool0o_l50?oo9bOoo@00VdCm003ooBL4oolWooom9`3oo@00oodW
1?oo9ooooBL0oo`00?om9`CoobOooodW0?om003ooBL4oolWooom9`3oo@00o2Cm
003om2L0ood00?od9`3oo000oo@W0?om003om2L0ood00?dTo@00oo@W0?om003o
m2L0oo`00?od9`3oo@00oo@W0?om00039?d00?od9`3oo@00oo@W0?ol003om2L0
ood00?od9`3oo@00ockm003oo2L3obOooodW0?om003oo2L3obOooodW0?ol003o
o2L3obOooodW0?om003oo2L3obOooodW0?ol04[m00;o9bOno`<0o`00o_l19oom
00;o9bOno`<0o`00o_l19ool00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00
o_l19ool03Sm0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom
0?koo@00oo`00Oooo@00j@:_00:_03;m003ooP00oo`00?on003oj@00ooh00?ol
003ooP00ood00?on003oo000ooh00?ol03Cm0?ko0P00ooh00_l00?koj@3no`80
0?on00;o003nood0o_l2003ooP02o`00o_om003n>_d01Oodm?oo0?ko1@3oooCd
onT01OlW9ooo0?ko1@3oobLWood01OlW9ooo0?ko1@3oobLWood00?hdo@00oogd
1?oom?oooO@0onT00?om9`CoobOooodW0?om003ooBL4oolWooom9`3oo@00oAcm
003om?@0onT00?od9`3oo@00oo@W0?om000L7?d00?odm03oj@00oo@W0?om003o
m2L0ood0008Lo@00ooCd0?oY003om2L0ood00?od9`3oo@00eS7m003oo?@3ooCo
oogd0?oY003oo2L3obOooodW0?om003oo2L3obOooodW0?om003o>_d00_odm?ko
0`3o003no`7donT00_lW9oko0`3o003no`4Wood00_lW9oko0`3o003no`4Wood0
0?lYo@3nood00?ol007oonT0o_om003oo001ooom0?koo@00oo`00Oooo004/000
o`B`000L8_d00?on003oo000ooh00?om003ooP00oo`00?on003oe@0Ro@3no`80
0?on00;o003nood0o_l2003ooP02o`00o_oE02Km00Go9bOoo`3no`D0oolW9oom
00Go9bOoo`3no`D0oolW9ooE02Cm003ooBL4oolWooom9`3oo@00oodW1?oo9ooo
oBL0omH00?dDo@00oo@W0?om003om2L0omH00?`Do@00oo@W0?om003om2L0omH0
00<Bo@00oo@W0?om003om2L0omD08?d00?ol9`?o9ooooBL0ood00?ol9`?o9ooo
oBL0omD09_d00_lW9oko0`3o003no`4Wood00_lW9oko0`3o003no`4WomD07_d0
o_om003oo001ooom0?koo@00oo`00OooeP0080B`003o1;000?m4o@00ooh00?ol
003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol
003ooP00ood00?m4o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko
0P00ooh00_l00?koo@3no`800?on00;o003nood00?i<o@05obLWool0o_l50?oo
9bOoo@05obLWool0o_l50?oo9bOoo005obXZool0o_l50?oo:R[oo@05obLWool0
o_l50?oo9bOoo@001DCm003ooBL4oolWooom9`3oo@00oodW1?oo9ooooBL0oo`0
0?om:PCoob[ooodZ0?om003ooBL4oolWooom9`3oo@00obCm003om2L0ood00?od
9`3oo000oo@Z0?om003om2L0ood001`To@00oo@W0?om003om2L0oo`00?od:P3o
o@00oo@W0?om003o9?d00?od9`3oo@00oo@W0?ol003om2X0ood00?od9`3oo@00
od3m003oo2L3obOooodW0?om003oo2L3obOooodW0?ol003oo2X3ob[ooodZ0?om
003oo2L3obOooodW0?om003mC?d00_lW9oko0`3o003no`4Wood00_lW9oko0`3o
003no`4Woo`00_lZ:_ko0`3o003no`4Zood00_lW9oko0`3o003no`4Wood00?hh
o@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol
007oood000D4/000o`B`003o=?d00?on003oo000ooh00?om003ooP00oo`00?on
003oj@00ooh00?ol003ooP00ood000<bo@3no`800?on00;o003nood0o_l2003o
oP02o`00o_oY0?ko0P00ooh00_l00?koo00ho@05obLWool0o_l50?oo9bOoo@05
obLWool0o_l50?oo9bOoj@05obLWool0o_l50?oo9bOoo00do@00oodW1?oo9ooo
oBL0ood00?om9`CoobOooodW0?oY003ooBL4oolWooom9`3oo@00oacm003om2L0
ood00?od9`3oj@00oo@W0?om003o7?d00?od9`3oo@00oo@W0?oY003om2L0ood0
01`Lo@00oo@W0?om003om2L0onT00?od9`3oo@00737m003oo2L3obOooodW0?om
003oo2L3obOooodW0?oY003oo2L3obOooodW0?om000L>_d00_lW9oko0`3o003n
o`4Wood00_lW9oko0`3o003no`4WonT00_lW9oko0`3o003no`4Wood00?lYo@3n
ood00?ol007oood0o_om003oo001oooY0?koo@00oo`00Oooo002[`02[`12o@00
ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00
ooh00?ol003ooP00oo`0@_d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?ko
o03no`800?on00;o003nood0o_l2003ooP02o`00o_ol04[m00Go9bOoo`3no`D0
oolW9oom00Go9bOoo`3no`D0oolW9ool00Go9bOoo`3no`D0oolW9oom00Go9bOo
o`3no`D0oolW9ool04Cm003ooBL4oolWooom9`3oo@00oodW1?oo9ooooBL0oo`0
0?om9`CoobOooodW0?om003ooBL4oolWooom9`3oo@00obCm003om2L0ood00?od
9`3oo000oo@W0?om003om2L0ood00?lTo@00oo@W0?om003om2L0oo`00?od9`3o
o@00oo@W0?om000L9?d00?od9`3oo@00oo@W0?ol003om2L0ood00?od9`3oo@00
743m003oo2L3obOooodW0?om003oo2L3obOooodW0?ol003oo2L3obOooodW0?om
003oo2L3obOooodW0?om000LC?d00_lW9oko0`3o003no`4Wood00_lW9oko0`3o
003no`4Woo`00_lW9oko0`3o003no`4Wood00_lW9oko0`3o003no`4Wood00?lf
o@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol
007ooo`00Zl00Zl0@_d00?on003oo000ooh00?om003ooP00oo`00?on003oo000
ooh00?ol003ooP00ood00?on003oo000ooh00?ol04;m0?ko0P00ooh00_l00?ko
o@3no`800?on00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?ko
o01:o@05obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOoo005onKVool0
o_l50?ooi^Koo@05obLWool0o_l50?oo9bOoo014o@00oodW1?oo9ooooBL0ood0
0?om9`CoobOooodW0?ol003ooNH4oooVooomiP3oo@00oodW1?oo9ooooBL0ood0
0?lTo@00oo@W0?om003om2L0oo`00?odiP3oo@00oo@W0?om003o9?d00?od9`3o
o@00oo@W0?ol003om>H0ood00?od9`3oo@00:RCm003om2L0ood00?od9`3oo000
ooCV0?om003om2L0ood002Y0o@00oo`W0olWooom9`3oo@00oo`W0olWooom9`3o
o000oocV0ooVooomiP3oo@00oo`W0olWooom9`3oo@00:Tcm00;o9bOno`<0o`00
o_l19oom00;o9bOno`<0o`00o_l19ool00;oi^Kno`<0o`00o_l1i_om00;o9bOn
o`<0o`00o_l19oom003o=_d0o_om003oo001ooom0?koo@00oo`00Oooo03nood0
0?ol007oood0o_om003oo001oool00:_00:_03;Z003ooP00oo`00?on003oo000
ooh00?ol003ooP00ood00?on003oo000ooh00?ol03;Z0?ko0P00ooh00_l00?ko
o03no`800?on00;o003nood0o_l2003ooP02o`00o_ol03SZ00Go9bOoo`3no`D0
oolW9ool00Go9bOoo`3no`D0oolW9oom00Go9bOoo`3no`D0oolW9ool03;Z003o
oBL4oolWooom9`3oo000oodW1?oo9ooooBL0ood00?om9`CoobOooodW0?ol01[Z
003om2L0oo`00?od9`3oo@00oo@W0?ol01[Z003om2L0oo`00?od9`3oo@00oo@W
0?ol01[Z003om2L0oo`00?od9`3oo@00oo@W0?ol02oZ003oo2L3obOooodW0?ol
003oo2L3obOooodW0?om003oo2L3obOooodW0?ol03SZ00;o9bOno`<0o`00o_l1
9ool00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19ool02WZ0?koo@00
oo`00Oooo03nood00?ol007oood0o_om003oo001oool00:_00:_00:_03;m003o
oP00oo`00?on003oj@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol03;m
0?ko0P00ooh00_l00?koj@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol
03[m00Go9bOoo`3no`D0oolW9ooY00Go9bOoo`3no`D0oolW9oom00GoADGoo`3n
o`D0oom5AOom003o=?d00?om9`CoobOooodW0?oY003ooBL4oolWooom9`3oo@00
ooe51?ooAOoooDD0ood00?lLo@00oo@W0?oY003om2L0ood00?odA@3oo@0071cm
003om2L0onT00?od9`3oo@00ooA50?om000L<Od00?ol9`?o9ooooBL0onT00?ol
9`?o9ooooBL0ood00?olA@?oAOoooDD0ood001`jo@02obLWo_l30?l00?ko0BOo
j@02obLWo_l30?l00?ko0BOoo@02odE5o_l30?l00?ko0DGoo@00obWm0?koo@00
oo`00Oooj@3nood00?ol007oood0o_om003oo001oool00:_00:_00:_04;m003o
oP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003o
oP00oo`00?on003oo012o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol
0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0C?d01OlW9ooo0?ko1@3o
obLWood01Oodm?oo0?ko1@3oooCdoo`01OlW9ooo0?ko1@3oobLWood01Om3@ooo
0?ko1@3ood=3ood00?m4o@00oodW1?oo9ooooBL0ood00?omm0CoooCooogd0?ol
003ooBL4oolWooom9`3oo@00ooe31?oo@ooooD<0ood00?lTo@00oo@W0?om003o
m?@0oo`00?od9`3oo@00ooA30?om000L9?d00?od9`3oo@00ooCd0?ol003om2L0
ood00?od@`3oo@0072Cm003om2L0ood00?odm03oo000oo@W0?om003om4<0ood0
01a0o@00oo`W0olWooom9`3oo@00oocd0oodooomm03oo000oo`W0olWooom9`3o
o@00ooa30om3ooom@`3oo@00od[m00;o9bOno`<0o`00o_l19oom00;om?Cno`<0
o`00o_l1m?ol00;o9bOno`<0o`00o_l19oom00;o@d?no`<0o`00o_l1@ool03Km
0?koo@00oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`0
0Oooo002[`02[`0bo@00ooh00?ol003ooP00ood00?on003oo000ooh00?oY003o
oP00oo`00?on003oo00bo@3no`800?on00;o003nood0o_l2003ooP02o`00o_oY
0?ko0P00ooh00_l00?koo00jo@05obLWool0o_l50?oo9bOoo@05obLWool0o_l5
0?oo9bOoj@05obLWool0o_l50?oo9bOoo@00ocCm003ooBL4oolWooom9`3oo@00
oodW1?oo9ooooBL0onT00?om9`CoobOooodW0?om003o7?d00?od9`3oo@00oo@W
0?oY003om2L0ood001`Lo@00oo@W0?om003om2L0onT00?od9`3oo@0071cm003o
m2L0ood00?od9`3oj@00oo@W0?om000L<Od00?ol9`?o9ooooBL0ood00?ol9`?o
9ooooBL0onT00?ol9`?o9ooooBL0ood00?lho@02obLWo_l30?l00?ko0BOoo@02
obLWo_l30?l00?ko0BOoj@02obLWo_l30?l00?ko0BOoo00Yo@3nood00?ol007o
ood0o_om003oo001oooY0?koo@00oo`00Oooo002[`02[`12o@00ooh00?ol003o
oP00ood00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh00?ol003o
oP00oo`0@_d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on
00;o003nood0o_l2003ooP02o`00o_ol04cm00Go9bOoo`3no`D0oolW9oom00Go
9bOoo`3no`D0oolW9ool00GoYZKoo`3no`D0oonVY_om00Go9bOoo`3no`D0oolW
9oom003oA?d00?om9`CoobOooodW0?om003ooBL4oolWooom9`3oo000oofV1?oo
Y_oooJH0ood00?om9`CoobOooodW0?om003o9?d00?od9`3oo@00oo@W0?ol003o
m:H0ood00?od9`3oo@00fRCm003om2L0ood00?od9`3oo000ooBV0?om003om2L0
ood00=XTo@00oo@W0?om003om2L0oo`00?odYP3oo@00oo@W0?om003J@?d00?ol
9`?o9ooooBL0ood00?ol9`?o9ooooBL0oo`00?olYP?oY_oooJH0ood00?ol9`?o
9ooooBL0ood00?m:o@02obLWo_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOo
o002ojJVo_l30?l00?ko0JKoo@02obLWo_l30?l00?ko0BOoo00fo@3nood00?ol
007oood0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007ooo`00Zl0
0Zl0@_d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003o
oP00ood00?on003oo000ooh00?ol04;m0?ko0P00ooh00_l00?koo@3no`800?on
00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo01<o@05obLW
ool0o_l50?oo9bOoo@05ojJVool0o_l50?ooYZKoo005obLWool0o_l50?oo9bOo
o@05obLWool0o_l50?oo9bOoo@00odCm003ooBL4oolWooom9`3oo@00oofV1?oo
Y_oooJH0oo`00?om9`CoobOooodW0?om003ooBL4oolWooom9`3oo@00obCm003o
m2L0ood00?odYP3oo000oo@W0?om003om2L0ood003TTo@00oo@W0?om003om:H0
oo`00?od9`3oo@00oo@W0?om000i9?d00?od9`3oo@00ooBV0?ol003om2L0ood0
0?od9`3oo@00>D3m003oo2L3obOooodW0?om003oo:H3ojKooofV0?ol003oo2L3
obOooodW0?om003oo2L3obOooodW0?om003oB_d00_lW9oko0`3o003no`4Wood0
0_nVY_ko0`3o003no`6Voo`00_lW9oko0`3o003no`4Wood00_lW9oko0`3o003n
o`4Woo`0=_d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007oood0
o_om003oo001oool00:_00:_03;m003ooP00oo`00?on003oo@00ooh00?ol003o
oP00onT00?on003oo000ooh00?ol03;m0?ko0P00ooh00_l00?koo@3no`800?on
00;o003nonT0o_l2003ooP02o`00o_ol03[m00Go9bOoo`3no`D0oolW9oom00Go
9bOoo`3no`D0oolW9ooY00Go9bOoo`3no`D0oolW9oom003o=?d00?om9`CoobOo
oodW0?om003ooBL4oolWooom9`3oj@00oodW1?oo9ooooBL0ood00?lLo@00oo@W
0?om003om2L0onT00?od9`3oo@0071cm003om2L0ood00?od9`3oj@00oo@W0?om
000L7?d00?od9`3oo@00oo@W0?oY003om2L0ood001`ao@00oo`W0olWooom9`3o
o@00oo`W0olWooom9`3oj@00oo`W0olWooom9`3oo@00ocSm00;o9bOno`<0o`00
o_l19oom00;o9bOno`<0o`00o_l19ooY00;o9bOno`<0o`00o_l19ool02Wm0?ko
o@00oo`00Oooo@3nood00?ol007oonT0o_om003oo001oool00:_00:_03;m003o
oP00oo`00?on003oo@00ooh00?ol003ooP00onT00?on003oo000ooh00?ol03;m
0?ko0P00ooh00_l00?koo@3no`800?on00;o003nonT0o_l2003ooP02o`00o_ol
03[m00Go9bOoo`3no`D0oolW9oom00Go9bOoo`3no`D0oolW9ooY00Go9bOoo`3n
o`D0oolW9oom003o=?d00?om9`CoobOooodW0?om003ooBL4oolWooom9`3oj@00
oodW1?oo9ooooBL0ood00?lLo@00oo@W0?om003om2L0onT00?od9`3oo@0071cm
003om2L0ood00?od9`3oj@00oo@W0?om000L7?d00?od9`3oo@00oo@W0?oY003o
m2L0ood001`ao@00oo`W0olWooom9`3oo@00oo`W0olWooom9`3oj@00oo`W0olW
ooom9`3oo@00ocSm00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19ooY
00;o9bOno`<0o`00o_l19ool02Wm0?koo@00oo`00Oooo@3nood00?ol007oonT0
o_om003oo001oool00:_00:_04;m003ooP00oo`00?on003oo@00ooh00?ol003o
oP00oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo012o@3no`800?on
00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on
00;o003noo`0C?d01OlW9ooo0?ko1@3oobLWood01OlW9ooo0?ko1@3oobLWoo`0
1Oodm?oo0?ko1@3oooCdood01OlW9ooo0?ko1@3oobLWood00?m4o@00oodW1?oo
9ooooBL0ood00?om9`CoobOooodW0?ol003ooO@4ooodooomm03oo@00oodW1?oo
9ooooBL0ood00?lTo@00oo@W0?om003om2L0oo`00?odm03oo@00oo@W0?om000L
9?d00?od9`3oo@00oo@W0?ol003om?@0ood00?od9`3oo@0072Cm003om2L0ood0
0?od9`3oo000ooCd0?om003om2L0ood001a0o@00oo`W0olWooom9`3oo@00oo`W
0olWooom9`3oo000oocd0oodooomm03oo@00oo`W0olWooom9`3oo@00od[m00;o
9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19ool00;om?Cno`<0o`00o_l1
m?om00;o9bOno`<0o`00o_l19ool03Km0?koo@00oo`00Oooo@3nood00?ol007o
oo`0o_om003oo001ooom0?koo@00oo`00Oooo002[`02[`0bjP00ooh00?ol003o
oP00oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo00bjP3no`800?on
00;o003noo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo00hjP05obLW
ool0o_l50?oo9bOoo005okjnool0o_l50?oo_[koo@05obLWool0o_l50?oo9bOo
o00djP00oodW1?oo9ooooBL0oo`00?om_PCookkooofn0?om003ooBL4oolWooom
9`3oo@00oacZ003om2L0oo`00?od_P3oo@00oo@W0?om003o7>X00?od9`3oo000
ooBn0?om003om2L0ood001`LjP00oo@W0?ol003om;h0ood00?od9`3oo@00737Z
003oo2L3obOooodW0?ol003oo;h3okkooofn0?om003oo2L3obOooodW0?om003o
>>X00_lW9oko0`3o003no`4Woo`00_nn__ko0`3o003no`6nood00_lW9oko0`3o
003no`4Woo`0:NX0o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007o
oo`00Zl00Zl04]H00?on003oo000ooh00?oY01;F0?ko0P00ooh00_l00?koj@0D
eP05obLWool0o_l50?oo9bOoj@0DeP00oodW1?oo9ooooBL0onX00?l<eP00oo@W
0?oZ003o3=H00?od9`3ojP0070cF003om2L0onX001`CeP00oo`W0olWooom9`3o
jP0071KF00;o9bOno`<0o`00o_l19ooZ003o3mH0o_om003oo001oooY00:_00:_
02;F003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`08]H0o_l2003ooP02
o`00o_om0?ko0P00ooh00_l00?koo00VeP05oeEEool0o_l50?ooEEGoo@05obLW
ool0o_l50?oo9bOoo00TeP00ooeE1?ooEOoooED0ood00?om9`CoobOooodW0?om
003o5=H00?odE@3oo@00oo@W0?om003o5=H00?odE@3oo@00oo@W0?om000L5=H0
0?odE@3oo@00oo@W0?om000L8]H00?olE@?oEOoooED0ood00?ol9`?o9ooooBL0
ood001`XeP02oeEEo_l30?l00?ko0EGoo@02obLWo_l30?l00?ko0BOoo@00oacF
0?koo@00oo`00Oooo@3nood00?ol007ooo`00Zl00Zl0@_d00?on003oo000ooh0
0?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood00?on003oo000ooh0
0?ol04;m0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2003ooP02
o`00o_om0?ko0P00ooh00_l00?koo01:o@05obLWool0o_l50?oo9bOoo@05obLW
ool0o_l50?oo9bOoo005obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOo
o014o@00oodW1?oo9ooooBL0ood00?om9`CoobOooodW0?ol003ooBL4oolWooom
9`3oo@00oodW1?oo9ooooBL0ood00?lTo@00oo@W0?om003om2L0oo`00?od9`3o
o@00oo@W0?om003o9?d00?od9`3oo@00oo@W0?ol003om2L0ood00?od9`3oo@00
72Cm003om2L0ood00?od9`3oo000oo@W0?om003om2L0ood001a0o@00oo`W0olW
ooom9`3oo@00oo`W0olWooom9`3oo000oo`W0olWooom9`3oo@00oo`W0olWooom
9`3oo@0074cm00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19ool00;o
9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19oom003o=_d0o_om003oo001
ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001oool00:_00:_
03;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh0
0?oY03;m0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0o_l2003ooP02
o`00o_oY03Sm00Go9bOoo`3no`D0oolW9oom00Go_[koo`3no`D0oonn__ol00Go
EEGoo`3no`D0oomEEOoY03Cm003ooBL4oolWooom9`3oo@00oofn1?oo__oooKh0
oo`00?omE@CooeGoooeE0?oZ003o7?d00?od9`3oo@00ooBn0?ol003om5D0onX0
0?lLo@00oo@W0?om003om;h0oo`00?odE@3ojP0071cm003om2L0ood00?od_P3o
o000ooAE0?oZ000L<Od00?ol9`?o9ooooBL0ood00?ol_P?o__oooKh0oo`00?ol
E@?oEOoooED0onX001`jo@02obLWo_l30?l00?ko0BOoo@02okjno_l30?l00?ko
0Kkoo002oeEEo_l30?l00?ko0EGojP00obWm0?koo@00oo`00Oooo@3nood00?ol
007ooo`0o_om003oo001oooY00:_00:_00:_00:_00:_00B`003o1;000?l4/000
>@B`000i1;0003T000402P120342=P5>03@1B04C0RL1C00100X1B04C0RL1C02H
P58000000Cl0D@000000000004P0001800000008004020000000/94/00000000
9<80003o003oooooool00Oooooo<c002oocoo:ZX00?oooooIVH013LS=b<g8`05
MRIf9WHV00Je:[DZ]BX01o@^m2kd;P08003oo:ZX00Tk4c/C>a<02WXGNQMj5`0;
^AZi6[TJ00ch7_PNn1h03@00oocoo00>EECoo?ol00nZZ?oloo`04?ooVITc<`0A
oonIV@0001;oofIVool04oooIVK<c00D>a<k4c/C01Ej5gXGNQL05[TJ^AZi6P0G
n1kh7_PN01P00?oloo`06Cl3?`<o0`0JOPMn1gh701^m2kd;_@/07?`>o0kl3P0M
EE@0000001jZZ00000007ool0000000Pool009VI027oo`00IVH08_oo000c<`0S
ool0000002@o0cl3?`<09Gh7OPMn1`0V_@^m2kd;02Ol3_`>o0h0:0?`0o03l00Y
@_=2ld;c02Z1mh7gPOL0:l3k`?_0n`0/000005ED02eEE000EE@0;ZZX001EE00_
oo`005ED033<c9VIool0<Lc<VIW<c00bc<bIVIVI03<3l0?`0o00=4;c@_=2l`0e
PON1mh7g03K0nl3k`?/0=`00001EE00h1n07h0OP03U6i4KTA^@0>XGWQNN5i`0k
a>_4jlC[03`00000ZZP0?EED002ZZ00nZZP00:ZX03ooo000ZZP0@<c<<c<c<`11
c<`c<`0004;<c000ool0@`OP1n07h014A^A6i4KT04F5ihGWQNL0A/C[a>_4j`17
00000:ZX04P;d0_@2m00BD[DB]A:e01:RMR9f8WH04_8flSKb=/0C000003oo01=
EE@00?ol04jZZ000oo`0Cool003oo01@VIW<c9VI056IVLc<IVH0DYVIc<`c<`1C
2m0;d0_@05A:e4[DB]@0EHWHRMR9f01Fb=_8flSK05L00000oo`0F0o03l0?`01I
C/A>a4k405Z=b8g8SLP0Flc<c<c<c01L001EE00005eEE5ED0000GZZXEE@0001O
ooaEE000062IVC<cool0HIVI<c?<c01RVITc<iVI06<?`0o03l00I4k4C/A>a01U
SLR=b8g806K<c<c<c<`0I`00EE@0001X4k4C/A>a06UB]5:dD[@0JY6hTKRA^01[
d;c@_=2l06`005EDEE@0KEEDEEAEE01^ZZQEE5ED06ooo5EDEE@0L6IVoolc<`1a
IVKoo`00079VI/c<ool0La>a4k4C/@1dD[AB]5:d07FA^96hTKP0M]2ld;c@_01g
001EE5ED07PGXANQ5j40NEJUEZEFY@1jUJREZ9FX07_D[=B/e:`0O000EEBZZ01m
EEAEE:ZX07jZZ5EDZZP0OoolEEBZZ020IVIVIYVI085VIVIVIVH0PVIVIVHc<`23
5j4GXANQ08AFYEJUEZD0QIFXUJREZ026e:cD[=B/08L005EDZZP0R1^A6i4KT@29
FYEJUEZE08ZIVIVIVIT0RmRLf9cHW02<001EE?ol08eEE5EDoo`0SZZXEECoo02?
ooaEE?ol090c<oooool0TC<cooo<c02B<c?ooiVI09<KTA^A6i40U5ZEFYEJU@2E
VIVIVIVI09KHW=RLf9`0U`00EECoo02H7h4OPAn109UNQEj5GXD0VYf9WHVMR@2K
g8cLS=b<09`00:ZX0000WEEDZZP0002NZZRZZ00009ooo:ZX0000X3<cVITc<`2Q
<c>IV@000:8c<fIVool0Xan17h4OP@2TGXENQEj50:FMRIf9WHT0Y]b<g8cLS02W
002ZZ0000:PSLR=b8g80ZF9eHWERM@2ZXGVQNJ5i0:_PON1mh7d0[000ZZQEE02]
EEBZZ5ED0:jZZ:ZXEE@0[oolZZQEE02`<c<009VI0;4c<`00IVH0/S<c000c<`2c
8g8SLR=b0;ARMF9eHWD0]J5iXGVQN@2fh7gPON1m0;L00:ZXEE@0^2MR9f8WHP2i
IVIVIVIV0;ZUJJEYYFT0^nA]i6gTK@2l002ZZ:ZX0;eEE:ZXZZP0_ZZXZZRZZ02o
oobZZ:ZX0<0009VIool0`@00VIW<c032002IVIVI0<<WHRMR9f80a6IVIVIVIP35
YFVUJJEY0<KTKNA]i6d0a`00ZZRZZ038:e8[DR]B0<UZEVYFJUH0bZUIZEVYF@3;
j5gXGNQM0<`00:ZXoo`0cEEDZZSoo03>ZZRZZ?ol0<ooo:ZXoo`0d000<c<c<`3A
000c<`000=800000ool0db]B:e8[DP3DJUIZEVYF0=FYFJUIZET0e^QMj5gXG@3G
002ZZ?ol0=P_@Rm2;d80fFi6KTI^AP3J[DZ]BZe:0=_/CNa=k4d0g000oo`0003M
EECoo0000=jZZ?ol0000gooloo`0003P4A4000000>400>k^0000hP00gMd0003S
;d8_@Rm20>A^AVi6KTH0iJe:[DZ]BP3Vk4g/CNa=0>L00?ol0000j3<c<c<c<`3Y
LSIb=W8f0>Za>[4j/CX0jo0nl3k`?P3/003oo5ED0>eEE?olEE@0kZZXooaEE03_
oocoo5ED0?000000MgL0l@00001EE@3b000004A40?<c<c<c<c<0m78fLSIb=P3e
/CZa>[4j0?K`?_0nl3h0m`00ooaEE03h=b<g8cLS0?Uf9WHVMRH0n[DZ]BZe:P3k
m2kd;_@^0?`00?olZZP0oEEDoobZZ03nZZSoo:ZX0?l00000000000000Cl0D@58
0A<29`5<02@4/00070B`003o1;000?l4/0000P:_00:_00:_00B`003K1;000?l2
[`14o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on
003oo@00ooh00?ol003ooP00ood000E2o@3no`800?on00;o003nood0o_l2003o
oP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0B_d01OlW
9ooo0?ko1@3oobLWood01OlW9ooo0?ko1@3oobLWoo`01OlW9ooo0?ko1@3oobLW
ood01OoVi_oo0?ko1@3oonKVoo`0A?d00?om9`CoobOooodW0?om003ooBL4oolW
ooom9`3oo000oodW1?oo9ooooBL0ood00?omiPCoonKooogV0?om000L9?d00?od
9`3oo@00oo@W0?ol003om2L0ood00?odiP3oo@00obCm003om2L0ood00?od9`3o
o000oo@W0?om003om>H0ood00?lTo@00oo@W0?om003om2L0oo`00?od9`3oo@00
ooCV0?om003o?_d00?ol9`?o9ooooBL0ood00?ol9`?o9ooooBL0oo`00?ol9`?o
9ooooBL0ood00?oliP?oi_oooNH0oo`0C?d00_lW9oko0`3o003no`4Wood00_lW
9oko0`3o003no`4Woo`00_lW9oko0`3o003no`4Wood00_oVi_ko0`3o003no`7V
ood000@fo@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooo@3n
ood00?ol007ooo`00Zl00Zl09?d00?on003oo000ooh00?oF003ooP00oo`00?on
003oo@00obCm0?ko0P00ooh00_l00?koeP3no`800?on00;o003nood00?lVo@05
obLWool0o_l50?oo9bOoeP05obLWool0o_l50?oo9bOoo00Ro@00oodW1?oo9ooo
oBL0omH00?om9`CoobOooodW0?ol01Cm003om2L0omH00?od9`3oo@00oaCm003o
m2L0omH00?od9`3oo@000ACm003om2L0omH00?od9`3oo@00ob;m003oo2L3obOo
oodW0?oF003oo2L3obOooodW0?om003n:?d00_lW9oko0`3o003no`4WomH00_lW
9oko0`3o003no`4Wood00?`Lo@3nood00?ol007oomH0o_om003oo001oool00:_
00B`003nA?d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol
003ooP00ood00?on003oo000ooh00?om003o@_d0o_l2003ooP02o`00o_om0?ko
0P00ooh00_l00?koo03no`800?on00;o003nood0o_l2003ooP02o`00o_ol04cm
00Go9bOoo`3no`D0oolW9oom00Go9bOoo`3no`D0oolW9ool00Go9bOoo`3no`D0
oolW9oom00Go9bOoo`3no`D0oolW9oom003ZA?d00?om9`CoobOooodW0?om003o
oBL4oolWooom9`3oo000oodW1?oo9ooooBL0ood00?om9`CoobOooodW0?om003o
9?d00?od9`3oo@00oo@W0?ol003om2L0ood00?od9`3oo@00obCm003om2L0ood0
0?od9`3oo000oo@W0?om003om2L0ood0008To@00oo@W0?om003om2L0oo`00?od
9`3oo@00oo@W0?om0004?_d00?ol9`?o9ooooBL0ood00?ol9`?o9ooooBL0oo`0
0?ol9`?o9ooooBL0ood00?ol9`?o9ooooBL0oo`0C?d00_lW9oko0`3o003no`4W
ood00_lW9oko0`3o003no`4Woo`00_lW9oko0`3o003no`4Wood00_lW9oko0`3o
003no`4Wood001`ho@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`0
0Oooo@3nood00?ol007oood00?l4/000o`B`001k<_d00?on003oo000ooh00?oY
003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`0=?d0o_l2003ooP02o`00
o_oY0?ko0P00ooh00_l00?koo@3no`800?on00;o003nood000<jo@05ofQXool0
o_l50?ooJ6Soj@05obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOoo@00
>cCm003ooFP4oomXooomJ03oj@00oodW1?oo9ooooBL0ood00?om9`CoobOooodW
0?om003h7?d00?odJ03oj@00oo@W0?om003om2L0ood00?lLo@00ooAX0?oY003o
m2L0ood00?od9`3oo@00fa[m003om6P0onT00?od9`3oo@00oo@W0?ol037m003o
o6P3ofSoooeX0?oY003oo2L3obOooodW0?om003oo2L3obOooodW0?om003l>_d0
0_mXJ?ko0`3o003no`5XonT00_lW9oko0`3o003no`4Wood00_lW9oko0`3o003n
o`4Wood001`[o@3nood00?ol007oonT0o_om003oo001ooom0?koo@00oo`00Ooo
o@00o`B`003d1;000?lRo@00ooh00?ol003ooP00omH00?on003oo000ooh00?ol
02Cm0?ko0P00ooh00_l00?koeP3no`800?on00;o003nood00?lXo@05ofQXool0
o_l50?ooJ6SoeP05obLWool0o_l50?oo9bOoo@00ob;m003ooFP4oomXooomJ03o
eP00oodW1?oo9ooooBL0oo`05?d00?odJ03oeP00oo@W0?om003d5?d00?odJ03o
eP00oo@W0?om003o4_d00?odJ03oeP00oo@W0?ol02;m003oo6P3ofSoooeX0?oF
003oo2L3obOooodW0?om003o:?d00_mXJ?ko0`3o003no`5XomH00_lW9oko0`3o
003no`4Wood00>XNo@3nood00?ol007oomH0o_om003oo001ooom003Z1;000?h2
[`14o@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on
003oo@00ooh00?ol003ooP00ood00?i4o@3no`800?on00;o003nood0o_l2003o
oP02o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003nood001a<o@05
obLWool0o_l50?oo9bOoo@05ooGeool0o_l50?oomOGoo005obLWool0o_l50?oo
9bOoo@05ohJ6ool0o_l50?ooQXKoo@00odCm003ooBL4oolWooom9`3oo@00ooge
1?oomOoooOD0oo`00?om9`CoobOooodW0?om003ooHH4oon6ooomQP3oo@00m2Cm
003om2L0ood00?odm@3oo000oo@W0?om003om8H0ood000<To@00oo@W0?om003o
m?D0oo`00?od9`3oo@00ooB60?om000L8_d00?od9`3oo@00ooCe0?ol003om2L0
ood00?odQP3oo010o@00oo`W0olWooom9`3oo@00ooce0ooeooomm@3oo000oo`W
0olWooom9`3oo@00oob60on6ooomQP3oo@00odcm00;o9bOno`<0o`00o_l19oom
00;omOGno`<0o`00o_l1mOol00;o9bOno`<0o`00o_l19oom00;oQXKno`<0o`00
o_l1Q_om000L>?d0o_om003oo001ooom0?koo@00oo`00Oooo03nood00?ol007o
ood0o_om003oo001ooom003o1;000?l4/000od;m003ooP00oo`00?on003oo@00
ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo014
o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?ko
o@3no`800?on00;o003nood00?i<o@05obLWool0o_l50?oo9bOoo@05obLWool0
o_l50?oo9bOoo005onKVool0o_l50?ooi^Koo@05ooGeool0o_l50?oomOGoo@00
0dCm003ooBL4oolWooom9`3oo@00oodW1?oo9ooooBL0oo`00?omiPCoonKooogV
0?om003ooOD4oooeooomm@3oo@001B;m003om2L0ood00?od9`3oo000ooCV0?om
003om?D0oo`09?d00?od9`3oo@00oo@W0?ol003om>H0ood00?odm@3oo@00m2;m
003om2L0ood00?od9`3oo000ooCV0?om003om?D0oo`0@?d00?ol9`?o9ooooBL0
ood00?ol9`?o9ooooBL0oo`00?oliP?oi_oooNH0ood00?olm@?omOoooOD0ood0
0?m<o@02obLWo_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOoo002onKVo_l3
0?l00?ko0NKoo@02ooGeo_l30?l00?ko0OGoo@00ocKm0?koo@00oo`00Oooo@3n
ood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo004/000o`B`003o
<_d00?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003ooP00
onT0=?d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03no`800?on00;o
003nonX001`jo@05obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOoo005
onKVool0o_l50?ooi^KojP000C;m003ooBL4oolWooom9`3oo@00oodW1?oo9ooo
oBL0oo`00?omiPCoonKooogV0?oY01[m003om2L0ood00?od9`3oo000ooCV0?oY
01cm003om2L0ood00?od9`3oo000ooCV0?oZ003`7?d00?od9`3oo@00oo@W0?ol
003om>H0onX000<ao@00oo`W0olWooom9`3oo@00oo`W0olWooom9`3oo000oocV
0ooVooomiP3ojP00o3[m00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l1
9ool00;oi^Kno`<0o`00o_l1i_oZ0002:od0o_om003oo001ooom0?koo@00oo`0
0Oooo03nood00?ol007oonX000@2[`04/0000d;m003ooP00oo`00?on003oo@00
ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`00?on003oo014
o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh00_l00?ko
o@3no`800?on00;o003nood0011:o@05obLWool0o_l50?oo9bOoo@05obLWool0
o_l50?oo9bOoo005obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo9bOoo012
o@00oodW1?oo9ooooBL0ood00?om9`CoobOooodW0?ol003ooBL4oolWooom9`3o
o@00oodW1?oo9ooooBL0oo`08_d00?od9`3oo@00oo@W0?ol003om2L0ood00?od
9`3oo00Ro@00oo@W0?om003om2L0oo`00?od9`3oo@00oo@W0?ol02;m003om2L0
ood00?od9`3oo000oo@W0?om003om2L0oo`0?_d00?ol9`?o9ooooBL0ood00?ol
9`?o9ooooBL0oo`00?ol9`?o9ooooBL0ood00?ol9`?o9ooooBL0oo`0B_d00_lW
9oko0`3o003no`4Wood00_lW9oko0`3o003no`4Woo`00_lW9oko0`3o003no`4W
ood00_lW9oko0`3o003no`4Woo`0=_d0o_om003oo001ooom0?koo@00oo`00Ooo
o03nood00?ol007oood0o_om003oo001oool00:_00:_04;m003ooP00oo`00?on
003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`00?on
003oo012o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh0
0_l00?koo@3no`800?on00;o003noo`0B_d01Ooknooo0?ko1@3ooo_kood01On6
Q_oo0?ko1@3oohJ6oo`01Ooknooo0?ko1@3ooo_kood01Ooknooo0?ko1@3ooo_k
oo`0@_d00?omn`Cooo_ooogk0?om003ooHH4oon6ooomQP3oo000oogk1?oonooo
oO/0ood00?omn`Cooo_ooogk0?ol02;m003om?/0ood00?odQP3oo000ooCk0?om
003om?/0oo`08_d00?odn`3oo@00ooB60?ol003om?/0ood00?odn`3oo00Ro@00
ooCk0?om003om8H0oo`00?odn`3oo@00ooCk0?ol03km003oo?/3oo_ooogk0?om
003oo8H3ohKooof60?ol003oo?/3oo_ooogk0?om003oo?/3oo_ooogk0?ol04[m
00;ono_no`<0o`00o_l1noom00;oQXKno`<0o`00o_l1Q_ol00;ono_no`<0o`00
o_l1noom00;ono_no`<0o`00o_l1nool03Km0?koo@00oo`00Oooo@3nood00?ol
007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo002[`02[`0bo@00ooh00?ol
003ooP00onT00?on003oo000ooh00?om003ooP00oo`00?on003oo00bo@3no`80
0?on00;o003nonT0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo00ho@05
obLWool0o_l50?oo9bOoj@05obLWool0o_l50?oo9bOoo@05obLWool0o_l50?oo
9bOoo00bo@00oodW1?oo9ooooBL0onT00?om9`CoobOooodW0?om003ooBL4oolW
ooom9`3oo00Jo@00oo@W0?oY003om2L0ood00?od9`3oo00Jo@00oo@W0?oY003o
m2L0ood00?od9`3oo00Jo@00oo@W0?oY003om2L0ood00?od9`3oo00_o@00oo`W
0olWooom9`3oj@00oo`W0olWooom9`3oo@00oo`W0olWooom9`3oo00ho@02obLW
o_l30?l00?ko0BOoj@02obLWo_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOo
o00Yo@3nood00?ol007oonT0o_om003oo001ooom0?koo@00oo`00Oooo002[`02
[`0bo@00ooh00?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on
003oj@0bo@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00ooh0
0_l00?koj@0ho@05obLWool0o_l50?oo9bOoo@05onKVool0o_l50?ooi^Koo005
onKVool0o_l50?ooi^Koj@0bo@00oodW1?oo9ooooBL0ood00?omiPCoonKooogV
0?ol003ooNH4oooVooomiP3oj@0Jo@00oo@W0?om003om>H0oo`00?odiP3oj@0J
o@00oo@W0?om003om>H0oo`00?odiP3oj@0Jo@00oo@W0?om003om>H0oo`00?od
iP3oj@0_o@00oo`W0olWooom9`3oo@00oocV0ooVooomiP3oo000oocV0ooVooom
iP3oj@0ho@02obLWo_l30?l00?ko0BOoo@02onKVo_l30?l00?ko0NKoo002onKV
o_l30?l00?ko0NKoj@0Yo@3nood00?ol007oood0o_om003oo001oool0?koo@00
oo`00Oooj@02[`02[`02[`0bo@00ooh00?ol003ooP00ood00?on003oo000ooh0
0?ol003ooP00oo`00?on003oj@0bo@3no`800?on00;o003nood0o_l2003ooP02
o`00o_ol0?ko0P00ooh00_l00?koj@0ho@05obLWool0o_l50?oo9bOoo@05obLW
ool0o_l50?oo9bOoo005obLWool0o_l50?oo9bOoj@0bo@00oodW1?oo9ooooBL0
ood00?om9`CoobOooodW0?ol003ooBL4oolWooom9`3oj@0Jo@00oo@W0?om003o
m2L0oo`00?od9`3oj@0Jo@00oo@W0?om003om2L0oo`00?od9`3oj@0_o@00oo`W
0olWooom9`3oo@00oo`W0olWooom9`3oo000oo`W0olWooom9`3oj@0ho@02obLW
o_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOoo002obLWo_l30?l00?ko0BOo
j@0Yo@3nood00?ol007oood0o_om003oo001oool0?koo@00oo`00Oooj@02[`02
[`02[`0bo@00ooh00?ol003ooP00ood00?on003oo000ooh00?oY003ooP00oo`0
0?on003oo00bo@3no`800?on00;o003nood0o_l2003ooP02o`00o_oY0?ko0P00
ooh00_l00?koo00ho@05onKVool0o_l50?ooi^Koo@05obLWool0o_l50?oo9bOo
j@05obLWool0o_l50?oo9bOoo00bo@00oogV1?ooi_oooNH0ood00?om9`CoobOo
oodW0?oY003ooBL4oolWooom9`3oo00Jo@00ooCV0?om003om2L0onT00?od9`3o
o00Jo@00ooCV0?om003om2L0onT00?od9`3oo00Jo@00ooCV0?om003om2L0onT0
0?od9`3oo00_o@00oocV0ooVooomiP3oo@00oo`W0olWooom9`3oj@00oo`W0olW
ooom9`3oo00ho@02onKVo_l30?l00?ko0NKoo@02obLWo_l30?l00?ko0BOoj@02
obLWo_l30?l00?ko0BOoo00Yo@3nood00?ol007oood0o_om003oo001oooY0?ko
o@00oo`00Oooo002[`02[`0bo@00ooh00?ol003ooP00ood00?on003oo000ooh0
0?ol003ooP00oo`00?on003oj@0bo@3no`800?on00;o003nood0o_l2003ooP02
o`00o_ol0?ko0P00ooh00_l00?koj@0ho@05oiBDool0o_l50?ooU9Coo@05ohJ6
ool0o_l50?ooQXKoo005odI6ool0o_l50?ooATKoj@0bo@00oofD1?ooU?oooI@0
ood00?omQPCoohKooof60?ol003ooDH4oom6ooomAP3oj@0Jo@00ooBD0?om003o
m8H0oo`00?odAP3oj@0Jo@00ooBD0?om003om8H0oo`00?odAP3oj@0Jo@00ooBD
0?om003om8H0oo`00?odAP3oj@0_o@00oobD0onDooomU03oo@00oob60on6ooom
QP3oo000ooa60om6ooomAP3oj@0ho@02oiBDo_l30?l00?ko0ICoo@02ohJ6o_l3
0?l00?ko0HKoo002odI6o_l30?l00?ko0DKoj@0Yo@3nood00?ol007oood0o_om
003oo001oool0?koo@00oo`00Oooj@02[`02[`0RjP00ooh00?ol003ooP00onT0
0?on003oo000ooh00?ol02;Z0?ko0P00ooh00_l00?koj@3no`800?on00;o003n
oo`09^X01OoVi_oo0?ko1@3oonKVonT01OoFe_oo0?ko1@3oomKFoo`08^X00?om
iPCoonKooogV0?oY003ooMH4oooFooomeP3oo00BjP00ooCV0?oY003om=H0oo`0
4^X00?odiP3oj@00ooCF0?ol01;Z003om>H0onT00?odeP3oo00PjP00oocV0ooV
ooomiP3oj@00oocF0ooFooomeP3oo00VjP02onKVo_l30?l00?ko0NKoj@02omKF
o_l30?l00?ko0MKoo00LjP3nood00?ol007oonT0o_om003oo001oool00:_00:_
03;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00onT00?on003oo000ooh0
0?ol03;m0?ko0P00ooh00_l00?koo@3no`800?on00;o003nonT0o_l2003ooP02
o`00o_ol03Sm00Go9bOoo`3no`D0oolW9oom00Goi^Koo`3no`D0oooVi_oY00Go
9bOoo`3no`D0oolW9ool03;m003ooBL4oolWooom9`3oo@00oogV1?ooi_oooNH0
onT00?om9`CoobOooodW0?ol01[m003om2L0ood00?odiP3oj@00oo@W0?ol01[m
003om2L0ood00?odiP3oj@00oo@W0?ol01[m003om2L0ood00?odiP3oj@00oo@W
0?ol02om003oo2L3obOooodW0?om003oo>H3onKooogV0?oY003oo2L3obOooodW
0?ol03Sm00;o9bOno`<0o`00o_l19oom00;oi^Kno`<0o`00o_l1i_oY00;o9bOn
o`<0o`00o_l19ool02Wm0?koo@00oo`00Oooo@3nood00?ol007oonT0o_om003o
o001oool00:_00:_03;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00onT0
0?on003oo000ooh00?ol03;m0?ko0P00ooh00_l00?koo@3no`800?on00;o003n
onT0o_l2003ooP02o`00o_ol03Sm00Go9bOoo`3no`D0oolW9oom00Go9bOoo`3n
o`D0oolW9ooY00Gono_oo`3no`D0oooknool03;m003ooBL4oolWooom9`3oo@00
oodW1?oo9ooooBL0onT00?omn`Cooo_ooogk0?ol01[m003om2L0ood00?od9`3o
j@00ooCk0?ol01[m003om2L0ood00?od9`3oj@00ooCk0?ol01[m003om2L0ood0
0?od9`3oj@00ooCk0?ol02om003oo2L3obOooodW0?om003oo2L3obOooodW0?oY
003oo?/3oo_ooogk0?ol03Sm00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00
o_l19ooY00;ono_no`<0o`00o_l1nool02Wm0?koo@00oo`00Oooo@3nood00?ol
007oonT0o_om003oo001oool00:_00:_03;m003ooP00oo`00?on003oo@00ooh0
0?ol003ooP00oo`00?on003oo000ooh00?oY03;m0?ko0P00ooh00_l00?koo@3n
o`800?on00;o003noo`0o_l2003ooP02o`00o_oY03Sm00Go:R[oo`3no`D0oolZ
:_om00Goi^Koo`3no`D0oooVi_ol00Goi^Koo`3no`D0oooVi_oY03;m003ooBX4
oolZooom:P3oo@00oogV1?ooi_oooNH0oo`00?omiPCoonKooogV0?oY01[m003o
m2X0ood00?odiP3oo000ooCV0?oY01[m003om2X0ood00?odiP3oo000ooCV0?oY
01[m003om2X0ood00?odiP3oo000ooCV0?oY02om003oo2X3ob[ooodZ0?om003o
o>H3onKooogV0?ol003oo>H3onKooogV0?oY03Sm00;o:R[no`<0o`00o_l1:_om
00;oi^Kno`<0o`00o_l1i_ol00;oi^Kno`<0o`00o_l1i_oY02Wm0?koo@00oo`0
0Oooo@3nood00?ol007ooo`0o_om003oo001oooY00:_00:_04;m003ooP00oo`0
0?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh00?om003ooP00oo`0
0?on003oo012o@3no`800?on00;o003nood0o_l2003ooP02o`00o_ol0?ko0P00
ooh00_l00?koo@3no`800?on00;o003noo`0B_d01OoVi_oo0?ko1@3oonKVood0
1OlW9ooo0?ko1@3oobLWoo`01OlW9ooo0?ko1@3oobLWood01OlW9ooo0?ko1@3o
obLWoo`0@_d00?omiPCoonKooogV0?om003ooBL4oolWooom9`3oo000oodW1?oo
9ooooBL0ood00?om9`CoobOooodW0?ol02;m003om>H0ood00?od9`3oo000oo@W
0?om003om2L0oo`08_d00?odiP3oo@00oo@W0?ol003om2L0ood00?od9`3oo00R
o@00ooCV0?om003om2L0oo`00?od9`3oo@00oo@W0?ol03km003oo>H3onKooogV
0?om003oo2L3obOooodW0?ol003oo2L3obOooodW0?om003oo2L3obOooodW0?ol
04[m00;oi^Kno`<0o`00o_l1i_om00;o9bOno`<0o`00o_l19ool00;o9bOno`<0
o`00o_l19oom00;o9bOno`<0o`00o_l19ool03Km0?koo@00oo`00Oooo@3nood0
0?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo002[`02[`12o@00ooh0
0?ol003ooP00ood00?on003oo000ooh00?ol003ooP00oo`00?on003oo@00ooh0
0?ol003ooP00oo`0@_d0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo03n
o`800?on00;o003nood0o_l2003ooP02o`00o_ol04[m00Go9bOoo`3no`D0oolW
9oom00Go9bOoo`3no`D0oolW9ool00Go9bOoo`3no`D0oolW9oom00Go9bOoo`3n
o`D0oolW9ool04;m003ooBL4oolWooom9`3oo@00oodW1?oo9ooooBL0oo`00?om
9`CoobOooodW0?om003ooBL4oolWooom9`3oo00Ro@00oo@W0?om003om2L0oo`0
0?od9`3oo@00oo@W0?ol02;m003om2L0ood00?od9`3oo000oo@W0?om003om2L0
oo`08_d00?od9`3oo@00oo@W0?ol003om2L0ood00?od9`3oo00no@00oo`W0olW
ooom9`3oo@00oo`W0olWooom9`3oo000oo`W0olWooom9`3oo@00oo`W0olWooom
9`3oo01:o@02obLWo_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOoo002obLW
o_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOoo00fo@3nood00?ol007oood0
o_om003oo001oool0?koo@00oo`00Oooo@3nood00?ol007ooo`00Zl00Zl0@_d0
0?on003oo000ooh00?om003ooP00oo`00?on003oo000ooh00?ol003ooP00ood0
0?on003oo000ooh00?ol04;m0?ko0P00ooh00_l00?koo@3no`800?on00;o003n
oo`0o_l2003ooP02o`00o_om0?ko0P00ooh00_l00?koo01:o@05obLWool0o_l5
0?oo9bOoo@05obLWool0o_l50?oo9bOoo005oiFEool0o_l50?ooUIGoo@05obLW
ool0o_l50?oo9bOoo012o@00oodW1?oo9ooooBL0ood00?om9`CoobOooodW0?ol
003ooID4oonEooomU@3oo@00oodW1?oo9ooooBL0oo`08_d00?od9`3oo@00oo@W
0?ol003om9D0ood00?od9`3oo00Ro@00oo@W0?om003om2L0oo`00?odU@3oo@00
oo@W0?ol02;m003om2L0ood00?od9`3oo000ooBE0?om003om2L0oo`0?_d00?ol
9`?o9ooooBL0ood00?ol9`?o9ooooBL0oo`00?olU@?oUOoooID0ood00?ol9`?o
9ooooBL0oo`0B_d00_lW9oko0`3o003no`4Wood00_lW9oko0`3o003no`4Woo`0
0_nEUOko0`3o003no`6Eood00_lW9oko0`3o003no`4Woo`0=_d0o_om003oo001
ooom0?koo@00oo`00Oooo03nood00?ol007oood0o_om003oo001oool00:_00:_
04;m003ooP00oo`00?on003oo@00ooh00?ol003ooP00oo`00?on003oo000ooh0
0?om003ooP00oo`00?on003oo012o@3no`800?on00;o003nood0o_l2003ooP02
o`00o_ol0?ko0P00ooh00_l00?koo@3no`800?on00;o003noo`0B_d01OlW9ooo
0?ko1@3oobLWood01OlW9ooo0?ko1@3oobLWoo`01OlW9ooo0?ko1@3oobLWood0
1OlW9ooo0?ko1@3oobLWoo`0@_d00?om9`CoobOooodW0?om003ooBL4oolWooom
9`3oo000oodW1?oo9ooooBL0ood00?om9`CoobOooodW0?ol02;m003om2L0ood0
0?od9`3oo000oo@W0?om003om2L0oo`08_d00?od9`3oo@00oo@W0?ol003om2L0
ood00?od9`3oo00Ro@00oo@W0?om003om2L0oo`00?od9`3oo@00oo@W0?ol03km
003oo2L3obOooodW0?om003oo2L3obOooodW0?ol003oo2L3obOooodW0?om003o
o2L3obOooodW0?ol04[m00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l1
9ool00;o9bOno`<0o`00o_l19oom00;o9bOno`<0o`00o_l19ool03Km0?koo@00
oo`00Oooo@3nood00?ol007ooo`0o_om003oo001ooom0?koo@00oo`00Oooo002
[`02[`0ReP00ooh00?ol003ooP00ood00?on003oo000ooh00?ol02;F0?ko0P00
ooh00_l00?koo@3no`800?on00;o003noo`09]H01OlW9ooo0?ko1@3oobLWood0
1OlW9ooo0?ko1@3oobLWoo`08]H00?om9`CoobOooodW0?om003ooBL4oolWooom
9`3oo00BeP00oo@W0?om003om2L0oo`04]H00?od9`3oo@00oo@W0?ol01;F003o
m2L0ood00?od9`3oo00PeP00oo`W0olWooom9`3oo@00oo`W0olWooom9`3oo00V
eP02obLWo_l30?l00?ko0BOoo@02obLWo_l30?l00?ko0BOoo00LeP3nood00?ol
007oood0o_om003oo001oool00:_00:_03;m003ooP00oo`00?on003oo@00ooh0
0?ol003ooP00onT00?on003oo000ooh00?ol03;m0?ko0P00ooh00_l00?koo@3n
o`800?on00;o003nonT0o_l2003ooP02o`00o_ol03Sm00Go9bOoo`3no`D0oolW
9oom00Go9bOoo`3no`D0oolW9ooY00Go9bOoo`3no`D0oolW9ool03;m003ooBL4
oolWooom9`3oo@00oodW1?oo9ooooBL0onT00?om9`CoobOooodW0?ol01[m003o
m2L0ood00?od9`3oj@00oo@W0?ol01[m003om2L0ood00?od9`3oj@00oo@W0?ol
01[m003om2L0ood00?od9`3oj@00oo@W0?ol02om003oo2L3obOooodW0?om003o
o2L3obOooodW0?oY003oo2L3obOooodW0?ol03Sm00;o9bOno`<0o`00o_l19oom
00;o9bOno`<0o`00o_l19ooY00;o9bOno`<0o`00o_l19ool02Wm0?koo@00oo`0
0Oooo@3nood00?ol007oonT0o_om003oo001oool00:_00:_00:_00:_00:_00:_
00:_00:_00:_00:_00000@0:0480<@8f0Dh0;00C>GL@DR16LWEdJFMULR1BKfeQ
KP000cUg00d02`0^00@0004101GCZ`0X0C00?@I7IFh^830001G_eP0YC0I7IFh^
83405@`102U=1TMUKRhP<P0E:2`0:D`6AfE^;R0d01EnF`0X0S<0>PI7IFh^83D0
01G_g00YBPM7IFh^834`000EhE`0:Dd7AfE^;R0a=@005JPc02U91dMUKRhP<S00
0?l\>"], "Graphics",
  ImageSize->{284, 499},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Butterflies adapting their wing colouring to a bright background.\
\
\>", "NumberedFigure"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["External Notebooks \[Ellipsis]"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "All the necessary programs for the butterfly evolution examples can be \
found in the notebook ",
  ButtonBox["Butterflies.nb",
    ButtonData:>{"Butterflies.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(SetDirectory["\<...\>"]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<Butterflies.m\>"\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["References \[Ellipsis]"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Download the ",
  ButtonBox["latest version",
    ButtonData:>{
      URL[ 
      "http://www.cpsc.ucalgary.ca/~jacob/Evolvica/EA-TableOfContents.html#\
Mimesis"], None},
    ButtonStyle->"Hyperlink"],
  " of this notebook from"
}], "Text"],

Cell["\<\
http://www.cpsc.ucalgary.ca/~jacob/Evolvica/EA-TableOfContents.html\
\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
AutoGeneratedPackage->None,
WindowSize->{632, 436},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Butterfly Mimicry"}]]}, {Cell[ 
        TextData[ {"Butterfly Mimicry"}]], Inherited, Inherited}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
StyleDefinitions -> "CourseStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000002n88o001
0000I00000400`<300000BL?00400@00000000000000050801T1T00000080000
00000000003ooP00003ooP000El00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 34, 0, 105, "Title"],
Cell[1768, 53, 108, 2, 61, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1901, 59, 31, 0, 60, "Section"],
Cell[1935, 61, 660, 14, 160, "Text"],
Cell[2598, 77, 433, 7, 122, "Text"],
Cell[3034, 86, 1028, 22, 217, "Text"],
Cell[4065, 110, 129, 3, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4231, 118, 47, 0, 44, "Section"],

Cell[CellGroupData[{
Cell[4303, 122, 34, 0, 40, "Subsection"],
Cell[4340, 124, 1090, 38, 122, "Text"],
Cell[5433, 164, 335, 10, 65, "Text"],
Cell[5771, 176, 181, 8, 33, "Text"],
Cell[5955, 186, 155, 3, 46, "Text"],
Cell[6113, 191, 545, 15, 109, "Text"],

Cell[CellGroupData[{
Cell[6683, 210, 34, 0, 32, "Subsubsection"],
Cell[6720, 212, 263, 7, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7020, 224, 30, 0, 32, "Subsubsection"],
Cell[7053, 226, 537, 11, 122, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7639, 243, 65, 0, 26, "Subsection"],
Cell[7707, 245, 222, 6, 46, "Text"],
Cell[7932, 253, 182, 4, 65, "Text"],
Cell[8117, 259, 157768, 2429, 507, 157676, 2426, "GraphicsData", 
"PICT", "Graphics"],
Cell[165888, 2690, 101, 3, 47, "NumberedFigure"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[166038, 2699, 139, 3, 44, "Section"],
Cell[166180, 2704, 237, 7, 46, "Text"],
Cell[166420, 2713, 110, 3, 47, "Input",
  InitializationCell->True],
Cell[166533, 2718, 109, 3, 47, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[166679, 2726, 99, 2, 44, "Section"],
Cell[166781, 2730, 259, 9, 27, "Text"],
Cell[167043, 2741, 93, 3, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

